// ========== 调试日志系统 ==========

class DebugLogger {
    constructor() {
        this.logs = [];
        this.maxLogs = 1000; // 最多保存1000条日志
        this.startTime = Date.now();
        this.isCollecting = true;
        
        // 拦截console方法
        this.originalConsole = {
            log: console.log,
            warn: console.warn,
            error: console.error,
            info: console.info,
            debug: console.debug
        };
        
        this.initConsoleInterception();
        this.initErrorHandling();
        this.logSystemInfo();
    }
    
    // 拦截console输出
    initConsoleInterception() {
        const self = this;
        
        ['log', 'warn', 'error', 'info', 'debug'].forEach(method => {
            console[method] = function(...args) {
                // 调用原始方法
                self.originalConsole[method].apply(console, args);
                
                // 记录到我们的日志系统
                if (self.isCollecting) {
                    self.addLog(method, args);
                }
            };
        });
    }
    
    // 处理未捕获的错误
    initErrorHandling() {
        const self = this;
        
        // 捕获JavaScript错误
        window.addEventListener('error', function(event) {
            // 清理文件路径，只保留文件名
            const cleanFilename = event.filename ? 
                event.filename.split('/').pop().split('\\').pop() : 'unknown';
                
            self.addLog('error', [
                `[JS Error] ${event.message}`,
                `File: ${cleanFilename}:${event.lineno}:${event.colno}`,
                `Stack: ${event.error ? self.cleanStackTrace(event.error.stack) : 'N/A'}`
            ]);
        });
        
        // 捕获Promise rejection
        window.addEventListener('unhandledrejection', function(event) {
            self.addLog('error', [
                `[Promise Rejection] ${event.reason}`,
                `Stack: ${event.reason && event.reason.stack ? self.cleanStackTrace(event.reason.stack) : 'N/A'}`
            ]);
        });
        
        // 捕获资源加载错误
        window.addEventListener('error', function(event) {
            if (event.target !== window) {
                // 清理资源路径，只保留文件名
                const resourceUrl = event.target.src || event.target.href || 'unknown';
                const cleanResource = resourceUrl.split('/').pop().split('\\').pop();
                
                self.addLog('error', [
                    `[Resource Error] Failed to load: ${cleanResource}`,
                    `Element: ${event.target.tagName}`,
                    `Type: ${event.type}`
                ]);
            }
        }, true);
    }
    
    // 记录系统信息
    logSystemInfo() {
        // 简化的用户代理信息，只保留浏览器类型
        const ua = navigator.userAgent;
        let browserInfo = 'Unknown Browser';
        if (ua.includes('Chrome')) browserInfo = 'Chrome-based';
        else if (ua.includes('Firefox')) browserInfo = 'Firefox';
        else if (ua.includes('Safari') && !ua.includes('Chrome')) browserInfo = 'Safari';
        else if (ua.includes('Edge')) browserInfo = 'Edge';
        
        const info = {
            timestamp: new Date().toISOString(),
            browser: browserInfo,
            platform: navigator.platform,
            language: navigator.language,
            cookieEnabled: navigator.cookieEnabled,
            onLine: navigator.onLine,
            screenSize: `${screen.width}x${screen.height}`,
            windowSize: `${window.innerWidth}x${window.innerHeight}`,
            localStorage: this.checkLocalStorage(),
            gameVersion: '1.4',
            protocol: window.location.protocol
        };
        
        this.addLog('info', ['[System Info]', JSON.stringify(info, null, 2)]);
    }
    
    // 清理堆栈跟踪中的文件路径
    cleanStackTrace(stack) {
        if (!stack) return 'N/A';
        
        // 将完整路径替换为文件名
        return stack.replace(/https?:\/\/[^\/]+\/[^:]*\//g, '')
                   .replace(/file:\/\/\/[^:]*\//g, '')
                   .replace(/\/[^\/\s]*\//g, '/')
                   .replace(/\\\S*\\/g, '\\');
    }
    
    // 检查localStorage可用性
    checkLocalStorage() {
        try {
            const test = '__test__';
            localStorage.setItem(test, test);
            localStorage.removeItem(test);
            return 'available';
        } catch (e) {
            return `unavailable: ${e.message}`;
        }
    }
    
    // 添加日志条目
    addLog(level, args) {
        const timestamp = Date.now() - this.startTime;
        const logEntry = {
            timestamp: timestamp,
            timeString: new Date().toISOString(),
            level: level,
            message: args.map(arg => {
                if (typeof arg === 'object') {
                    try {
                        return JSON.stringify(arg, null, 2);
                    } catch (e) {
                        return arg.toString();
                    }
                }
                return String(arg);
            }).join(' ')
        };
        
        this.logs.push(logEntry);
        
        // 限制日志数量
        if (this.logs.length > this.maxLogs) {
            this.logs.shift();
        }
    }
    
    // 导出日志
    exportLogs() {
        const exportData = {
            exportTime: new Date().toISOString(),
            sessionDuration: Date.now() - this.startTime,
            totalLogs: this.logs.length,
            gameState: this.getGameState(),
            logs: this.logs
        };
        
        const dataStr = JSON.stringify(exportData, null, 2);
        const dataBlob = new Blob([dataStr], { type: 'application/json' });
        
        // 创建下载链接
        const url = URL.createObjectURL(dataBlob);
        const link = document.createElement('a');
        link.href = url;
        link.download = `game-debug-log-${new Date().toISOString().replace(/[:.]/g, '-')}.json`;
        
        // 触发下载
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
        
        // 清理URL对象
        URL.revokeObjectURL(url);
        
        return exportData;
    }
    
    // 获取游戏状态信息
    getGameState() {
        const state = {};
        
        try {
            // 玩家数据
            if (typeof player !== 'undefined' && player) {
                state.player = {
                    name: player.name,
                    level: player.lvl,
                    allocated: player.allocated,
                    inCombat: player.inCombat,
                    gold: player.gold
                };
            }
            
            // 地牢状态
            if (typeof dungeon !== 'undefined' && dungeon) {
                state.dungeon = {
                    floor: dungeon.floor,
                    room: dungeon.room,
                    exploring: dungeon.status ? dungeon.status.exploring : null,
                    paused: dungeon.status ? dungeon.status.paused : null
                };
            }
            
            // localStorage数据
            const savedPlayer = localStorage.getItem('playerData');
            const savedDungeon = localStorage.getItem('dungeonData');
            
            state.localStorage = {
                playerData: savedPlayer ? 'exists' : 'missing',
                dungeonData: savedDungeon ? 'exists' : 'missing',
                playerDataSize: savedPlayer ? savedPlayer.length : 0,
                dungeonDataSize: savedDungeon ? savedDungeon.length : 0
            };
            
        } catch (e) {
            state.error = `Failed to collect game state: ${e.message}`;
        }
        
        return state;
    }
    
    // 获取简要日志摘要
    getSummary() {
        const errorLogs = this.logs.filter(log => log.level === 'error');
        const warnLogs = this.logs.filter(log => log.level === 'warn');
        
        return {
            totalLogs: this.logs.length,
            errors: errorLogs.length,
            warnings: warnLogs.length,
            recentErrors: errorLogs.slice(-5),
            recentWarnings: warnLogs.slice(-5)
        };
    }
    
    // 清空日志
    clearLogs() {
        this.logs = [];
        this.addLog('info', ['[Debug Logger] Logs cleared']);
    }
    
    // 停止/开始收集日志
    toggleCollection() {
        this.isCollecting = !this.isCollecting;
        this.addLog('info', [`[Debug Logger] Collection ${this.isCollecting ? 'started' : 'stopped'}`]);
        return this.isCollecting;
    }
}

// 全局日志实例
window.debugLogger = new DebugLogger();

// 添加全局函数方便调用
window.exportLogs = () => window.debugLogger.exportLogs();
window.getLogSummary = () => window.debugLogger.getSummary();
window.clearDebugLogs = () => window.debugLogger.clearLogs();

// 在游戏关键点添加日志
window.logGameEvent = (event, data) => {
    console.log(`[Game Event] ${event}`, data);
};

console.log('[Debug Logger] Initialized successfully');