const dungeonActivity = document.querySelector("#dungeonActivity");
const dungeonAction = document.querySelector("#dungeonAction");
const dungeonTime = document.querySelector("#dungeonTime");
const floorCount = document.querySelector("#floorCount");
const roomCount = document.querySelector("#roomCount");

// 休息时血量恢复计时器
let restTimer;

let dungeon = {
    rating: 500,
    grade: "E",
    progress: {
        floor: 1,
        room: 1,
        floorLimit: 100,
        roomLimit: 5,
    },
    settings: {
        enemyBaseLvl: 1,
        enemyLvlGap: 5,
        enemyBaseStats: 1,
        enemyScaling: 1.1,
    },
    status: {
        exploring: false,
        paused: true,
        event: false,
    },
    statistics: {
        kills: 0,
        runtime: 0,
    },
    backlog: [],
    action: 0,
};

// ===== Dungeon Setup =====
// Enables start and pause on button click
dungeonActivity.addEventListener('click', function () {
    dungeonStartPause();
});

// ========== 事件状态管理器 ==========
const EventStateManager = {
    // 检查是否有活动的事件选择
    hasActiveEventChoices: function() {
        const eventButtons = document.querySelectorAll('.decision-panel button:not([disabled])');
        return eventButtons.length > 0;
    },
    
    // 检查是否可以安全清理事件状态
    canSafelyClearEvent: function() {
        // 如果没有活动的事件选择按钮，且当前在事件状态，则可以清理
        return !this.hasActiveEventChoices() && dungeon.status.event;
    },
    
    // 尝试清理事件状态（统一入口）
    tryToClearEventState: function(source = 'unknown') {
        if (this.canSafelyClearEvent()) {
            console.log(`[${source}] 清理事件状态：没有活动的事件选择`);
            this.clearEventAndTriggerNext();
            return true;
        }
        return false;
    },
    
    // 清理事件状态并触发下一个事件
    clearEventAndTriggerNext: function() {
        console.log('清理事件状态并准备下一个事件');
        dungeon.status.event = false;
        
        // 确保清除任何遗留的事件选择按钮
        const decisionPanels = document.querySelectorAll('.decision-panel');
        decisionPanels.forEach(panel => panel.remove());
        
        updateDungeonActivityButton();
        
        // 如果玩家在探索状态，立即生成下一个事件
        if (dungeon.status.exploring && !player.inCombat) {
            // 重置action计数，避免卡在roomLimit
            if (dungeon.action > 10) {
                console.log('重置action计数，避免卡住');
                dungeon.action = 0;
            }
            
            setTimeout(() => {
                this.triggerNextEvent();
            }, 1000); // 延迟调整为1秒，给用户时间看到结果
        }
    },
    
    // 开始事件状态
    startEvent: function() {
        console.log('开始新事件');
        dungeon.status.event = true;
        updateDungeonActivityButton();
    },
    
    // 触发下一个事件（仅在探索时）
    triggerNextEvent: function() {
        console.log('尝试触发下一个事件:', {
            exploring: dungeon.status.exploring,
            paused: dungeon.status.paused,
            event: dungeon.status.event,
            inCombat: player.inCombat
        });
        
        // 额外的状态验证
        if (dungeon.status.paused) {
            console.log('游戏暂停中，不触发事件');
            return;
        }
        
        // 检查是否有未关闭的模态窗口
        const openModals = document.querySelectorAll('.modal-container[style*="flex"]');
        if (openModals.length > 0) {
            console.log('检测到未关闭的模态窗口，不触发事件');
            return;
        }
        
        // 主要条件检查
        if (dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
            // 记录事件触发时间，用于调试
            window.lastEventTime = Date.now();
            dungeonEvent();
        } else {
            console.log('无法触发事件，条件不满足:', {
                needExploring: !dungeon.status.exploring,
                hasEvent: dungeon.status.event,
                inCombat: player.inCombat
            });
        }
    },
    
    // 完成选择后的清理
    completeChoice: function(actionCallback) {
        if (typeof actionCallback === 'function') {
            actionCallback();
        }
        // 不要立即清理和触发下一个事件
        // 某些操作（如显示模态窗口）需要延迟处理
        // 让具体的事件处理函数决定何时继续
    },
    
    // 进入战斗状态
    enterCombat: function() {
        console.log('进入战斗状态');
        dungeon.status.event = false; // 战斗状态不需要事件标志
        updateDungeonActivityButton();
    },
    
    // 战斗结束后恢复探索
    exitCombat: function() {
        console.log('退出战斗状态');
        if (dungeon.status.exploring && !dungeon.status.paused) {
            setTimeout(() => {
                this.triggerNextEvent();
            }, 500); // 给战斗结束一些时间
        }
    },
    
    // 清理事件状态（由combat.js调用）
    clearEventState: function(source = 'unknown') {
        console.log(`[${source}] 清理事件状态`);
        dungeon.status.event = false;
        updateDungeonActivityButton();
    }
};

// Sets up the initial dungeon（增强版）
const initialDungeonLoad = () => {
    if (localStorage.getItem("dungeonData") !== null) {
        dungeon = JSON.parse(localStorage.getItem("dungeonData"));
        
        // 强制重置状态，避免加载时的状态不一致
        dungeon.status = {
            exploring: false,
            paused: true,
            event: false,
        };
        
        // 确保玩家不在战斗状态（避免存档时状态不一致）
        if (player && player.inCombat) {
            console.warn('初始化时检测到玩家在战斗中，重置战斗状态');
            player.inCombat = false;
        }
        
        // 清理包含交互元素的日志条目（防止重新加载时显示孤儿按钮）
        if (dungeon.backlog) {
            dungeon.backlog = dungeon.backlog.filter(log => 
                !log.includes('decision-panel') && 
                !log.includes('<button id="choice') &&
                !log.includes('primary-panel') &&
                !log.includes('<ul>') &&
                !log.includes('<li>') &&
                !log.includes('onclick=')
            );
        }
        
        updateDungeonLog();
    }
    
    loadDungeonProgress();
    dungeonTime.innerHTML = "00:00:00";
    
    // 清理旧的定时器
    if (window.dungeonTimer) {
        clearInterval(window.dungeonTimer);
    }
    if (window.playTimer) {
        clearInterval(window.playTimer);
    }
    
    // 创建新的定时器 - 移除自动事件生成
    window.playTimer = setInterval(dungeonCounter, 1000);
    
    // 初始化按钮状态
    updateDungeonActivityButton();
    
    // 初始化时如果处于暂停状态，开始休息血量恢复
    if (dungeon.status.paused && !player.inCombat) {
        startResting();
    }
    
    console.log('地牢系统初始化完成');
}

// 简化的状态检查 - 只检查战斗状态不一致
const validateDungeonState = () => {
    // 只修复战斗状态不一致
    if (player && player.inCombat && !dungeon.status.event) {
        console.log('修复战斗状态不一致');
        dungeon.status.event = true;
        return true;
    }
    return false;
};

// 更新探索按钮状态的函数（增强版）
// 检查是否真的有可点击的事件按钮
const hasActiveEventButtons = () => {
    // 检查页面上是否真的有可点击的决策按钮
    const eventButtons = document.querySelectorAll(
        '.decision-panel button:not([disabled]), ' +
        'button[id^="choice"]:not([disabled]), ' +
        '#battleButton:not([disabled])'
    );
    
    // 过滤出真正可见且可点击的按钮
    const visibleButtons = Array.from(eventButtons).filter(btn => {
        const rect = btn.getBoundingClientRect();
        const style = window.getComputedStyle(btn);
        return rect.width > 0 && rect.height > 0 && 
               style.display !== 'none' && 
               style.visibility !== 'hidden' &&
               !btn.disabled;
    });
    
    return visibleButtons.length > 0;
};

// 检查是否在主页面
const isOnMainPage = () => {
    const dungeonMain = document.querySelector('#dungeon-main');
    return dungeonMain && dungeonMain.style.display !== 'none';
};

// 简化的按钮状态管理
const updateDungeonActivityButton = () => {
    dungeonActivity.style.display = "block";
    dungeonActivity.style.visibility = "visible";
    
    const hasButtons = hasActiveEventButtons();
    const onMainPage = isOnMainPage();
    
    if (hasButtons && onMainPage) {
        // 有真实按钮时显示"处理事件"
        dungeon.status.event = true;
        dungeonActivity.innerHTML = "处理事件";
        dungeonActivity.style.opacity = "0.7";
        dungeonActivity.disabled = true;
        dungeonAction.innerHTML = "等待选择...";
    } else if (!onMainPage) {
        // 不在主页面时暂停
        dungeon.status.event = false;
        dungeon.status.exploring = false;
        dungeon.status.paused = true;
        dungeonActivity.innerHTML = "探索";
        dungeonActivity.style.opacity = "1";
        dungeonActivity.disabled = false;
        dungeonAction.innerHTML = "已暂停";
    } else if (dungeon.status.paused) {
        // 暂停状态
        clearEventState();
        dungeonActivity.innerHTML = "探索";
        dungeonActivity.style.opacity = "1";
        dungeonActivity.disabled = false;
        dungeonAction.innerHTML = "休息中...";
    } else {
        // 探索状态
        clearEventState();
        dungeonActivity.innerHTML = "暂停";
        dungeonActivity.style.opacity = "1";
        dungeonActivity.disabled = false;
        dungeonAction.innerHTML = "探索中...";
    }
};

// 清理事件状态
const clearEventState = () => {
    dungeon.status.event = false;
    // 不强制改变exploring和paused状态，让它们保持原有状态
};

// 强制重置系统状态（紧急情况使用）
const forceResetDungeonState = () => {
    console.warn('执行强制状态重置...');
    
    // 关闭所有可能的模态窗口
    const modals = document.querySelectorAll('.modal-container');
    modals.forEach(modal => {
        if (modal.style.display === 'flex' || modal.style.display === 'block') {
            modal.style.display = 'none';
        }
    });
    
    // 重置所有状态
    dungeon.status.event = false;
    if (player) {
        player.inCombat = false;
    }
    
    // 强制更新UI
    updateDungeonActivityButton();
    addDungeonLog('<i class="fas fa-hammer"></i> <span style="color: #ff6b6b;">强制重置：系统状态已清除</span>');
    
    // 保存数据
    saveData();
};

// 双击计数器
let dungeonButtonClickCount = 0;
let dungeonButtonClickTimer = null;

// Start and Pause Functionality（增强版）
const dungeonStartPause = () => {
    // 双击检测（用于强制重置）
    if (dungeon.status.event) {
        dungeonButtonClickCount++;
        
        if (dungeonButtonClickCount === 1) {
            dungeonButtonClickTimer = setTimeout(() => {
                dungeonButtonClickCount = 0;
            }, 500); // 500ms内双击有效
        } else if (dungeonButtonClickCount === 2) {
            clearTimeout(dungeonButtonClickTimer);
            dungeonButtonClickCount = 0;
            
            // 确认强制重置
            if (confirm('检测到系统状态异常，是否强制重置？\n注意：这将关闭所有窗口并清除事件状态。')) {
                forceResetDungeonState();
            }
            return;
        }
    }
    
    // 调试信息
    console.log('探索按钮点击 - 当前状态:', {
        paused: dungeon.status.paused,
        exploring: dungeon.status.exploring,
        event: dungeon.status.event,
        action: dungeon.action
    });
    
    if (!dungeon.status.paused) {
        // 检查是否有未完成的事件
        if (dungeon.status.event) {
            safePlaySFX(sfxDeny);
            addDungeonLog("<span style='color: #ff6b6b;'><i class='fas fa-exclamation-triangle'></i> 无法休息：必须先处理当前事件！</span>");
            
            // 短暂闪烁按钮提示
            dungeonActivity.style.backgroundColor = "#ff6b6b";
            dungeonActivity.style.color = "white";
            setTimeout(() => {
                dungeonActivity.style.backgroundColor = "";
                dungeonActivity.style.color = "";
                updateDungeonActivityButton(); // 恢复正确状态
            }, 500);
            
            return; // 阻止暂停操作
        }
        
        safePlaySFX(sfxPause);
        dungeon.status.exploring = false;
        dungeon.status.paused = true;
        
        // 开始休息时的血量恢复
        startResting();
    } else {
        safePlaySFX(sfxUnpause);
        dungeon.status.exploring = true;
        dungeon.status.paused = false;
        
        // 停止休息时的血量恢复
        stopResting();
        
        // 开始探索时，如果没有进行中的事件，触发第一个事件
        if (!dungeon.status.event && !player.inCombat) {
            setTimeout(() => {
                EventStateManager.triggerNextEvent();
            }, 500); // 短暂延迟让UI更新
        }
    }
    
    // 更新按钮状态
    updateDungeonActivityButton();
}

// Counts the total time for the current run and total playtime
const dungeonCounter = () => {
    player.playtime++;
    dungeon.statistics.runtime++;
    dungeonTime.innerHTML = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
    saveData();
}

// Loads the floor and room count
const loadDungeonProgress = () => {
    if (dungeon.progress.room > dungeon.progress.roomLimit) {
        dungeon.progress.room = 1;
        dungeon.progress.floor++;
        
        // 检查是否达到100星区通关
        if (dungeon.progress.floor > dungeon.progress.floorLimit) {
            triggerVictory();
            return;
        }
    }
    floorCount.innerHTML = `星区 ${dungeon.progress.floor}`;
    roomCount.innerHTML = `区域 ${dungeon.progress.room}`;
}

// ========== Events in the Dungeon ==========
const dungeonEvent = () => {
    // 确保只在正确的状态下生成事件
    if (!dungeon.status.exploring || dungeon.status.event || player.inCombat) {
        console.log('无法生成事件:', {
            exploring: dungeon.status.exploring,
            event: dungeon.status.event,
            inCombat: player.inCombat
        });
        return;
    }
    
    console.log('生成新的地牢事件，当前action:', dungeon.action);
    dungeon.action++;
    let choices;
    let eventRoll;
    let eventTypes = ["blessing", "curse", "treasure", "enemy", "enemy", "nothing", "nothing", "monarch"];
    if (dungeon.action > 2 && dungeon.action < 6) {
        eventTypes.push("nextroom");
    } else if (dungeon.action > 5) {
        eventTypes = ["nextroom"];
    }
    const event = eventTypes[Math.floor(Math.random() * eventTypes.length)];
    console.log('生成事件类型:', event);

    switch (event) {
            case "nextroom":
                EventStateManager.startEvent(); // 使用状态管理器开始事件
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">进入</button>
                        <button id="choice2">忽略</button>
                    </div>`;
                if (dungeon.progress.room == dungeon.progress.roomLimit) {
                    addDungeonLog(`<span class="Heirloom">你发现了一个不稳定的跃迁点，通往危险的异常空间。</span>`, choices);
                } else {
                    addDungeonLog("你发现了一个跃迁点。", choices);
                }
                
                // 使用安全的事件绑定
                handleEventChoice("#choice1", () => {
                    safePlaySFX(sfxConfirm);
                    if (dungeon.progress.room == dungeon.progress.roomLimit) {
                        guardianBattle();
                    } else {
                        eventRoll = randomizeNum(1, 3);
                        if (eventRoll == 1) {
                            incrementRoom();
                            mimicBattle("door");
                            addDungeonLog("你移动到了下一个区域。");
                        } else if (eventRoll == 2) {
                            incrementRoom();
                            addDungeonLog("你移动到了下一个区域。");
                            // 设置下一个事件为宝箱事件
                            setTimeout(() => {
                                if (dungeon.status.exploring && !player.inCombat) {
                                    // 直接触发一个宝箱事件
                                    EventStateManager.startEvent();
                                    const treasureChoices = `
                                        <div class="decision-panel">
                                            <button id="choice1">激活能量箱</button>
                                            <button id="choice2">忽略</button>
                                        </div>`;
                                    addDungeonLog(`发现了一个能量储存室。里面有一个 <i class="fa fa-battery-half"></i>能量箱。`, treasureChoices);
                                    handleEventChoice("#choice1", () => {
                                        safePlaySFX(sfxConfirm);
                                        chestEvent();
                                    });
                                    handleEventChoice("#choice2", () => {
                                        safePlaySFX(sfxDecline);
                                        ignoreEvent();
                                    });
                                }
                            }, 500);
                        } else {
                            // 这不是真正的选择事件，直接执行
                            incrementRoom();
                            addDungeonLog("你移动到了下一个区域。");
                            // 需要手动触发下一个事件
                            EventStateManager.clearEventAndTriggerNext();
                        }
                    }
                });
                handleEventChoice("#choice2", () => {
                    safePlaySFX(sfxDecline);
                    dungeon.action = 0;
                    ignoreEvent();
                });
                break;
            case "treasure":
                EventStateManager.startEvent(); // 使用状态管理器开始事件
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">激活能量箱</button>
                        <button id="choice2">忽略</button>
                    </div>`;
                addDungeonLog(`你发现了一个能量储存室。里面有一个 <i class="fa fa-battery-half"></i>能量箱。`, choices);
                handleEventChoice("#choice1", () => {
                    safePlaySFX(sfxConfirm);
                    chestEvent();
                });
                handleEventChoice("#choice2", () => {
                    safePlaySFX(sfxDecline);
                    ignoreEvent();
                });
                break;
            case "nothing":
                // nothing事件不是真正的选择事件，直接执行
                nothingEvent();
                // nothing事件后需要自动触发下一个事件
                setTimeout(() => {
                    if (dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
                        EventStateManager.triggerNextEvent();
                    }
                }, 2000); // 给玩家2秒时间看消息
                break;
            case "enemy":
                EventStateManager.startEvent(); // 使用状态管理器开始事件
                generateRandomEnemy();
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">战斗</button>
                        <button id="choice2">逃跑</button>
                    </div>`;
                addDungeonLog(`你遇到了 ${enemy.name}。`, choices);
                // 不要在这里设置inCombat，等用户选择战斗后再设置
                handleEventChoice("#choice1", () => {
                    safePlaySFX(sfxConfirm);
                    engageBattle();
                });
                handleEventChoice("#choice2", () => {
                    safePlaySFX(sfxDecline);
                    fleeBattle();
                });
                break;
            case "blessing":
                eventRoll = randomizeNum(1, 2);
                if (eventRoll == 1) {
                    EventStateManager.startEvent(); // 使用状态管理器开始事件
                    blessingValidation();
                    // 确保 player.blessing 是数字类型
                    player.blessing = Number(player.blessing) || 1;
                    let cost = Math.floor(player.blessing * (500 * (player.blessing * 0.5)) + 750);
                    choices = `
                        <div class="decision-panel">
                            <button id="choice1">激活</button>
                            <button id="choice2">忽略</button>
                        </div>`;
                    addDungeonLog(`<span class="Legendary">你发现了一个古代能量节点。你想投入 <i class="fas fa-coins" style="color: #FFD700;"></i><span class="Common">${nFormatter(cost)}</span> 信用点来激活它吗？ (增强等级.${player.blessing})</span>`, choices);
                    handleEventChoice("#choice1", () => {
                        // 确保金币比较时使用数字类型
                        const playerGold = Number(player.gold) || 0;
                        const requiredCost = Number(cost) || 0;
                        console.log(`祝福金币检查 - 玩家金币: ${playerGold}, 需要: ${requiredCost}`);
                        
                        if (playerGold < requiredCost) {
                            safePlaySFX(sfxDeny);
                            addDungeonLog("你没有足够的信用点。");
                            // 金币不足也需要触发下一个事件
                            EventStateManager.clearEventAndTriggerNext();
                        } else {
                            player.gold -= cost;
                            saveData();
                            playerLoadStats();
                            safePlaySFX(sfxConfirm);
                            statBlessing();
                            // statBlessing不显示模态窗口，需要手动触发下一个事件
                            EventStateManager.clearEventAndTriggerNext();
                        }
                        
                        // 确保战斗界面已关闭
                        const combatPanel = document.querySelector('#combatPanel');
                        if (combatPanel && combatPanel.style.display !== 'none') {
                            combatPanel.style.display = 'none';
                        }
                        
                        // 确保页面亮度恢复
                        const dimDungeon = document.querySelector('#dungeon-main');
                        if (dimDungeon && dimDungeon.style.filter !== 'brightness(100%)') {
                            dimDungeon.style.filter = 'brightness(100%)';
                        }
                    });
                    handleEventChoice("#choice2", () => {
                        ignoreEvent();
                    });
                } else {
                    nothingEvent();
                    // nothing事件后需要自动触发下一个事件
                    setTimeout(() => {
                        if (dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
                            EventStateManager.triggerNextEvent();
                        }
                    }, 2000);
                }
                break;
            case "curse":
                eventRoll = randomizeNum(1, 3);
                if (eventRoll == 1) {
                    EventStateManager.startEvent(); // 使用状态管理器开始事件
                    let curseLvl = Math.round((dungeon.settings.enemyScaling - 1) * 10);
                    let cost = Math.floor(curseLvl * (10000 * (curseLvl * 0.5)) + 5000);
                    choices = `
                            <div class="decision-panel">
                                <button id="choice1">激活</button>
                                <button id="choice2">忽略</button>
                            </div>`;
                    addDungeonLog(`<span class="Heirloom">你发现了一个高能量干扰器。你想投入 <i class="fas fa-coins" style="color: #FFD700;"></i><span class="Common">${nFormatter(cost)}</span> 信用点吗？这将增强敌人但也会提高收获。 (干扰核心.Lv${curseLvl})</span>`, choices);
                    handleEventChoice("#choice1", () => {
                        // 确保金币比较时使用数字类型
                        const playerGold = Number(player.gold) || 0;
                        const requiredCost = Number(cost) || 0;
                        console.log(`诅咒金币检查 - 玩家金币: ${playerGold}, 需要: ${requiredCost}`);
                        
                        if (playerGold < requiredCost) {
                            safePlaySFX(sfxDeny);
                            addDungeonLog("你没有足够的信用点。");
                            // 金币不足也需要触发下一个事件
                            EventStateManager.clearEventAndTriggerNext();
                        } else {
                            player.gold -= cost;
                            saveData();
                            playerLoadStats();
                            safePlaySFX(sfxConfirm);
                            cursedTotem(curseLvl);
                            // cursedTotem不显示模态窗口，需要手动触发下一个事件
                            EventStateManager.clearEventAndTriggerNext();
                        }
                        
                        // 确保战斗界面已关闭
                        const combatPanel = document.querySelector('#combatPanel');
                        if (combatPanel && combatPanel.style.display !== 'none') {
                            combatPanel.style.display = 'none';
                        }
                        
                        // 确保页面亮度恢复
                        const dimDungeon = document.querySelector('#dungeon-main');
                        if (dimDungeon && dimDungeon.style.filter !== 'brightness(100%)') {
                            dimDungeon.style.filter = 'brightness(100%)';
                        }
                    });
                    handleEventChoice("#choice2", () => {
                        ignoreEvent();
                    });
                } else {
                    nothingEvent();
                    // nothing事件后需要自动触发下一个事件
                    setTimeout(() => {
                        if (dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
                            EventStateManager.triggerNextEvent();
                        }
                    }, 2000);
                }
                break;
            case "monarch":
                eventRoll = randomizeNum(1, 7);
                if (eventRoll == 1) {
                    EventStateManager.startEvent(); // 使用状态管理器开始事件
                    choices = `
                            <div class="decision-panel">
                                <button id="choice1">进入</button>
                                <button id="choice2">忽略</button>
                            </div>`;
                    addDungeonLog(`<span class="Heirloom">你发现了一个空间扩张异常。里面似乎有强大的存在正在休眠。</span>`, choices);
                    handleEventChoice("#choice1", () => {
                        safePlaySFX(sfxConfirm);
                        specialBossBattle();
                    });
                    handleEventChoice("#choice2", () => {
                        safePlaySFX(sfxDecline);
                        ignoreEvent();
                    });
                } else {
                    nothingEvent();
                    // nothing事件后需要自动触发下一个事件
                    setTimeout(() => {
                        if (dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
                            EventStateManager.triggerNextEvent();
                        }
                    }, 2000);
                }
                break;
        }
    }

// 简化的事件选择处理函数 - 使用状态管理器
const handleEventChoice = (choiceId, handler) => {
    setTimeout(() => {
        const element = document.querySelector(choiceId);
        if (element && !element.hasAttribute('data-bound')) {
            element.setAttribute('data-bound', 'true');
            element.onclick = function() {
                // 立即清除所有事件选择按钮
                const decisionPanel = document.querySelector('.decision-panel');
                if (decisionPanel) {
                    decisionPanel.remove();
                }
                
                // 使用状态管理器完成选择
                EventStateManager.completeChoice(handler);
            };
        }
    }, 50);
};

// ========= Dungeon Choice Events ==========
// Starts the battle
const engageBattle = () => {
    console.log('开始战斗事件处理...');
    stopResting(); // 停止休息血量恢复
    EventStateManager.enterCombat(); // 使用状态管理器进入战斗
    showCombatInfo();
    startCombat('battleMain');
    addCombatLog(`你遇到了 ${enemy.name}。`);
    updateDungeonLog();
}

// Mimic encounter
const mimicBattle = (type) => {
    console.log('开始Mimic战斗事件处理...');
    stopResting(); // 停止休息血量恢复
    EventStateManager.enterCombat(); // 使用状态管理器进入战斗
    generateRandomEnemy(type);
    showCombatInfo();
    startCombat('battleMain');
    addCombatLog(`你遇到了 ${enemy.name}。`);
    addDungeonLog(`你遇到了 ${enemy.name}。`);
}

// Guardian boss fight
const guardianBattle = () => {
    console.log('开始守护者战斗事件处理...');
    stopResting(); // 停止休息血量恢复
    EventStateManager.enterCombat(); // 使用状态管理器进入战斗
    incrementRoom();
    generateRandomEnemy("guardian");
    showCombatInfo();
    startCombat('battleGuardian');
    addCombatLog(`星区守护者 ${enemy.name} 正在阻挡你的去路。`);
    addDungeonLog("你移动到了下一个星区。");
}

// Guardian boss fight
const specialBossBattle = () => {
    console.log('开始特殊Boss战斗事件处理...');
    stopResting(); // 停止休息血量恢复
    EventStateManager.enterCombat(); // 使用状态管理器进入战斗
    generateRandomEnemy("sboss");
    showCombatInfo();
    startCombat('battleBoss');
    addCombatLog(`空间异常体 ${enemy.name} 被激活了。`);
    addDungeonLog(`空间异常体 ${enemy.name} 被激活了。`);
}

// Flee from the monster
const fleeBattle = () => {
    let eventRoll = randomizeNum(1, 2);
    if (eventRoll == 1) {
        safePlaySFX(sfxConfirm);
        addDungeonLog(`你设法逃跑了。`);
        // 确保玩家不在战斗状态（虽然此时应该还没进入战斗）
        player.inCombat = false;
        
        // 确保清除任何可能残留的战斗UI
        const combatPanel = document.querySelector('#combatPanel');
        if (combatPanel && combatPanel.style.display !== 'none') {
            combatPanel.style.display = 'none';
        }
        
        // 逃跑成功，触发下一个事件
        EventStateManager.clearEventAndTriggerNext();
    } else {
        safePlaySFX(sfxDecline);
        stopResting(); // 停止休息血量恢复
        addDungeonLog(`你逃跑失败！`);
        
        // 逃跑失败，进入战斗
        showCombatInfo();
        startCombat('battleMain');
        addCombatLog(`你遇到了 ${enemy.name}。`);
        addCombatLog(`你逃跑失败！`);
        
        // 使用状态管理器进入战斗状态
        EventStateManager.enterCombat();
    }
}

// Chest event randomizer
const chestEvent = () => {
    safePlaySFX(sfxConfirm);
    let eventRoll = randomizeNum(1, 4);
    if (eventRoll == 1) {
        mimicBattle("chest");
    } else if (eventRoll == 2) {
        if (dungeon.progress.floor == 1) {
            goldDrop();
            // 金币掉落会显示双倍弹窗，状态会在弹窗关闭时处理
        } else {
            createEquipmentPrint("dungeon");
            // createEquipmentPrint不显示模态窗口，需要手动触发下一个事件
            EventStateManager.clearEventAndTriggerNext();
        }
    } else if (eventRoll == 3) {
        goldDrop();
        // 金币掉落会显示双倍弹窗，状态会在弹窗关闭时处理
    } else {
        addDungeonLog("能量箱已消耗完毕。");
        // 这个分支没有显示模态窗口，需要手动触发下一个事件
        EventStateManager.clearEventAndTriggerNext();
    }
}

// Calculates Gold Drop
const goldDrop = () => {
    safePlaySFX(sfxSell);
    let goldValue = Math.max(randomizeNum(50, 500) * safeNumber(dungeon.progress.floor, 1), 50);
    addDungeonLog(`你发现了 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(goldValue)}。`);
    
    // 显示双倍金币选项
    showDoubleGoldOptions(goldValue);
}

// Non choices dungeon event messages
const nothingEvent = () => {
    let eventRoll = randomizeNum(1, 12);
    let message;
    if (eventRoll == 1) {
        message = "你扫描了周围区域，但传感器没有检测到任何异常。";
    } else if (eventRoll == 2) {
        message = "你发现了一个空的能量箱。";
    } else if (eventRoll == 3) {
        message = "你发现了一具机械残骸，看起来已经停机很久了。";
    } else if (eventRoll == 4) {
        message = "你发现了一个失效的探索者动力外骨骼。";
    } else if (eventRoll == 5) {
        message = "这个区域的能量读数为零，完全空旷。";
    } else if (eventRoll == 6) {
        message = "你检测到了微弱的能量波动，但很快就消失了。";
    } else if (eventRoll == 7) {
        message = "你发现了一些散落的金属碎片和烧焦的电路板。";
    } else if (eventRoll == 8) {
        message = "雷达显示前方有异常，但抵达后发现只是一些空的储物舱。";
    } else if (eventRoll == 9) {
        message = "你发现了一个损坏的数据终端，屏幕闪烁着错误信息。";
    } else if (eventRoll == 10) {
        message = "这里有一个废弃的临时营地，设备已经完全断电。";
    } else if (eventRoll == 11) {
        message = "你发现了一些深空探索者留下的装备痕迹，但人已经不知去向。";
    } else {
        message = "传感器检测到了异常的量子波动，但现在已经平静下来。";
    }
    addDungeonLog(message);
}

// Random stat buff
const statBlessing = () => {
    safePlaySFX(sfxBuff);
    let stats = ["hp", "atk", "def", "atkSpd", "vamp", "critRate", "critDmg"];
    let buff = stats[Math.floor(Math.random() * stats.length)];
    let value;
    switch (buff) {
        case "hp":
            value = 10;
            player.bonusStats.hp += value;
            break;
        case "atk":
            value = 8;
            player.bonusStats.atk += value;
            break;
        case "def":
            value = 8;
            player.bonusStats.def += value;
            break;
        case "atkSpd":
            value = 3;
            player.bonusStats.atkSpd += value;
            break;
        case "vamp":
            value = 0.5;
            player.bonusStats.vamp += value;
            break;
        case "critRate":
            value = 1;
            player.bonusStats.critRate += value;
            break;
        case "critDmg":
            value = 6;
            player.bonusStats.critDmg += value;
            break;
    }
    const buffNames = {
        "hp": "装甲完整度",
        "atk": "武器输出",
        "def": "护盾强度",
        "atkSpd": "反应速度",
        "vamp": "纳米修复",
        "critRate": "弱点扫描",
        "critDmg": "爆击倍率"
    };
    addDungeonLog(`系统升级成功！${buffNames[buff]}提升 ${value}%。 (系统强化.Lv${player.blessing} > Lv${player.blessing + 1})`);
    blessingUp();
    playerLoadStats();
    saveData();
}

// Cursed totem offering
const cursedTotem = (curseLvl) => {
    safePlaySFX(sfxBuff);
    dungeon.settings.enemyScaling += 0.1;
    addDungeonLog(`干扰器启动！敌方单位增强，但收益也相应提高。 (干扰核心.Lv${curseLvl} > Lv${curseLvl + 1})`);
    saveData();
}

// Ignore event and proceed exploring
const ignoreEvent = () => {
    safePlaySFX(sfxConfirm);
    addDungeonLog("你忽略了它，决定继续前进。");
    // 清理事件状态并触发下一个事件
    EventStateManager.clearEventAndTriggerNext();
}

// Increase room or floor accordingly
const incrementRoom = () => {
    dungeon.progress.room++;
    dungeon.action = 0;
    loadDungeonProgress();
}

// Increases player total blessing
const blessingUp = () => {
    blessingValidation();
    player.blessing++;
}

// Validates whether blessing exists or not
const blessingValidation = () => {
    if (player.blessing == undefined || isNaN(player.blessing)) {
        player.blessing = 1;
    } else {
        player.blessing = Number(player.blessing);
    }
}

// ========= Dungeon Backlog ==========
// Displays every dungeon activity
const updateDungeonLog = (choices) => {
    let dungeonLog = document.querySelector("#dungeonLog");
    dungeonLog.innerHTML = "";

    // Display the recent 50 dungeon logs
    for (let message of dungeon.backlog.slice(-50)) {
        let logElement = document.createElement("p");
        logElement.innerHTML = message;
        dungeonLog.appendChild(logElement);
    }

    // If the event has choices, display it
    if (typeof choices !== 'undefined') {
        let eventChoices = document.createElement("div");
        eventChoices.innerHTML = choices;
        dungeonLog.appendChild(eventChoices);
    }

    dungeonLog.scrollTop = dungeonLog.scrollHeight;
}

// Add a log to the dungeon backlog
const addDungeonLog = (message, choices) => {
    dungeon.backlog.push(message);
    updateDungeonLog(choices);
}

// Evaluate a dungeon difficulty
const evaluateDungeon = () => {
    let base = 500;
    // Work in Progress
}

// 显示双倍金币选项弹窗
const showDoubleGoldOptions = (baseGold) => {
    safePlaySFX(sfxEncounter);
    
    let modalContent = `
    <div class="content combat">
        <div class="modal-head">
            <h3><i class="fas fa-coins"></i> 信用点发现</h3>
        </div>
        <div class="modal-body">
            <p>你发现了 <span class="highlight">${nFormatter(baseGold)}</span> 信用点！</p>
            <p>连接到量子广告网络可以激活纳米复制器，将信用点翻倍。</p>
            <p class="hint">观看广告（15-30秒）获得双倍奖励</p>
        </div>
        <div class="modal-buttons">
            <button onclick="watchAdForDoubleGold(${baseGold})">
                <i class="fas fa-tv"></i> 激活复制器
            </button>
            <button onclick="collectNormalGold(${baseGold})">
                <i class="fas fa-coins"></i> 收集信用点
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = modalContent;
    document.querySelector("#defaultModal").style.display = "flex";
}

// 观看广告获得双倍金币
const watchAdForDoubleGold = (baseGold) => {
    safePlaySFX(sfxBuff);
    
    // 广告接口预留位置
    // TODO: 在这里调用广告SDK
    // window.showRewardedAd(() => {
    //     // 广告观看成功回调
    //     grantDoubleGold(baseGold);
    // }, () => {
    //     // 广告观看失败回调
    //     showAdError();
    // });
    
    // 临时：直接给予双倍奖励
    grantDoubleGold(baseGold);
}

// 发放双倍金币奖励
const grantDoubleGold = (baseGold) => {
    const doubleGold = baseGold * 2;
    player.gold += doubleGold;
    playerLoadStats();
    
    addDungeonLog(`纳米复制器激活成功！获得 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(doubleGold)}。`);
    
    document.querySelector("#defaultModal").style.display = "none";
    EventStateManager.clearEventAndTriggerNext();
}

// 收集普通金币
const collectNormalGold = (baseGold) => {
    player.gold += baseGold;
    playerLoadStats();
    
    document.querySelector("#defaultModal").style.display = "none";
    EventStateManager.clearEventAndTriggerNext();
}

// 触发胜利条件
const triggerVictory = () => {
    if (typeof sfxBuff !== 'undefined' && sfxBuff.play) {
        safePlaySFX(sfxBuff);
    }
    
    // 停止所有游戏循环
    clearInterval(dungeonTimer);
    clearInterval(playTimer);
    dungeon.status.exploring = false;
    dungeon.status.paused = true;
    
    // 记录通关统计
    if (!player.victoryStats) {
        player.victoryStats = {
            completions: 0,
            fastestTime: null,
            totalKills: 0,
            totalPlaytime: 0
        };
    }
    
    player.victoryStats.completions++;
    player.victoryStats.totalKills += dungeon.statistics.kills;
    player.victoryStats.totalPlaytime += dungeon.statistics.runtime;
    
    if (!player.victoryStats.fastestTime || dungeon.statistics.runtime < player.victoryStats.fastestTime) {
        player.victoryStats.fastestTime = dungeon.statistics.runtime;
    }
    
    saveData();
    showVictoryScreen();
}

// 显示胜利界面
const showVictoryScreen = () => {
    let runTime = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
    let totalPlayTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
    let fastestTime = player.victoryStats.fastestTime ? 
        new Date(player.victoryStats.fastestTime * 1000).toISOString().slice(11, 19) : "N/A";
    
    const victoryModal = `
    <div class="content victory-screen">
        <div class="victory-header">
            <h2><i class="fas fa-trophy"></i> 深空探索完成！</h2>
            <p class="victory-subtitle">你成功探索了全部100个星区！</p>
        </div>
        
        <div class="victory-content">
            <div class="victory-stats">
            <div class="stat-section">
                <h3><i class="fas fa-rocket"></i> 本次探索统计</h3>
                <div class="stat-grid">
                    <div class="stat-item">
                        <span class="stat-label">探索时间</span>
                        <span class="stat-value">${runTime}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">击败敌人</span>
                        <span class="stat-value">${nFormatter(dungeon.statistics.kills)}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">最终等级</span>
                        <span class="stat-value">Lv.${player.lvl}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">系统强化</span>
                        <span class="stat-value">Lv.${player.blessing || 1}</span>
                    </div>
                </div>
            </div>
            
            <div class="stat-section">
                <h3><i class="fas fa-chart-line"></i> 总体成就</h3>
                <div class="stat-grid">
                    <div class="stat-item">
                        <span class="stat-label">完成次数</span>
                        <span class="stat-value">${player.victoryStats.completions}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">最快记录</span>
                        <span class="stat-value">${fastestTime}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">总击杀数</span>
                        <span class="stat-value">${nFormatter(player.kills)}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">总游戏时间</span>
                        <span class="stat-value">${totalPlayTime}</span>
                    </div>
                </div>
            </div>
        </div>
        </div>
        
        <div class="victory-actions">
            <button id="restart-journey" class="victory-btn primary">
                <i class="fas fa-redo"></i> 重新开始探索
            </button>
            <button id="view-statistics" class="victory-btn secondary">
                <i class="fas fa-chart-bar"></i> 查看详细统计
            </button>
            <button id="return-home" class="victory-btn secondary">
                <i class="fas fa-home"></i> 返回主菜单
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = victoryModal;
    document.querySelector("#defaultModal").style.display = "flex";
    document.querySelector('#dungeon-main').style.filter = "brightness(50%)";
    
    // 胜利界面按钮事件
    document.querySelector("#restart-journey").onclick = function() {
        safePlaySFX(sfxConfirm);
        progressReset();
        allocationPopup();
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#dungeon-main').style.filter = "brightness(100%)";
    };
    
    document.querySelector("#view-statistics").onclick = function() {
        safePlaySFX(sfxOpen);
        showDetailedStatistics();
    };
    
    document.querySelector("#return-home").onclick = function() {
        safePlaySFX(sfxConfirm);
        MusicManager.stopBGM();
        document.querySelector('#dungeon-main').style.display = "none";
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#dungeon-main').style.filter = "brightness(100%)";
        runLoad("title-screen", "flex");
        stopResting(); // 清理休息计时器
        progressReset();
    };
}

// 显示详细统计面板
const showDetailedStatistics = () => {
    let totalPlayTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
    let fastestTime = player.victoryStats?.fastestTime ? 
        new Date(player.victoryStats.fastestTime * 1000).toISOString().slice(11, 19) : "未完成";
    let avgKillsPerRun = player.victoryStats?.completions > 0 ? 
        Math.round(player.victoryStats.totalKills / player.victoryStats.completions) : 0;
    
    const statsModal = `
    <div class="content statistics-mobile">
        <div class="stats-header">
            <h3><i class="fas fa-chart-bar"></i> 探索者档案</h3>
            <button id="close-stats" class="close-btn"><i class="fa fa-xmark"></i></button>
        </div>
        
        <div class="stats-body">
            <div class="stats-section">
                <h4><i class="fas fa-trophy"></i> 成就进度</h4>
                <div class="achievement-grid">
                    <div class="achievement-card ${player.victoryStats?.completions > 0 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-star"></i>
                        <span class="achievement-name">首次通关</span>
                        <span class="achievement-progress">${player.victoryStats?.completions > 0 ? '已完成' : '未完成'}</span>
                    </div>
                    <div class="achievement-card ${player.kills >= 1000 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-skull"></i>
                        <span class="achievement-name">千人斩</span>
                        <span class="achievement-progress">${player.kills >= 1000 ? '已完成' : Math.round(player.kills / 10) + '%'}</span>
                    </div>
                    <div class="achievement-card ${player.victoryStats?.fastestTime && player.victoryStats.fastestTime <= 3600 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-bolt"></i>
                        <span class="achievement-name">极速通关</span>
                        <span class="achievement-progress">${player.victoryStats?.fastestTime && player.victoryStats.fastestTime <= 3600 ? '已完成' : '未完成'}</span>
                    </div>
                </div>
            </div>
            
            <div class="stats-section">
                <h4><i class="fas fa-chart-line"></i> 数据统计</h4>
                <div class="stats-grid">
                    <div class="stat-card">
                        <i class="fas fa-flag-checkered"></i>
                        <span class="stat-value">${player.victoryStats?.completions || 0}</span>
                        <span class="stat-label">通关次数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-stopwatch"></i>
                        <span class="stat-value">${fastestTime}</span>
                        <span class="stat-label">最快记录</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-crosshairs"></i>
                        <span class="stat-value">${nFormatter(player.kills)}</span>
                        <span class="stat-label">击杀总数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-skull-crossbones"></i>
                        <span class="stat-value">${nFormatter(player.deaths)}</span>
                        <span class="stat-label">死亡次数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-hourglass-half"></i>
                        <span class="stat-value">${totalPlayTime}</span>
                        <span class="stat-label">游戏时长</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-percentage"></i>
                        <span class="stat-value">${player.deaths > 0 ? (player.kills / player.deaths).toFixed(2) : player.kills}</span>
                        <span class="stat-label">K/D 比率</span>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="stats-footer">
            <button id="back-to-victory" class="action-btn">
                <i class="fas fa-arrow-left"></i> 返回
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = statsModal;
    
    document.querySelector("#close-stats").onclick = function() {
        safePlaySFX(sfxDecline);
        showVictoryScreen();
    };
    
    document.querySelector("#back-to-victory").onclick = function() {
        safePlaySFX(sfxDecline);
        showVictoryScreen();
    };
}

// ===== 休息血量恢复系统 =====
const startResting = () => {
    // 清除已存在的休息计时器
    if (restTimer) {
        clearInterval(restTimer);
    }
    
    // 开始血量恢复计时器（每秒恢复1%最大血量）
    restTimer = setInterval(() => {
        if (player && player.stats && !player.inCombat && dungeon.status.paused) {
            const healAmount = Math.round(player.stats.hpMax * 0.01); // 1%最大血量
            
            if (player.stats.hp < player.stats.hpMax) {
                player.stats.hp += healAmount;
                
                // 确保血量不超过上限
                if (player.stats.hp > player.stats.hpMax) {
                    player.stats.hp = player.stats.hpMax;
                }
                
                // 更新界面显示
                playerLoadStats();
                saveData();
            }
        }
    }, 1000); // 每1000毫秒（1秒）执行一次
};

const stopResting = () => {
    if (restTimer) {
        clearInterval(restTimer);
        restTimer = null;
    }
};

// 显示空的统计面板（用于主菜单）
const showEmptyStatistics = () => {
    const player = JSON.parse(localStorage.getItem("playerData"));
    let totalPlayTime = player ? new Date(player.playtime * 1000).toISOString().slice(11, 19) : "00:00:00";
    
    const statsModal = `
    <div class="content statistics-screen">
        <div class="content-head">
            <h3><i class="fas fa-chart-bar"></i> 探索者档案</h3>
            <p id="close-stats"><i class="fa fa-xmark"></i></p>
        </div>
        
        <div class="stats-container">
            <div class="stats-category">
                <h4><i class="fas fa-trophy"></i> 成就进度</h4>
                <div class="achievement-list">
                    <div class="achievement locked">
                        <i class="fas fa-star"></i>
                        <span>首次通关</span>
                        <span class="achievement-status">×</span>
                    </div>
                    <div class="achievement locked">
                        <i class="fas fa-skull"></i>
                        <span>击杀1000敌人</span>
                        <span class="achievement-status">${player ? Math.min(player.kills, 999) : 0}/1000</span>
                    </div>
                    <div class="achievement locked">
                        <i class="fas fa-bolt"></i>
                        <span>1小时通关</span>
                        <span class="achievement-status">×</span>
                    </div>
                </div>
            </div>
            
            <div class="stats-category">
                <h4><i class="fas fa-chart-line"></i> 统计数据</h4>
                <div class="detailed-stats">
                    <div class="stat-row">
                        <span>通关次数</span>
                        <span>0</span>
                    </div>
                    <div class="stat-row">
                        <span>最快记录</span>
                        <span>未完成</span>
                    </div>
                    <div class="stat-row">
                        <span>击杀/死亡</span>
                        <span>${player ? nFormatter(player.kills) : 0}/${player ? nFormatter(player.deaths) : 0}</span>
                    </div>
                    <div class="stat-row">
                        <span>游戏时长</span>
                        <span>${totalPlayTime}</span>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="stats-actions">
            <button id="close-empty-stats" class="stats-btn">
                <i class="fas fa-times"></i> 关闭
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = statsModal;
    document.querySelector("#defaultModal").style.display = "flex";
    
    document.querySelector("#close-stats").onclick = function() {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#title-screen').style.filter = "brightness(100%)";
    };
    
    document.querySelector("#close-empty-stats").onclick = function() {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#title-screen').style.filter = "brightness(100%)";
    };
}