// ========== 独立宝箱系统 ==========

// 宝箱系统数据结构
const independentChestSystem = {
    openedChests: [], // 已开启的宝箱ID列表
    lastRefreshTime: Date.now(),
    refreshCooldown: 0.0001 * 60 * 60 * 1000, // 2小时
    isRefreshing: false,
    currentBatchRarities: [] // 当前批次的稀有度分配
};

// 宝箱稀有度配置（每批次包含所有6个等级）
const chestRarities = [
    { rarity: "标准级", name: "标准级", color: "#9E9E9E" },
    { rarity: "改进级", name: "改进级", color: "#4CAF50" },
    { rarity: "军用级", name: "军用级", color: "#2196F3" },
    { rarity: "实验级", name: "实验级", color: "#9C27B0" },
    { rarity: "原型级", name: "原型级", color: "#FF9800" },
    { rarity: "遗产级", name: "遗产级", color: "#F44336" }
];

// 初始化独立宝箱系统
const initIndependentChestSystem = () => {
    loadIndependentChestData();
    
    // 如果没有稀有度分配，生成新的
    if (!independentChestSystem.currentBatchRarities || independentChestSystem.currentBatchRarities.length !== 6) {
        independentChestSystem.currentBatchRarities = shuffleArray([...chestRarities]);
        saveIndependentChestData();
    }
    
    checkAutoRefresh();
};

// 加载宝箱数据
const loadIndependentChestData = () => {
    const savedData = localStorage.getItem('independentChestSystem');
    if (savedData) {
        const parsed = JSON.parse(savedData);
        Object.assign(independentChestSystem, parsed);
    }
};

// 保存宝箱数据
const saveIndependentChestData = () => {
    localStorage.setItem('independentChestSystem', JSON.stringify(independentChestSystem));
};

// 检查自动刷新
const checkAutoRefresh = () => {
    const now = Date.now();
    const timePassed = now - independentChestSystem.lastRefreshTime;
    
    if (timePassed >= independentChestSystem.refreshCooldown) {
        refreshIndependentChests();
    }
};

// 刷新宝箱
const refreshIndependentChests = () => {
    independentChestSystem.openedChests = [];
    independentChestSystem.lastRefreshTime = Date.now();
    independentChestSystem.isRefreshing = false;
    
    // 生成新的稀有度分配（每批次包含所有6个等级，随机分配到6个槽位）
    independentChestSystem.currentBatchRarities = shuffleArray([...chestRarities]);
    
    saveIndependentChestData();
    
    // 清除localStorage中的旧宝箱数据
    localStorage.removeItem('chestData');
};

// 数组随机打乱函数
const shuffleArray = (array) => {
    const newArray = [...array];
    for (let i = newArray.length - 1; i > 0; i--) {
        const j = Math.floor(Math.random() * (i + 1));
        [newArray[i], newArray[j]] = [newArray[j], newArray[i]];
    }
    return newArray;
};

// 获取刷新倒计时
const getIndependentChestRefreshTimeRemaining = () => {
    const now = Date.now();
    const timePassed = now - independentChestSystem.lastRefreshTime;
    const timeRemaining = independentChestSystem.refreshCooldown - timePassed;
    
    if (timeRemaining <= 0) {
        return { totalMs: 0, minutes: 0, seconds: 0 };
    }
    
    const minutes = Math.floor(timeRemaining / (60 * 1000));
    const seconds = Math.floor((timeRemaining % (60 * 1000)) / 1000);
    
    return { totalMs: timeRemaining, minutes, seconds };
};

// 获取指定槽位的稀有度（从预分配的稀有度中获取）
const getChestRarityForSlot = (slotNumber) => {
    // 确保有预分配的稀有度
    if (!independentChestSystem.currentBatchRarities || independentChestSystem.currentBatchRarities.length !== 6) {
        // 如果没有预分配，重新生成
        independentChestSystem.currentBatchRarities = shuffleArray([...chestRarities]);
        saveIndependentChestData();
    }
    
    // 返回对应槽位的稀有度（槽位1-6对应数组索引0-5）
    return independentChestSystem.currentBatchRarities[slotNumber - 1] || chestRarities[0];
};

// 辅助函数 - 如果主游戏函数不存在，提供备用实现
const safeRandomizeNum = (min, max) => {
    if (typeof randomizeNum === 'function') {
        return randomizeNum(min, max);
    }
    return Math.floor(Math.random() * (max - min + 1)) + min;
};

const safeRandomizeDecimal = (min, max) => {
    if (typeof randomizeDecimal === 'function') {
        return randomizeDecimal(min, max);
    }
    return Math.random() * (max - min) + min;
};

const safeSafeNumber = (value, defaultValue) => {
    if (typeof safeNumber === 'function') {
        return safeNumber(value, defaultValue);
    }
    return isNaN(value) || value === null || value === undefined ? defaultValue : value;
};

// 生成指定稀有度的装备
const generateChestEquipment = (rarity, slotNumber) => {
    // 创建新的装备对象，不使用createEquipment避免重复保存
    const equipment = {
        category: null,
        attribute: null,
        type: null,
        rarity: rarity, // 直接设置指定的稀有度
        lvl: null,
        tier: null,
        value: null,
        stats: [],
    };
    
    // 生成装备属性
    const equipmentAttributes = ["伤害", "防御"];
    equipment.attribute = equipmentAttributes[Math.floor(Math.random() * equipmentAttributes.length)];
    
    // 生成装备名称和类型
    if (equipment.attribute == "伤害") {
        const equipmentCategories = ["等离子刀", "量子剑", "电磁锤", "激光切割器", "能量链剑", "粒子束刀"];
        equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        equipment.type = "武器";
    } else if (equipment.attribute == "防御") {
        const equipmentTypes = ["动力装甲", "能量盾", "防护头盔"];
        equipment.type = equipmentTypes[Math.floor(Math.random() * equipmentTypes.length)];
        if (equipment.type == "动力装甲") {
            const equipmentCategories = ["重型装甲", "战术装甲", "隐形装甲"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        } else if (equipment.type == "能量盾") {
            const equipmentCategories = ["量子盾坎", "电磁护盾", "纳米盾牌"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        } else if (equipment.type == "防护头盔") {
            const equipmentCategories = ["战术头盔", "增强头盔"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        }
    }
        
    // 设置稀有度对应的属性数量
    let loopCount;
    switch (rarity) {
        case "标准级":
            loopCount = 2;
            break;
        case "改进级":
            loopCount = 3;
            break;
        case "军用级":
            loopCount = 4;
            break;
        case "实验级":
            loopCount = 5;
            break;
        case "原型级":
            loopCount = 6;
            break;
        case "遗产级":
            loopCount = 8;
            break;
        default:
            loopCount = 2;
    }
        
        // 重新生成装备属性（复制自createEquipment函数的逻辑）
        const physicalStats = ["atk", "atkSpd", "vamp", "critRate", "critDmg"];
        const damageyStats = ["atk", "atk", "vamp", "critRate", "critDmg", "critDmg"];
        const speedyStats = ["atkSpd", "atkSpd", "atk", "vamp", "critRate", "critRate", "critDmg"];
        const defenseStats = ["hp", "hp", "def", "def", "atk"];
        const dmgDefStats = ["hp", "def", "atk", "atk", "critRate", "critDmg"];
        let statTypes;
        
        if (equipment.attribute == "伤害") {
            if (equipment.category == "斗" || equipment.category == "镰刀") {
                statTypes = damageyStats;
            } else if (equipment.category == "匕首" || equipment.category == "链搄") {
                statTypes = speedyStats;
            } else if (equipment.category == "锤") {
                statTypes = dmgDefStats;
            } else {
                statTypes = physicalStats;
            }
        } else if (equipment.attribute == "防御") {
            statTypes = defenseStats;
        } else {
            // 默认使用物理属性，避免statTypes为undefined
            statTypes = physicalStats;
            console.warn('Unknown equipment attribute:', equipment.attribute);
        }
        
        let equipmentValue = 0;
        
        // 确保statTypes已定义且不为空
        if (!statTypes || statTypes.length === 0) {
            console.error('statTypes is undefined or empty, using default');
            statTypes = physicalStats;
        }
        
        // 记录已使用的属性类型，避免重复
        const usedStats = {};
        
        for (let i = 0; i < loopCount; i++) {
            // 获取未使用的属性类型
            const availableStats = statTypes.filter(stat => !usedStats[stat] || 
                // 某些属性允许出现2次（如atk, hp, def）
                (usedStats[stat] < 2 && ['atk', 'hp', 'def'].includes(stat))
            );
            
            // 如果没有可用属性，重置已使用列表（极少情况）
            let statType;
            if (availableStats.length === 0) {
                console.warn('No available stats, resetting used stats');
                Object.keys(usedStats).forEach(key => delete usedStats[key]);
                // 重新选择属性
                statType = statTypes[Math.floor(Math.random() * statTypes.length)];
                usedStats[statType] = 1;
            } else {
                statType = availableStats[Math.floor(Math.random() * availableStats.length)];
                usedStats[statType] = (usedStats[statType] || 0) + 1;
            }
            
            let statValue = 0;

            // Stat scaling for equipment
            const maxLvl = (dungeon && dungeon.progress) ? 
                dungeon.progress.floor * dungeon.settings.enemyLvlGap + (dungeon.settings.enemyBaseLvl - 1) : 
                (player ? player.lvl + 5 : 10);
            const minLvl = maxLvl - ((dungeon && dungeon.settings) ? dungeon.settings.enemyLvlGap - 1 : 5);
            
            // Set equipment level with Lv.100 cap
            equipment.lvl = safeRandomizeNum(minLvl, maxLvl);
            if (equipment.lvl > 100) {
                equipment.lvl = 100;
            }
            
            // Set stat scaling and equipment tier
            let enemyScaling = (dungeon && dungeon.settings) ? dungeon.settings.enemyScaling : 1.5;
            if (enemyScaling > 2) {
                enemyScaling = 2;
            }
            let statMultiplier = safeSafeNumber((enemyScaling - 1) * equipment.lvl, 0);
            equipment.tier = Math.max(Math.round((enemyScaling - 1) * 10), 1);
            
            // 使用安全的缩放计算，确保有最小值
            let hpScaling = Math.max((40 * safeRandomizeDecimal(0.5, 1.5)) + ((40 * safeRandomizeDecimal(0.5, 1.5)) * statMultiplier), 20);
            let atkDefScaling = Math.max((16 * safeRandomizeDecimal(0.5, 1.5)) + ((16 * safeRandomizeDecimal(0.5, 1.5)) * statMultiplier), 8);
            let cdAtkSpdScaling = Math.max((3 * safeRandomizeDecimal(0.5, 1.5)) + ((3 * safeRandomizeDecimal(0.5, 1.5)) * statMultiplier), 1.5);
            let crVampScaling = Math.max((2 * safeRandomizeDecimal(0.5, 1.5)) + ((2 * safeRandomizeDecimal(0.5, 1.5)) * statMultiplier), 1);

            // Set randomized numbers to respective stats and increment sell value
            if (statType === "hp") {
                statValue = safeRandomizeNum(hpScaling * 0.5, hpScaling);
                equipmentValue += statValue;
            } else if (statType === "atk") {
                statValue = safeRandomizeNum(atkDefScaling * 0.5, atkDefScaling);
                equipmentValue += statValue * 2.5;
            } else if (statType === "def") {
                statValue = safeRandomizeNum(atkDefScaling * 0.5, atkDefScaling);
                equipmentValue += statValue * 2.5;
            } else if (statType === "atkSpd") {
                statValue = safeRandomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
                if (statValue > 15) {
                    statValue = 15 * safeRandomizeDecimal(0.5, 1);
                    loopCount++;
                }
                equipmentValue += statValue * 8.33;
            } else if (statType === "vamp") {
                statValue = safeRandomizeDecimal(crVampScaling * 0.5, crVampScaling);
                if (statValue > 8) {
                    statValue = 8 * safeRandomizeDecimal(0.5, 1);
                    loopCount++;
                }
                equipmentValue += statValue * 12.5;
            } else if (statType === "critRate") {
                statValue = safeRandomizeDecimal(crVampScaling * 0.5, crVampScaling);
                if (statValue > 10) {
                    statValue = 10 * safeRandomizeDecimal(0.5, 1);
                    loopCount++;
                }
                equipmentValue += statValue * 12.5;
            } else if (statType === "critDmg") {
                statValue = safeRandomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
                if (statValue > 20) {
                    statValue = 20 * safeRandomizeDecimal(0.5, 1);
                    loopCount++;
                }
                equipmentValue += statValue * 4.17;
            }
            
            // 根据稀有度限制最大属性条目数
            if (equipment.rarity == "标准级" && loopCount > 3) {
                loopCount--;
            } else if (equipment.rarity == "改进级" && loopCount > 4) {
                loopCount--;
            } else if (equipment.rarity == "军用级" && loopCount > 5) {
                loopCount--;
            } else if (equipment.rarity == "实验级" && loopCount > 6) {
                loopCount--;
            } else if (equipment.rarity == "原型级" && loopCount > 7) {
                loopCount--;
            } else if (equipment.rarity == "遗产级" && loopCount > 9) {
                loopCount--;
            }

            // 检查属性是否已存在
            let statExists = false;
            for (let j = 0; j < equipment.stats.length; j++) {
                if (Object.keys(equipment.stats[j])[0] == statType) {
                    statExists = true;
                    break;
                }
            }
            
            // 如果属性已存在，合并数值
            if (statExists) {
                for (let j = 0; j < equipment.stats.length; j++) {
                    if (Object.keys(equipment.stats[j])[0] == statType) {
                        equipment.stats[j][statType] += statValue;
                        break;
                    }
                }
            }
            // 如果属性不存在，添加新属性
            else {
                let stat = {};
                stat[statType] = statValue;
                equipment.stats.push(stat);
            }
        }
        
        // Set equipment value
        equipment.value = Math.round(equipmentValue);
        
        // 确保装备至少有最小价值
        const minValues = {
            "标准级": 50,
            "改进级": 250,
            "军用级": 1000,
            "实验级": 3000,
            "原型级": 8000,
            "遗产级": 20000
        };
        
        if (equipment.value < minValues[equipment.rarity]) {
            equipment.value = minValues[equipment.rarity] || 50;
        }
        
        // 生成装备图标
        if (typeof equipmentIcon === 'function') {
            equipment.icon = equipmentIcon(equipment);
        }
        
        // 添加装备到玩家背包
        if (player && player.inventory && player.inventory.equipment) {
            player.inventory.equipment.push(JSON.stringify(equipment));
            
            // 保存游戏数据
            if (typeof saveData === 'function') {
                saveData();
            }
            
            // 更新显示
            if (typeof showInventory === 'function') {
                showInventory();
            }
            if (typeof showEquipment === 'function') {
                showEquipment();
            }
        }
        
        return equipment;
};

// 打开独立宝箱界面
const openIndependentChestInterface = () => {
    // 检查是否需要自动刷新
    checkAutoRefresh();
    
    const modal = document.createElement('div');
    modal.id = 'independentChestInterface';
    modal.className = 'modal-container';
    
    modal.innerHTML = `
        <div class="content independent-chest-content">
            <div class="independent-chest-header">
                <div class="header-left">
                    <div class="chest-title">
                        <i class="fas fa-gem chest-gem-icon"></i>
                        <span>量子宝箱</span>
                    </div>
                    <div class="chest-subtitle">神秘装备等你发现</div>
                </div>
                <div class="header-right">
                    <div class="chest-credits">
                        <i class="fas fa-coins"></i>
                        <span id="chest-player-gold">${typeof player !== 'undefined' ? (player.gold || 0) : 0}</span>
                    </div>
                    <button class="chest-close-btn" onclick="closeIndependentChestInterface()">
                        <i class="fas fa-times"></i>
                    </button>
                </div>
            </div>
            
            <div class="chest-status-bar">
                <div class="status-item">
                    <i class="fas fa-clock status-icon"></i>
                    <div class="status-info">
                        <div class="status-label">刷新倒计时</div>
                        <div class="status-value" id="independentChestTimerDisplay">加载中...</div>
                    </div>
                </div>
                <button class="quick-refresh-btn ${independentChestSystem.openedChests.length < 6 ? 'disabled' : ''}" 
                        onclick="showIndependentResetConfirm()"
                        ${independentChestSystem.openedChests.length < 6 ? 'title="请先开启所有宝箱"' : 'title="花费10,000信用点立即刷新"'}>
                    <i class="fas fa-bolt"></i>
                    <span class="refresh-text">立即刷新</span>
                    <div class="refresh-cost">10,000</div>
                </button>
            </div>
            
            <div class="chest-grid-container">
                <div class="grid-title">
                    <span class="grid-title-text">当前批次宝箱</span>
                    <div class="grid-subtitle">包含全部6种稀有度装备</div>
                </div>
                <div class="independent-chest-grid">
                    ${Array.from({length: 6}, (_, i) => createIndependentChestSlot(i + 1)).join('')}
                </div>
            </div>
            
            <div class="chest-help-section">
                <div class="help-item">
                    <i class="fas fa-play-circle help-icon"></i>
                    <span>观看广告开启宝箱</span>
                </div>
                <div class="help-item">
                    <i class="fas fa-gift help-icon"></i>
                    <span>每批包含全稀有度装备</span>
                </div>
                <div class="help-item">
                    <i class="fas fa-sync help-icon"></i>
                    <span>2小时自动刷新</span>
                </div>
            </div>
        </div>
    `;
    
    document.body.appendChild(modal);
    
    // 显示模态框并使用层级管理器
    modal.style.display = "flex";
    
    // 使用层级管理器设置z-index
    if (window.zIndexManager) {
        window.zIndexManager.pushModal(modal);
    }
    
    // 启动定时器更新
    startIndependentChestTimerUpdate();
    
    // 更新金币显示
    updateChestGoldDisplay();
    
    // 添加CSS样式（如果还没有）
    addIndependentChestStyles();
};

// 创建宝箱槽位
const createIndependentChestSlot = (slotNumber) => {
    const slotId = `chest-slot-${slotNumber}`;
    const isOpened = independentChestSystem.openedChests.includes(slotId);
    
    // 检查localStorage中是否有该槽位的数据
    const chestData = JSON.parse(localStorage.getItem('chestData') || '{}');
    const slotData = chestData[slotId];
    
    // 修复：如果有slotData且标记为opened，或者在openedChests数组中，都认为是已开启
    const isActuallyOpened = isOpened || (slotData && slotData.opened);
    
    if (isActuallyOpened && slotData) {
        // 显示已开启的宝箱结果
        return `
            <div class="chest-slot opened ${slotData.rarity}" data-slot="${slotNumber}" onclick="showChestEquipmentDetails('${slotId}')">
                <div class="chest-result">
                    <div class="chest-icon opened-chest">
                        ${getEquipmentIconForChest(slotData)}
                    </div>
                    <div class="chest-info">
                        <div class="rarity-name ${slotData.rarity}">${slotData.rarityName}</div>
                        <div class="equipment-name">${slotData.equipmentName}</div>
                        <div class="equipment-level">Lv.${slotData.equipmentLevel} T${slotData.equipmentTier || 1}</div>
                    </div>
                </div>
            </div>
        `;
    } else {
        // 显示未开启的神秘宝箱
        return `
            <div class="chest-slot mystery" data-slot="${slotNumber}" onclick="confirmOpenChest(${slotNumber})">
                <div class="chest-icon mystery-chest">
                    ${getChestIcon('mystery', slotNumber)}
                </div>
                <div class="chest-label">
                    <i class="fas fa-question"></i> 神秘宝箱
                </div>
            </div>
        `;
    }
};

// 获取装备图标（为宝箱使用）
const getEquipmentIconForChest = (slotData) => {
    // 如果equipmentIcon函数存在，使用它生成图标
    if (typeof equipmentIcon === 'function' && slotData.equipmentCategory && slotData.rarity) {
        const equipment = {
            category: slotData.equipmentCategory,
            rarity: slotData.rarity
        };
        return equipmentIcon(equipment);
    }
    
    // 如果没有equipmentIcon函数，返回基础SVG图标
    const rarityColors = {
        "标准级": { border: "#9E9E9E", fill: "#757575", glow: "#9E9E9E" },
        "改进级": { border: "#4CAF50", fill: "#66BB6A", glow: "#4CAF50" },
        "军用级": { border: "#2196F3", fill: "#42A5F5", glow: "#2196F3" },
        "实验级": { border: "#9C27B0", fill: "#AB47BC", glow: "#9C27B0" },
        "原型级": { border: "#FF9800", fill: "#FFA726", glow: "#FF9800" },
        "遗产级": { border: "#F44336", fill: "#EF5350", glow: "#F44336" }
    };
    
    const colors = rarityColors[slotData.rarity] || rarityColors["标准级"];
    
    // 通用装备图标
    return `
        <svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <defs>
                <radialGradient id="equipGlow-${slotData.rarity}" cx="50%" cy="50%" r="50%">
                    <stop offset="0%" style="stop-color:${colors.glow};stop-opacity:1" />
                    <stop offset="70%" style="stop-color:${colors.fill};stop-opacity:0.8" />
                    <stop offset="100%" style="stop-color:${colors.border};stop-opacity:0.3" />
                </radialGradient>
                <filter id="equipmentGlow-${slotData.rarity}">
                    <feGaussianBlur stdDeviation="3" result="coloredBlur"/>
                    <feMerge> 
                        <feMergeNode in="coloredBlur"/>
                        <feMergeNode in="SourceGraphic"/>
                    </feMerge>
                </filter>
            </defs>
            
            <!-- 装备外框 -->
            <rect x="20" y="20" width="60" height="60" rx="8" 
                  fill="url(#equipGlow-${slotData.rarity})" 
                  stroke="${colors.border}" 
                  stroke-width="2" 
                  filter="url(#equipmentGlow-${slotData.rarity})"/>
            
            <!-- 装备核心 -->
            <circle cx="50" cy="50" r="15" 
                    fill="${colors.glow}" 
                    opacity="0.8">
                <animate attributeName="r" values="15;18;15" dur="2s" repeatCount="indefinite"/>
                <animate attributeName="opacity" values="0.8;1;0.8" dur="2s" repeatCount="indefinite"/>
            </circle>
            
            <!-- 装备符号 -->
            <text x="50" y="58" text-anchor="middle" 
                  fill="#ffffff" 
                  font-size="20" 
                  font-family="monospace" 
                  opacity="0.9"></text>
        </svg>
    `;
};

// 获取宝箱图标
const getChestIcon = (type, slotNumber = 1) => {
    const uniqueId = `${type}-${slotNumber}`;
    
    if (type === 'mystery') {
        return `
            <svg viewBox="0 0 120 120" class="energy-chest-icon">
                <defs>
                    <!-- 能量核心渐变 -->
                    <radialGradient id="coreGlow-${uniqueId}" cx="50%" cy="50%" r="50%">
                        <stop offset="0%" style="stop-color:var(--neon-cyan);stop-opacity:1" />
                        <stop offset="50%" style="stop-color:var(--border-color);stop-opacity:0.8" />
                        <stop offset="100%" style="stop-color:var(--bg-accent);stop-opacity:0.3" />
                    </radialGradient>
                    
                    <!-- 外壳渐变 -->
                    <linearGradient id="shellGradient-${uniqueId}" x1="0%" y1="0%" x2="100%" y2="100%">
                        <stop offset="0%" style="stop-color:var(--bg-secondary);stop-opacity:1" />
                        <stop offset="50%" style="stop-color:var(--bg-accent);stop-opacity:1" />
                        <stop offset="100%" style="stop-color:var(--bg-primary);stop-opacity:1" />
                    </linearGradient>
                    
                    <!-- 发光滤镜 -->
                    <filter id="energyGlow-${uniqueId}">
                        <feGaussianBlur stdDeviation="4" result="coloredBlur"/>
                        <feMerge> 
                            <feMergeNode in="coloredBlur"/>
                            <feMergeNode in="SourceGraphic"/>
                        </feMerge>
                    </filter>
                    
                    <!-- 脉冲滤镜 -->
                    <filter id="pulse-${uniqueId}">
                        <feGaussianBlur stdDeviation="2" result="coloredBlur"/>
                        <feMerge> 
                            <feMergeNode in="coloredBlur"/>
                            <feMergeNode in="SourceGraphic"/>
                        </feMerge>
                    </filter>
                </defs>
                
                <!-- 外层护盾环 -->
                <circle cx="60" cy="60" r="50" fill="none" stroke="url(#coreGlow-${uniqueId})" stroke-width="1" opacity="0.4">
                    <animate attributeName="r" values="50;52;50" dur="3s" repeatCount="indefinite"/>
                    <animate attributeName="opacity" values="0.4;0.7;0.4" dur="3s" repeatCount="indefinite"/>
                </circle>
                
                <!-- 中层能量罩 -->
                <circle cx="60" cy="60" r="45" fill="none" stroke="var(--neon-cyan)" stroke-width="2" opacity="0.6" stroke-dasharray="5,3">
                    <animateTransform attributeName="transform" type="rotate" values="0 60 60;360 60 60" dur="8s" repeatCount="indefinite"/>
                </circle>
                
                <!-- 主体外壳 - 六边形 -->
                <polygon points="60,25 85,40 85,65 60,80 35,65 35,40" 
                         fill="url(#shellGradient-${uniqueId})" 
                         stroke="var(--border-color)" 
                         stroke-width="2"/>
                
                <!-- 内部框架线 -->
                <polygon points="60,35 75,45 75,60 60,70 45,60 45,45" 
                         fill="none" 
                         stroke="var(--border-color)" 
                         stroke-width="1" 
                         opacity="0.7"/>
                
                <!-- 能量核心 -->
                <circle cx="60" cy="52.5" r="12" fill="url(#coreGlow-${uniqueId})" filter="url(#energyGlow-${uniqueId})">
                    <animate attributeName="r" values="12;15;12" dur="2s" repeatCount="indefinite"/>
                    <animate attributeName="opacity" values="0.8;1;0.8" dur="2s" repeatCount="indefinite"/>
                </circle>
                
                <!-- 能量粒子 -->
                <circle cx="45" cy="45" r="2" fill="var(--neon-cyan)" filter="url(#pulse-${uniqueId})">
                    <animate attributeName="opacity" values="0;1;0" dur="1.5s" begin="0s" repeatCount="indefinite"/>
                </circle>
                <circle cx="75" cy="45" r="2" fill="var(--neon-cyan)" filter="url(#pulse-${uniqueId})">
                    <animate attributeName="opacity" values="0;1;0" dur="1.5s" begin="0.5s" repeatCount="indefinite"/>
                </circle>
                <circle cx="75" cy="60" r="2" fill="var(--neon-cyan)" filter="url(#pulse-${uniqueId})">
                    <animate attributeName="opacity" values="0;1;0" dur="1.5s" begin="1s" repeatCount="indefinite"/>
                </circle>
                <circle cx="45" cy="60" r="2" fill="var(--neon-cyan)" filter="url(#pulse-${uniqueId})">
                    <animate attributeName="opacity" values="0;1;0" dur="1.5s" begin="1.5s" repeatCount="indefinite"/>
                </circle>
                
                <!-- 量子传输环 -->
                <circle cx="60" cy="52.5" r="20" fill="none" stroke="var(--neon-cyan)" stroke-width="1" opacity="0.3" stroke-dasharray="2,4">
                    <animateTransform attributeName="transform" type="rotate" values="360 60 52.5;0 60 52.5" dur="4s" repeatCount="indefinite"/>
                </circle>
                
                <!-- 能量连接线 -->
                <path d="M45 45 L60 52.5 L75 45" stroke="var(--border-color)" stroke-width="1.5" fill="none" opacity="0.8">
                    <animate attributeName="opacity" values="0.3;0.9;0.3" dur="2s" repeatCount="indefinite"/>
                </path>
                <path d="M45 60 L60 52.5 L75 60" stroke="var(--border-color)" stroke-width="1.5" fill="none" opacity="0.8">
                    <animate attributeName="opacity" values="0.9;0.3;0.9" dur="2s" repeatCount="indefinite"/>
                </path>
                
                <!-- 状态指示器 -->
                <rect x="56" y="75" width="8" height="3" rx="1" fill="#ff6600" opacity="0.8">
                    <animate attributeName="opacity" values="0.8;0.3;0.8" dur="1s" repeatCount="indefinite"/>
                </rect>
                
                <!-- 量子符号 -->
                <text x="60" y="90" text-anchor="middle" fill="var(--neon-cyan)" font-size="10" font-family="monospace" opacity="0.9">◊</text>
            </svg>
        `;
    } else if (type === 'opened') {
        return `
            <svg viewBox="0 0 120 120" class="energy-chest-icon opened">
                <defs>
                    <!-- 废弃状态渐变 -->
                    <linearGradient id="deadShell-${uniqueId}" x1="0%" y1="0%" x2="100%" y2="100%">
                        <stop offset="0%" style="stop-color:var(--bg-accent);stop-opacity:1" />
                        <stop offset="100%" style="stop-color:var(--bg-primary);stop-opacity:1" />
                    </linearGradient>
                </defs>
                
                <!-- 废弃的外环 -->
                <circle cx="60" cy="60" r="50" fill="none" stroke="var(--text-secondary)" stroke-width="1" opacity="0.2" stroke-dasharray="3,6"/>
                
                <!-- 破损的能量罩 -->
                <circle cx="60" cy="60" r="45" fill="none" stroke="var(--text-secondary)" stroke-width="1" opacity="0.3" stroke-dasharray="8,12"/>
                
                <!-- 主体外壳 - 六边形 (打开状态) -->
                <polygon points="60,25 85,40 85,65 60,80 35,65 35,40" 
                         fill="url(#deadShell-${uniqueId})" 
                         stroke="var(--text-secondary)" 
                         stroke-width="2"/>
                
                <!-- 打开的上盖 -->
                <polygon points="60,15 80,25 70,35 50,25" 
                         fill="url(#deadShell-${uniqueId})" 
                         stroke="var(--text-secondary)" 
                         stroke-width="2" 
                         transform="rotate(-20 60 25)"/>
                
                <!-- 空的能量核心 -->
                <circle cx="60" cy="52.5" r="10" fill="none" stroke="var(--text-secondary)" stroke-width="2" opacity="0.4"/>
                
                <!-- 内部损坏的框架 -->
                <polygon points="60,40 70,47 70,58 60,65 50,58 50,47" 
                         fill="none" 
                         stroke="var(--text-secondary)" 
                         stroke-width="1" 
                         opacity="0.3"
                         stroke-dasharray="2,3"/>
                
                <!-- 已消散的能量粒子 -->
                <circle cx="45" cy="45" r="1" fill="#4a5568" opacity="0.2"/>
                <circle cx="75" cy="60" r="1" fill="#4a5568" opacity="0.2"/>
                
                <!-- 断裂的连接线 -->
                <path d="M45 45 L55 50" stroke="#4a5568" stroke-width="1" fill="none" opacity="0.3"/>
                <path d="M65 55 L75 60" stroke="#4a5568" stroke-width="1" fill="none" opacity="0.3"/>
                
                <!-- 已关闭状态指示器 -->
                <rect x="56" y="75" width="8" height="3" rx="1" fill="#22c55e" opacity="0.7"/>
                
                <!-- 完成标记 -->
                <text x="60" y="90" text-anchor="middle" fill="#22c55e" font-size="12" font-weight="bold">✓</text>
            </svg>
        `;
    }
    return '📦';
};

// 确认开启宝箱（显示广告确认）
const confirmOpenChest = (slotNumber) => {
    const slotId = `chest-slot-${slotNumber}`;
    
    // 检查是否已开启
    if (independentChestSystem.openedChests.includes(slotId)) {
        showChestNotification('该宝箱已经开启过了！', 'error');
        return;
    }
    
    // 检查localStorage中是否有该槽位的数据
    const chestData = JSON.parse(localStorage.getItem('chestData') || '{}');
    const slotData = chestData[slotId];
    if (slotData && slotData.opened) {
        showChestNotification('该宝箱已经开启过了！', 'error');
        return;
    }
    
    // 显示广告确认对话框
    if (!defaultModalElement) {
        console.error('defaultModalElement not found!');
        return;
    }
    
    defaultModalElement.style.display = "flex";
    defaultModalElement.innerHTML = `
        <div class="content">
            <h3><i class="fas fa-box-open"></i> 宝箱开启</h3>
            <p>连接量子广告网络以激活宝箱开启协议</p>
            <p style="font-size: 0.9rem; opacity: 0.7;">观看广告（15-30秒）来开启神秘宝箱</p>
            <div class="button-container">
                <button id="watchAdToOpen"><i class="fas fa-play-circle"></i> 连接网络</button>
                <button id="cancelOpen">取消</button>
            </div>
        </div>
    `;
    
    const watchAdBtn = document.querySelector("#watchAdToOpen");
    const cancelBtn = document.querySelector("#cancelOpen");
    
    watchAdBtn.onclick = function() {
        safePlaySFX(sfxConfirm);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        openIndependentChest(slotNumber);
    };
    
    cancelBtn.onclick = function() {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
    };
};

// 开启独立宝箱
const openIndependentChest = (slotNumber) => {
    const slotId = `chest-slot-${slotNumber}`;
    
    // 检查是否已开启
    if (independentChestSystem.openedChests.includes(slotId)) {
        showChestNotification('该宝箱已经开启过了！', 'error');
        return;
    }
    
    // 需要看广告
    if (window.Android && window.Android.showRewardAd) {
        window.currentChestSlot = slotNumber;
        window.Android.showRewardAd();
        // 等待广告回调
        window.onRewardAdComplete = () => {
            performIndependentChestOpen(slotNumber);
        };
        window.onRewardAdFailed = () => {
            showChestNotification('需要观看完整广告才能开启宝箱！', 'error');
        };
    } else {
        // 开发环境直接开启
        performIndependentChestOpen(slotNumber);
    }
};

// 执行独立宝箱开启
const performIndependentChestOpen = (slotNumber) => {
    const slotId = `chest-slot-${slotNumber}`;
    
    // 记录已开启
    independentChestSystem.openedChests.push(slotId);
    saveIndependentChestData();
    
    // 更新刷新按钮状态
    updateRefreshButtonState();
    
    // 获取该槽位预分配的稀有度
    const rarity = getChestRarityForSlot(slotNumber);
    
    // 生成对应稀有度的装备
    const equipment = generateChestEquipment(rarity.rarity, slotNumber);
    
    // 检查装备是否生成成功
    if (equipment) {
        // 保存宝箱数据到localStorage
        const chestData = JSON.parse(localStorage.getItem('chestData') || '{}');
        chestData[slotId] = {
            opened: true,
            rarity: rarity.rarity,
            rarityName: rarity.name,
            equipmentName: equipment.category || equipment.name || "神秘装备",
            equipmentCategory: equipment.category || "神秘装备",
            equipmentType: equipment.type || "未知",
            equipmentLevel: equipment.lvl || 1,
            equipmentTier: equipment.tier || 1,
            equipmentStats: equipment.stats || [],
            equipmentValue: equipment.value || 0,
            openTime: Date.now(),
            // 保存完整装备对象用于显示详情
            fullEquipment: equipment
        };
        localStorage.setItem('chestData', JSON.stringify(chestData));
        
        // 注意：createChestEquipment 函数已经添加装备到背包并保存了游戏数据
        
        // 显示开箱动画和结果
        showIndependentChestOpenAnimation(slotNumber, equipment, rarity);
    } else {
        console.error('Failed to generate chest equipment');
        showChestNotification('装备生成失败，请重试！', 'error');
    }
};

// 显示独立宝箱开箱动画
const showIndependentChestOpenAnimation = (slotNumber, equipment, rarityConfig) => {
    const slot = document.querySelector(`#independentChestInterface [data-slot="${slotNumber}"]`);
    
    if (!slot) return;
    
    // 播放音效
    if (typeof safePlaySFX === 'function' && typeof sfxOpen !== 'undefined') {
        safePlaySFX(sfxOpen);
    }
    
    // 创建炫酷的开箱动画
    createEpicChestOpenAnimation(slot, slotNumber, equipment, rarityConfig);
};

// 创建史诗级开箱动画
const createEpicChestOpenAnimation = (slot, slotNumber, equipment, rarityConfig) => {
    // 第一阶段：宝箱发光和震动
    slot.style.transform = 'scale(1.1)';
    slot.style.filter = 'brightness(1.5) drop-shadow(0 0 20px ' + rarityConfig.color + ')';
    slot.style.transition = 'all 0.3s ease';
    
    // 添加震动效果
    let shakeCount = 0;
    const shakeInterval = setInterval(() => {
        const shakeX = (Math.random() - 0.5) * 10;
        const shakeY = (Math.random() - 0.5) * 10;
        slot.style.transform = `scale(1.1) translate(${shakeX}px, ${shakeY}px)`;
        shakeCount++;
        
        if (shakeCount >= 8) {
            clearInterval(shakeInterval);
            // 第二阶段：爆炸效果
            createExplosionEffect(slot, rarityConfig);
        }
    }, 100);
    
    // 第三阶段：显示结果（在爆炸效果后）
    setTimeout(() => {
        // 重置宝箱样式
        slot.style.transform = 'scale(1)';
        slot.style.filter = 'none';
        slot.style.transition = 'all 0.5s ease';
        
        // 重新渲染宝箱界面以显示新结果
        refreshIndependentChestInterface();
        
        // 显示获得装备的浮动文字动画
        showEquipmentRewardAnimation(slotNumber, equipment, rarityConfig);
        
        // 创建装备详情面板
        let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
        const equipmentIconSvg = (typeof window.equipmentIcon === 'function') ? window.equipmentIcon(equipment) : '';
        let panel = `
            <div class="primary-panel" style="padding: 0.5rem; margin-top: 0.5rem;">
                    <h4 class="${equipment.rarity}"><b>${equipmentIconSvg}${equipment.rarity} ${equipment.category}</b></h4>
                    <h5 class="${equipment.rarity}"><b>Lv.${equipment.lvl} Tier ${equipment.tier}</b></h5>
                    <ul>
                    ${equipment.stats.map(stat => {
            const statNames = {
                "hp": "装甲完整度",
                "atk": "武器输出",
                "def": "护盾强度",
                "atkSpd": "反应速度",
                "vamp": "纳米修复",
                "critRate": "弱点扫描",
                "critDmg": "爆击倍率"
            };
            const statKey = Object.keys(stat)[0];
            const statValue = stat[statKey];
            const displayName = statNames[statKey] || statKey;
            
            if (statKey === "critRate" || statKey === "critDmg" || statKey === "atkSpd" || statKey === "vamp") {
                return `<li>${displayName}+${statValue.toFixed(2).replace(rx, "$1")}%</li>`;
            }
            else {
                return `<li>${displayName}+${statValue}</li>`;
            }
        }).join('')}
                </ul>
            </div>`;
        
        // 显示获得装备通知
        const equipmentInfo = `${rarityConfig.name} ${equipment.category} (Lv.${equipment.lvl} T${equipment.tier})`;
        if (typeof showEquipmentNotification === 'function') {
            showEquipmentNotification(equipment);
        } else {
            showChestNotification(`获得了${equipmentInfo}！`, 'success');
        }
        
        // 不要添加到地牢日志，避免干扰事件流程
        
        // 延迟500毫秒后显示装备详情弹窗（在动画和通知显示完成后）
        setTimeout(() => {
            showChestEquipmentModal(equipment);
        }, 500);
        
        // 注意：事件状态清理移到装备详情模态窗口关闭时进行
    }, 2000);
};

// 创建爆炸粒子效果
const createExplosionEffect = (slot, rarityConfig) => {
    const rect = slot.getBoundingClientRect();
    const centerX = rect.left + rect.width / 2;
    const centerY = rect.top + rect.height / 2;
    
    // 创建多个粒子
    for (let i = 0; i < 15; i++) {
        const particle = document.createElement('div');
        particle.className = 'chest-particle';
        particle.style.cssText = `
            position: fixed;
            left: ${centerX}px;
            top: ${centerY}px;
            width: 6px;
            height: 6px;
            background: ${rarityConfig.color};
            border-radius: 50%;
            pointer-events: none;
            z-index: 9999;
            box-shadow: 0 0 10px ${rarityConfig.color};
        `;
        
        document.body.appendChild(particle);
        
        // 随机方向和距离
        const angle = (Math.PI * 2 * i) / 15;
        const distance = 100 + Math.random() * 100;
        const endX = centerX + Math.cos(angle) * distance;
        const endY = centerY + Math.sin(angle) * distance;
        
        // 动画粒子
        particle.animate([
            {
                transform: 'translate(0, 0) scale(1)',
                opacity: 1
            },
            {
                transform: `translate(${endX - centerX}px, ${endY - centerY}px) scale(0)`,
                opacity: 0
            }
        ], {
            duration: 800,
            easing: 'cubic-bezier(0.25, 0.46, 0.45, 0.94)'
        }).onfinish = () => {
            particle.remove();
        };
    }
    
    // 创建光环效果
    const ring = document.createElement('div');
    ring.style.cssText = `
        position: fixed;
        left: ${centerX}px;
        top: ${centerY}px;
        width: 20px;
        height: 20px;
        border: 3px solid ${rarityConfig.color};
        border-radius: 50%;
        pointer-events: none;
        z-index: 9998;
        transform: translate(-50%, -50%);
        box-shadow: 0 0 20px ${rarityConfig.color};
    `;
    
    document.body.appendChild(ring);
    
    ring.animate([
        {
            transform: 'translate(-50%, -50%) scale(0)',
            opacity: 1
        },
        {
            transform: 'translate(-50%, -50%) scale(3)',
            opacity: 0
        }
    ], {
        duration: 600,
        easing: 'ease-out'
    }).onfinish = () => {
        ring.remove();
    };
};

// 显示装备奖励浮动动画
const showEquipmentRewardAnimation = (slotNumber, equipment, rarityConfig) => {
    const slot = document.querySelector(`#independentChestInterface [data-slot="${slotNumber}"]`);
    if (!slot) return;
    
    const rect = slot.getBoundingClientRect();
    const rewardText = document.createElement('div');
    rewardText.className = 'chest-reward-text';
    rewardText.innerHTML = `
        <div class="reward-rarity" style="color: ${rarityConfig.color}">
            ${rarityConfig.name}
        </div>
        <div class="reward-equipment">
            ${equipment.category || equipment.name || "神秘装备"}
        </div>
    `;
    
    rewardText.style.cssText = `
        position: fixed;
        left: ${rect.left + rect.width / 2}px;
        top: ${rect.top + rect.height / 2}px;
        transform: translate(-50%, -50%);
        z-index: 10000;
        pointer-events: none;
        text-align: center;
        font-weight: bold;
        text-shadow: 2px 2px 4px rgba(0,0,0,0.8);
        font-size: 1.2rem;
    `;
    
    document.body.appendChild(rewardText);
    
    // 浮动文字动画
    rewardText.animate([
        {
            transform: 'translate(-50%, -50%) scale(0)',
            opacity: 0
        },
        {
            transform: 'translate(-50%, -60%) scale(1.2)',
            opacity: 1,
            offset: 0.3
        },
        {
            transform: 'translate(-50%, -80%) scale(1)',
            opacity: 1,
            offset: 0.7
        },
        {
            transform: 'translate(-50%, -100%) scale(0.8)',
            opacity: 0
        }
    ], {
        duration: 2000,
        easing: 'ease-out'
    }).onfinish = () => {
        rewardText.remove();
    };
};

// 刷新独立宝箱界面
const refreshIndependentChestInterface = () => {
    const grid = document.querySelector('.independent-chest-grid');
    if (grid) {
        grid.innerHTML = Array.from({length: 6}, (_, i) => createIndependentChestSlot(i + 1)).join('');
    }
    
    // 更新刷新按钮状态
    updateRefreshButtonState();
};

// 更新刷新按钮状态
const updateRefreshButtonState = () => {
    const refreshBtn = document.querySelector('.quick-refresh-btn');
    if (refreshBtn) {
        const allOpened = independentChestSystem.openedChests.length >= 6;
        if (allOpened) {
            refreshBtn.classList.remove('disabled');
            refreshBtn.removeAttribute('disabled');
            refreshBtn.setAttribute('title', '花费10,000信用点立即刷新');
        } else {
            refreshBtn.classList.add('disabled');
            refreshBtn.setAttribute('disabled', '');
            refreshBtn.setAttribute('title', '请先开启所有宝箱');
        }
    }
};

// 关闭独立宝箱界面
const closeIndependentChestInterface = () => {
    const modal = document.getElementById('independentChestInterface');
    if (modal) {
        // 清理定时器
        clearInterval(window.independentChestTimerInterval);
        
        // 隐藏模态框
        modal.style.display = "none";
        
        // 从层级管理器移除
        if (window.zIndexManager) {
            window.zIndexManager.popModal(modal);
        }
        
        // 移除DOM元素
        setTimeout(() => {
            modal.remove();
        }, 100);
        
        // 关闭宝箱界面后，如果之前在探索，继续探索
        if (typeof continueExploring === 'function') {
            continueExploring();
        }
    }
};

// 启动独立宝箱定时器更新
const startIndependentChestTimerUpdate = () => {
    // 清除之前的定时器
    if (window.independentChestTimerInterval) {
        clearInterval(window.independentChestTimerInterval);
    }
    
    window.independentChestTimerInterval = setInterval(() => {
        const timeRemaining = getIndependentChestRefreshTimeRemaining();
        const display = document.getElementById('independentChestTimerDisplay');
        
        if (display) {
            if (timeRemaining.totalMs <= 0) {
                display.innerHTML = '宝箱已刷新！';
                refreshIndependentChests();
                refreshIndependentChestInterface();
            } else {
                display.innerHTML = `${timeRemaining.minutes}分${timeRemaining.seconds}秒后刷新`;
            }
        }
    }, 1000);
};

// 显示独立宝箱重置确认
const showIndependentResetConfirm = () => {
    // 检查是否所有宝箱都已开启
    const totalChests = 6;
    if (independentChestSystem.openedChests.length < totalChests) {
        // 显示弹窗提示需要开完所有宝箱
        if (!defaultModalElement) {
            showChestNotification('请先开启所有宝箱后再刷新！', 'error');
            return;
        }
        
        defaultModalElement.style.display = "flex";
        defaultModalElement.innerHTML = `
            <div class="content">
                <h3><i class="fas fa-exclamation-triangle" style="color: #fbbf24;"></i> 无法刷新宝箱</h3>
                <p>您需要先开启所有宝箱才能进行刷新！</p>
                <p style="font-size: 0.85rem; opacity: 0.7;">当前已开启: ${independentChestSystem.openedChests.length}/6 个宝箱</p>
                <div class="button-container">
                    <button id="closeNotification" style="background: linear-gradient(135deg, #8b5cf6, #7c3aed);">
                        <i class="fas fa-check"></i> 我知道了
                    </button>
                </div>
            </div>
        `;
        
        const closeBtn = document.querySelector("#closeNotification");
        closeBtn.onclick = function() {
            safePlaySFX(sfxDecline);
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
        };
        return;
    }
    
    if (!player || player.gold < 10000) {
        showChestNotification('信用点不足！需要 10,000 信用点', 'error');
        return;
    }
    
    // 显示自定义确认对话框
    if (!defaultModalElement) {
        console.error('defaultModalElement not found!');
        return;
    }
    
    defaultModalElement.style.display = "flex";
    defaultModalElement.innerHTML = `
        <div class="content">
            <h3><i class="fas fa-bolt"></i> 立即刷新宝箱</h3>
            <p>确定要花费 <span style="color: #fbbf24; font-weight: bold;">10,000 信用点</span> 立即刷新所有宝箱吗？</p>
            <p style="font-size: 0.85rem; opacity: 0.7;">刷新后将获得全新的6个神秘宝箱</p>
            <div class="button-container">
                <button id="confirmRefresh" style="background: linear-gradient(135deg, #8b5cf6, #7c3aed);">
                    <i class="fas fa-check"></i> 确认刷新
                </button>
                <button id="cancelRefresh">取消</button>
            </div>
        </div>
    `;
    
    const confirmBtn = document.querySelector("#confirmRefresh");
    const cancelBtn = document.querySelector("#cancelRefresh");
    
    confirmBtn.onclick = function() {
        safePlaySFX(sfxConfirm);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        
        player.gold -= 10000;
        refreshIndependentChests();
        if (typeof saveData === 'function') {
            saveData();
        }
        refreshIndependentChestInterface();
        updateChestGoldDisplay();
        if (typeof updatePlayerGoldDisplay === 'function') {
            updatePlayerGoldDisplay();
        }
        showChestNotification('宝箱已刷新！', 'success');
    };
    
    cancelBtn.onclick = function() {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
    };
};

// 更新宝箱界面金币显示
const updateChestGoldDisplay = () => {
    const goldDisplay = document.getElementById('chest-player-gold');
    if (goldDisplay) {
        goldDisplay.textContent = (typeof player !== 'undefined' && player) ? (player.gold || 0) : 0;
    }
};

// 添加独立宝箱样式
const addIndependentChestStyles = () => {
    if (document.getElementById('independent-chest-styles')) return;
    
    const style = document.createElement('style');
    style.id = 'independent-chest-styles';
    style.textContent = `
        /* 独立宝箱界面样式 - 游戏主题配色 */
        .independent-chest-content {
            max-width: 100vw;
            width: 100%;
            height: 100vh;
            max-height: 100vh;
            padding: 8px;
            margin: 0;
            background: linear-gradient(135deg, 
                var(--bg-primary) 0%, 
                var(--bg-secondary) 50%, 
                var(--bg-primary) 100%
            );
            border: 3px solid var(--border-color);
            border-radius: 12px;
            box-shadow: 
                0 0 20px var(--border-glow),
                inset 0 0 30px rgba(0, 212, 255, 0.1);
            overflow-y: auto;
            display: flex;
            flex-direction: column;
            position: relative;
            box-sizing: border-box;
        }
        
        /* 内容区域 */
        .independent-chest-content > * {
            position: relative;
            z-index: 1;
        }
        
        /* 头部区域 */
        .independent-chest-header {
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
            padding: 1rem 1.5rem;
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.15) 0%, 
                var(--bg-secondary) 100%
            );
            border: 2px solid var(--border-color);
            border-radius: 8px;
            margin: 4px;
            position: relative;
            z-index: 10;
        }
        
        .header-left {
            flex: 1;
        }
        
        .chest-title {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-size: 1.5rem;
            font-weight: bold;
            color: var(--text-primary);
            text-shadow: 0 0 10px var(--border-glow);
            margin: 0;
        }
        
        .chest-gem-icon {
            font-size: 1.8rem;
            color: var(--neon-cyan);
            text-shadow: 0 0 10px var(--border-glow);
            animation: gemPulse 2s ease-in-out infinite;
        }
        
        @keyframes gemPulse {
            0%, 100% { transform: scale(1); }
            50% { transform: scale(1.05); }
        }
        
        .chest-subtitle {
            font-size: 0.85rem;
            color: var(--text-secondary);
            margin-top: 0.25rem;
            font-weight: normal;
        }
        
        .header-right {
            display: flex;
            align-items: center;
            gap: 1rem;
        }
        
        .chest-credits {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            font-size: 1.1rem;
            font-weight: bold;
            color: var(--text-primary);
            background: rgba(0, 212, 255, 0.1);
            padding: 0.5rem 0.75rem;
            border-radius: 6px;
            border: 1px solid var(--border-color);
        }
        
        .chest-close-btn {
            background: rgba(0, 212, 255, 0.1);
            border: 1px solid var(--border-color);
            color: var(--text-primary);
            width: 42px;
            height: 42px;
            border-radius: 6px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: all 0.3s ease;
            font-size: 1.1rem;
        }
        
        .chest-close-btn:hover {
            background: rgba(0, 212, 255, 0.2);
            box-shadow: 0 0 15px var(--border-glow);
            transform: scale(1.05);
        }
        
        /* 状态栏 */
        .chest-status-bar {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 1rem 1.5rem;
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.1) 0%, 
                var(--bg-secondary) 100%
            );
            border: 2px solid var(--border-color);
            border-radius: 8px;
            margin: 4px;
            gap: 1rem;
            position: relative;
        }
        
        .status-item {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            flex: 1;
        }
        
        .status-icon {
            font-size: 1.2rem;
            color: var(--text-primary);
            width: 24px;
            text-align: center;
        }
        
        .status-info {
            flex: 1;
        }
        
        .status-label {
            font-size: 0.75rem;
            color: var(--text-secondary);
            text-transform: uppercase;
            letter-spacing: 0.5px;
        }
        
        .status-value {
            font-size: 0.9rem;
            color: var(--text-primary);
            font-weight: 600;
            margin-top: 0.15rem;
        }
        
        .quick-refresh-btn {
            background: linear-gradient(135deg, var(--border-color), var(--neon-cyan));
            border: 1px solid var(--border-color);
            color: var(--bg-primary);
            padding: 0.75rem 1rem;
            border-radius: 6px;
            cursor: pointer;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            gap: 0.5rem;
            font-size: 0.85rem;
            font-weight: 600;
            position: relative;
            overflow: hidden;
            white-space: nowrap;
            flex-shrink: 0;
            writing-mode: horizontal-tb !important;
            text-orientation: mixed !important;
            flex-direction: row !important;
        }
        
        .quick-refresh-btn:hover:not(.disabled) {
            transform: translateY(-2px);
            box-shadow: 0 4px 15px var(--border-glow);
        }
        
        .quick-refresh-btn.disabled {
            opacity: 0.5;
            cursor: not-allowed;
            background: linear-gradient(135deg, rgba(100, 100, 100, 0.3), rgba(80, 80, 80, 0.2));
            border-color: rgba(100, 100, 100, 0.5);
        }
        
        .quick-refresh-btn.disabled .refresh-cost {
            opacity: 0.6;
        }
        
        .refresh-cost {
            font-size: 0.7rem;
            opacity: 0.9;
            background: rgba(0, 0, 0, 0.3);
            padding: 0.2rem 0.4rem;
            border-radius: 0.3rem;
            white-space: nowrap;
            flex-shrink: 0;
            writing-mode: horizontal-tb !important;
            text-orientation: mixed !important;
            display: inline-block !important;
        }
        
        .refresh-text {
            white-space: nowrap;
            flex-shrink: 0;
            writing-mode: horizontal-tb !important;
            text-orientation: mixed !important;
            display: inline-block !important;
        }
        
        .quick-refresh-btn * {
            writing-mode: horizontal-tb !important;
            text-orientation: mixed !important;
        }
        
        /* 宝箱网格容器 */
        .chest-grid-container {
            flex: 1;
            padding: 1rem;
            overflow-y: auto;
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.05) 0%, 
                var(--bg-accent) 100%
            );
            border: 2px solid var(--border-color);
            border-radius: 8px;
            margin: 4px;
        }
        
        .grid-title {
            text-align: center;
            margin-bottom: 1.5rem;
            position: relative;
            padding: 1rem 0;
        }
        
        .grid-title-text {
            font-size: 1.2rem;
            font-weight: bold;
            color: var(--text-primary);
            display: block;
            text-shadow: 0 0 8px var(--border-glow);
        }
        
        .grid-subtitle {
            font-size: 0.85rem;
            color: var(--text-secondary);
            margin-top: 0.5rem;
            font-weight: 500;
        }
        
        .independent-chest-grid {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            grid-template-rows: repeat(2, 1fr);
            gap: 0.75rem;
            max-width: 100%;
            margin: 0 auto;
            height: auto;
            min-height: 300px;
        }
        
        .chest-slot {
            aspect-ratio: 1;
            border: 2px solid var(--border-color);
            border-radius: 8px;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            gap: 0.25rem;
            padding: 0.5rem;
            transition: all 0.3s ease;
            position: relative;
            overflow: hidden;
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.1) 0%, 
                var(--bg-accent) 100%
            );
            min-height: 0;
            height: auto;
            box-shadow: 
                inset 0 1px 3px var(--border-glow),
                0 2px 8px rgba(0, 0, 0, 0.3);
        }
        
        .chest-slot.mystery {
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.2) 0%, 
                var(--bg-accent) 100%
            );
            border-color: var(--neon-cyan);
            cursor: pointer;
        }
        
        .chest-slot.mystery:hover {
            transform: translateY(-3px);
            box-shadow: 
                0 8px 25px var(--border-glow),
                inset 0 1px 3px var(--border-glow);
            border-color: var(--text-primary);
        }
        
        .chest-slot.mystery::after {
            content: '';
            position: absolute;
            top: -2px;
            left: -2px;
            right: -2px;
            bottom: -2px;
            background: linear-gradient(45deg, 
                transparent, 
                var(--border-glow), 
                transparent
            );
            animation: shine 3s linear infinite;
            border-radius: 8px;
            z-index: -1;
        }
        
        .chest-slot.opened {
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.15) 0%, 
                var(--bg-accent) 100%
            );
            border-color: var(--neon-cyan);
            opacity: 0.9;
        }
        
        /* 稀有度边框样式 */
        .chest-slot.opened.标准级 {
            border-color: #9E9E9E;
            box-shadow: 
                0 0 15px rgba(158, 158, 158, 0.4),
                inset 0 0 10px rgba(158, 158, 158, 0.1);
        }
        
        .chest-slot.opened.改进级 {
            border-color: #4CAF50;
            box-shadow: 
                0 0 15px rgba(76, 175, 80, 0.5),
                inset 0 0 10px rgba(76, 175, 80, 0.2);
        }
        
        .chest-slot.opened.军用级 {
            border-color: #2196F3;
            box-shadow: 
                0 0 20px rgba(33, 150, 243, 0.6),
                inset 0 0 10px rgba(33, 150, 243, 0.2);
        }
        
        .chest-slot.opened.实验级 {
            border-color: #9C27B0;
            box-shadow: 
                0 0 20px rgba(156, 39, 176, 0.6),
                inset 0 0 10px rgba(156, 39, 176, 0.2);
        }
        
        .chest-slot.opened.原型级 {
            border-color: #FF9800;
            box-shadow: 
                0 0 25px rgba(255, 152, 0, 0.7),
                inset 0 0 10px rgba(255, 152, 0, 0.3);
            animation: orangeGlow 3s ease-in-out infinite;
        }
        
        .chest-slot.opened.遗产级 {
            border-color: #F44336;
            box-shadow: 
                0 0 30px rgba(244, 67, 54, 0.8),
                inset 0 0 15px rgba(244, 67, 54, 0.3);
            animation: legendaryGlow 2s ease-in-out infinite;
        }
        
        @keyframes orangeGlow {
            0%, 100% { 
                box-shadow: 
                    0 0 25px rgba(255, 152, 0, 0.7),
                    inset 0 0 10px rgba(255, 152, 0, 0.3);
            }
            50% { 
                box-shadow: 
                    0 0 35px rgba(255, 152, 0, 0.9),
                    inset 0 0 15px rgba(255, 152, 0, 0.4);
            }
        }
        
        @keyframes legendaryGlow {
            0%, 100% { 
                box-shadow: 
                    0 0 30px rgba(244, 67, 54, 0.8),
                    inset 0 0 15px rgba(244, 67, 54, 0.3);
            }
            50% { 
                box-shadow: 
                    0 0 40px rgba(244, 67, 54, 1),
                    inset 0 0 20px rgba(244, 67, 54, 0.5);
            }
        }
        
        @keyframes shine {
            0% { transform: translateX(-100%); }
            100% { transform: translateX(100%); }
        }
        
        .chest-icon {
            font-size: 2rem;
            margin-bottom: 0.25rem;
            filter: drop-shadow(0 0 8px currentColor);
        }
        
        .chest-icon svg,
        .energy-chest-icon {
            width: 2.5rem;
            height: 2.5rem;
            filter: drop-shadow(0 0 8px var(--border-glow));
        }
        
        .energy-chest-icon.opened {
            filter: drop-shadow(0 0 6px var(--border-glow));
        }
        
        /* 装备图标样式 */
        .equipment-icon {
            width: 3rem;
            height: 3rem;
            filter: drop-shadow(0 0 10px currentColor);
        }
        
        .chest-slot.opened .equipment-icon {
            width: 2.5rem;
            height: 2.5rem;
        }
        
        .chest-label {
            text-align: center;
            font-size: 0.7rem;
            color: var(--text-primary);
            font-weight: 500;
            line-height: 1.2;
        }
        
        .chest-result {
            display: flex;
            flex-direction: column;
            align-items: center;
            gap: 0.5rem;
            height: 100%;
            text-align: center;
        }
        
        .chest-info {
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
            gap: 0.25rem;
        }
        
        .rarity-name {
            font-size: 0.85rem;
            font-weight: bold;
            text-shadow: 0 0 8px currentColor;
        }
        
        .equipment-name {
            font-size: 0.75rem;
            color: var(--text-primary);
            font-weight: 500;
        }
        
        .equipment-level {
            font-size: 0.7rem;
            color: var(--text-secondary);
        }
        
        /* 帮助区域 */
        .chest-help-section {
            padding: 1rem 1.5rem;
            background: linear-gradient(135deg, 
                rgba(0, 212, 255, 0.1) 0%, 
                var(--bg-accent) 100%
            );
            border: 2px solid var(--border-color);
            border-radius: 8px;
            margin: 4px;
            display: flex;
            flex-direction: column;
            gap: 0.75rem;
            position: relative;
        }
        
        .help-item {
            display: flex;
            align-items: center;
            gap: 1rem;
            font-size: 0.85rem;
            color: var(--text-primary);
            padding: 0.25rem 0;
        }
        
        .help-icon {
            width: 20px;
            text-align: center;
            color: var(--neon-cyan);
            font-size: 0.9rem;
            flex-shrink: 0;
        }
        
        /* 动画效果 */
        .chest-slot.opening {
            animation: epicChestShake 0.8s ease-in-out;
        }
        
        @keyframes epicChestShake {
            0%, 100% { transform: scale(1.05) translate(0, 0); }
            10% { transform: scale(1.05) translate(-2px, -2px); }
            20% { transform: scale(1.05) translate(2px, -2px); }
            30% { transform: scale(1.05) translate(-2px, 2px); }
            40% { transform: scale(1.05) translate(2px, 2px); }
            50% { transform: scale(1.05) translate(-1px, -1px); }
            60% { transform: scale(1.05) translate(1px, -1px); }
            70% { transform: scale(1.05) translate(-1px, 1px); }
            80% { transform: scale(1.05) translate(1px, 1px); }
            90% { transform: scale(1.05) translate(-0.5px, -0.5px); }
        }
        
        .chest-particle {
            will-change: transform, opacity;
        }
        
        .chest-reward-text {
            font-family: inherit;
            will-change: transform, opacity;
        }
        
        .reward-rarity {
            font-size: 1.1em;
            font-weight: bold;
            margin-bottom: 0.2em;
            text-shadow: 0 0 10px currentColor;
        }
        
        .reward-equipment {
            font-size: 0.9em;
            color: #ffffff;
            text-shadow: 1px 1px 2px rgba(0,0,0,0.8);
        }
        
        /* 小屏幕适配 */
        @media (max-width: 767px) {
            .independent-chest-content {
                padding: 4px;
            }
            
            .independent-chest-header {
                padding: 0.8rem 1rem;
                margin: 2px;
            }
            
            .chest-title {
                font-size: 1.3rem;
            }
            
            .chest-status-bar {
                flex-direction: column;
                align-items: stretch;
                gap: 0.75rem;
                padding: 0.8rem 1rem;
                margin: 2px;
            }
            
            .status-item {
                text-align: center;
                justify-content: center;
            }
            
            .quick-refresh-btn {
                align-self: center;
                min-width: auto;
                padding: 0.6rem 0.8rem;
                font-size: 0.8rem;
                flex-direction: row !important;
                align-items: center;
                justify-content: center;
                writing-mode: horizontal-tb !important;
                text-orientation: mixed !important;
            }
            
            .refresh-text {
                display: inline-block;
                white-space: nowrap;
                text-overflow: ellipsis;
                overflow: hidden;
                writing-mode: horizontal-tb !important;
                text-orientation: mixed !important;
                direction: ltr;
            }
            
            .refresh-cost {
                font-size: 0.65rem;
                padding: 0.15rem 0.3rem;
                white-space: nowrap;
                writing-mode: horizontal-tb !important;
            }
            
            .chest-grid-container {
                padding: 0.8rem;
                margin: 2px;
            }
            
            .independent-chest-grid {
                gap: 0.5rem;
                min-height: 250px;
            }
            
            .chest-slot {
                padding: 0.4rem;
            }
            
            .chest-icon svg,
            .energy-chest-icon {
                width: 2rem;
                height: 2rem;
            }
            
            .rarity-name {
                font-size: 0.75rem;
            }
            
            .equipment-name {
                font-size: 0.7rem;
            }
            
            .equipment-level {
                font-size: 0.65rem;
            }
            
            .chest-help-section {
                padding: 0.8rem 1rem;
                margin: 2px;
            }
        }
        
        /* 超小屏幕适配 */
        @media (max-width: 480px) {
            .independent-chest-header {
                flex-direction: column;
                gap: 0.5rem;
                align-items: stretch;
            }
            
            .header-left {
                text-align: center;
            }
            
            .header-right {
                justify-content: center;
            }
            
            .chest-title {
                font-size: 1.2rem;
                justify-content: center;
            }
            
            .chest-gem-icon {
                font-size: 1.5rem;
            }
            
            .chest-status-bar {
                padding: 0.75rem 0.5rem;
            }
            
            .quick-refresh-btn {
                padding: 0.5rem 0.7rem;
                font-size: 0.75rem;
                gap: 0.3rem;
                flex-direction: row !important;
                align-items: center;
                writing-mode: horizontal-tb !important;
                min-width: 120px;
            }
            
            .quick-refresh-btn i {
                font-size: 0.9em;
                flex-shrink: 0;
            }
            
            .refresh-text {
                writing-mode: horizontal-tb !important;
                text-orientation: mixed !important;
                direction: ltr;
                flex-shrink: 0;
            }
            
            .refresh-cost {
                font-size: 0.6rem;
                padding: 0.1rem 0.25rem;
                writing-mode: horizontal-tb !important;
                flex-shrink: 0;
            }
            
            .grid-title-text {
                font-size: 1rem;
            }
            
            .grid-subtitle {
                font-size: 0.75rem;
            }
            
            .chest-slot {
                padding: 0.3rem;
            }
            
            .chest-label {
                font-size: 0.65rem;
            }
            
            .help-item {
                font-size: 0.75rem;
                gap: 0.5rem;
            }
        }
        
        /* 大屏幕适配 */
        @media (min-width: 768px) {
            .independent-chest-header {
                padding: 1.5rem 2rem 1.75rem 2rem;
            }
            
            .chest-status-bar {
                padding: 1.5rem 2rem;
            }
            
            .chest-grid-container {
                padding: 2rem;
            }
            
            .independent-chest-grid {
                gap: 1.5rem;
                max-width: 600px;
            }
            
            .chest-help-section {
                padding: 2rem;
                flex-direction: row;
                justify-content: space-around;
            }
            
            .help-item {
                flex-direction: column;
                text-align: center;
                gap: 0.5rem;
            }
            
            .grid-title {
                margin-bottom: 2.5rem;
            }
        }
    `;
    
    document.head.appendChild(style);
};

// 显示宝箱装备详情
const showChestEquipmentDetails = (slotId) => {
    const chestData = JSON.parse(localStorage.getItem('chestData') || '{}');
    const slotData = chestData[slotId];
    
    if (!slotData || !slotData.fullEquipment) {
        showChestNotification('装备信息不完整', 'error');
        return;
    }
    
    const equipment = slotData.fullEquipment;
    
    // 直接使用装备详情显示模态框
    showChestEquipmentModal(equipment);
};

// 备用装备详情显示模态框
const showChestEquipmentModal = (equipment) => {
    const modal = document.createElement('div');
    modal.className = 'modal-container';
    modal.style.display = 'flex';
    modal.style.zIndex = '10001';
    
    let rx = /\\.0+$|(\\.[0-9]*[1-9])0+$/;
    const icon = (typeof equipmentIcon === 'function') ? equipmentIcon(equipment) : '';
    
    modal.innerHTML = `
        <div class="content">
            <h3 class="${equipment.rarity}">${icon}${equipment.rarity} ${equipment.category}</h3>
            <h5 class="lvltier ${equipment.rarity}"><b>Lv.${equipment.lvl} Tier ${equipment.tier}</b></h5>
            <ul>
            ${equipment.stats.map(stat => {
                const statNames = {
                    "hp": "装甲完整度",
                    "atk": "武器输出",
                    "def": "护盾强度",
                    "atkSpd": "反应速度",
                    "vamp": "纳米修复",
                    "critRate": "弱点扫描",
                    "critDmg": "爆击倍率"
                };
                const statKey = Object.keys(stat)[0];
                const statValue = stat[statKey];
                const displayName = statNames[statKey] || statKey;
                
                if (statKey === "critRate" || statKey === "critDmg" || statKey === "atkSpd" || statKey === "vamp") {
                    return `<li>${displayName}+${statValue.toFixed(2).replace(rx, "$1")}%</li>`;
                } else {
                    return `<li>${displayName}+${statValue}</li>`;
                }
            }).join('')}
            </ul>
            <div class="button-container">
                <button onclick="closeChestEquipmentModal(this.closest('.modal-container'))">关闭</button>
            </div>
        </div>
    `;
    
    document.body.appendChild(modal);
    
    // 添加点击模态框背景关闭功能
    modal.addEventListener('click', (e) => {
        if (e.target === modal) {
            closeChestEquipmentModal(modal);
        }
    });
    
    // 15秒后自动关闭
    setTimeout(() => {
        if (modal.parentElement) {
            closeChestEquipmentModal(modal);
        }
    }, 15000);
};

// 关闭宝箱装备模态窗口（并清理事件状态）
const closeChestEquipmentModal = (modal) => {
    if (modal && modal.parentElement) {
        modal.remove();
        
        // 在模态窗口关闭后检查是否需要清理地牢事件状态
        setTimeout(() => {
            if (typeof EventStateManager !== 'undefined') {
                EventStateManager.tryToClearEventState('宝箱详情模态窗');
            }
        }, 100);
    }
};

// 自定义弹窗提示函数
const showChestNotification = (message, type = 'info') => {
    // 移除现有的通知
    const existingNotification = document.querySelector('.chest-notification');
    if (existingNotification) {
        existingNotification.remove();
    }
    
    const notification = document.createElement('div');
    notification.className = `chest-notification ${type}`;
    notification.innerHTML = `
        <div class="notification-content">
            <div class="notification-icon">
                ${type === 'error' ? '⚠️' : type === 'success' ? '✅' : 'ℹ️'}
            </div>
            <div class="notification-message">${message}</div>
            <button class="notification-close" onclick="this.parentElement.parentElement.remove()">
                <i class="fas fa-times"></i>
            </button>
        </div>
    `;
    
    // 添加样式
    notification.style.cssText = `
        position: fixed;
        top: 20px;
        left: 50%;
        transform: translateX(-50%);
        z-index: 10000;
        background: linear-gradient(135deg, rgba(15, 23, 42, 0.95), rgba(0, 0, 0, 0.9));
        border: 2px solid ${type === 'error' ? '#ef4444' : type === 'success' ? '#22c55e' : '#60a5fa'};
        border-radius: 0.75rem;
        box-shadow: 0 10px 25px rgba(0, 0, 0, 0.3);
        backdrop-filter: blur(10px);
        animation: slideInDown 0.3s ease-out;
        max-width: 90vw;
        width: auto;
        min-width: 250px;
    `;
    
    // 添加内容样式
    const style = document.createElement('style');
    style.textContent = `
        @keyframes slideInDown {
            from {
                opacity: 0;
                transform: translateX(-50%) translateY(-20px);
            }
            to {
                opacity: 1;
                transform: translateX(-50%) translateY(0);
            }
        }
        
        .chest-notification .notification-content {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            padding: 1rem 1.25rem;
        }
        
        .chest-notification .notification-icon {
            font-size: 1.25rem;
            flex-shrink: 0;
        }
        
        .chest-notification .notification-message {
            flex: 1;
            color: #e5e7eb;
            font-size: 0.9rem;
            font-weight: 500;
        }
        
        .chest-notification .notification-close {
            background: none;
            border: none;
            color: #9ca3af;
            cursor: pointer;
            padding: 0.25rem;
            border-radius: 0.25rem;
            transition: all 0.2s ease;
            flex-shrink: 0;
        }
        
        .chest-notification .notification-close:hover {
            color: #e5e7eb;
            background: rgba(255, 255, 255, 0.1);
        }
    `;
    
    if (!document.querySelector('#chest-notification-styles')) {
        style.id = 'chest-notification-styles';
        document.head.appendChild(style);
    }
    
    document.body.appendChild(notification);
    
    // 3秒后自动消失
    setTimeout(() => {
        if (notification.parentElement) {
            notification.style.animation = 'slideInDown 0.3s ease-out reverse';
            setTimeout(() => notification.remove(), 300);
        }
    }, 3000);
};

// 通知显示函数（如果不存在）
if (typeof showNotification !== 'function') {
    window.showNotification = showChestNotification;
}

// 初始化系统（当文档加载完成后）
if (document.readyState === 'loading') {
    document.addEventListener('DOMContentLoaded', initIndependentChestSystem);
} else {
    initIndependentChestSystem();
}