// ========== 移动端调试悬浮球 ==========

class MobileDebugFloat {
    constructor() {
        this.isDebugMode = this.checkDebugMode();
        this.isVisible = false;
        this.isDragging = false;
        this.startX = 0;
        this.startY = 0;
        this.currentX = 0;
        this.currentY = 0;
        
        if (this.isDebugMode) {
            this.createFloatButton();
            this.createDebugPanel();
        }
    }
    
    // 检查是否为调试模式
    checkDebugMode() {
        // 强制关闭调试模式
        return false;
        
        // 首先检查全局调试开关
        if (typeof DEBUG_MODE !== 'undefined' && !DEBUG_MODE) {
            return false;
        }
        
        // 多种方式检测调试模式
        const urlParams = new URLSearchParams(window.location.search);
        const isDebugUrl = urlParams.get('debug') === 'true';
        const isLocalhost = window.location.hostname === 'localhost' || 
                           window.location.hostname === '127.0.0.1' ||
                           window.location.hostname.includes('192.168.');
        const isFileProtocol = window.location.protocol === 'file:';
        const hasDebugFlag = localStorage.getItem('mobileDebug') === 'true';
        
        // 开发环境自动启用
        return isDebugUrl || isLocalhost || isFileProtocol || hasDebugFlag;
    }
    
    // 创建悬浮按钮
    createFloatButton() {
        this.floatButton = document.createElement('div');
        this.floatButton.id = 'mobile-debug-float';
        this.floatButton.innerHTML = `
            <div class="debug-icon">
                <i class="fas fa-bug"></i>
            </div>
        `;
        
        // 样式
        this.floatButton.style.cssText = `
            position: fixed;
            top: 50%;
            right: 10px;
            width: 50px;
            height: 50px;
            background: linear-gradient(135deg, #00d4ff, #0099cc);
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            z-index: 9999;
            box-shadow: 0 4px 20px rgba(0, 212, 255, 0.4);
            cursor: pointer;
            user-select: none;
            touch-action: none;
            transition: all 0.3s ease;
            font-size: 18px;
            color: white;
            border: 2px solid rgba(255, 255, 255, 0.3);
        `;
        
        // 添加脉冲动画
        const style = document.createElement('style');
        style.textContent = `
            @keyframes debugPulse {
                0% { transform: scale(1); box-shadow: 0 4px 20px rgba(0, 212, 255, 0.4); }
                50% { transform: scale(1.1); box-shadow: 0 6px 25px rgba(0, 212, 255, 0.6); }
                100% { transform: scale(1); box-shadow: 0 4px 20px rgba(0, 212, 255, 0.4); }
            }
            
            #mobile-debug-float {
                animation: debugPulse 2s ease-in-out infinite;
            }
            
            #mobile-debug-float:active {
                transform: scale(0.95);
            }
            
            #mobile-debug-float.dragging {
                animation: none;
                box-shadow: 0 8px 30px rgba(0, 212, 255, 0.8);
                transform: scale(1.1);
            }
        `;
        document.head.appendChild(style);
        
        document.body.appendChild(this.floatButton);
        this.bindFloatEvents();
    }
    
    // 绑定悬浮球事件
    bindFloatEvents() {
        let startTime;
        let startPos = { x: 0, y: 0 };
        let hasMoved = false;
        let moveThreshold = 10; // 移动阈值，超过此值才认为是拖拽
        
        // 触摸开始
        this.floatButton.addEventListener('touchstart', (e) => {
            e.preventDefault();
            startTime = Date.now();
            hasMoved = false;
            
            const touch = e.touches[0];
            startPos.x = touch.clientX;
            startPos.y = touch.clientY;
            
            // 记录当前位置
            const rect = this.floatButton.getBoundingClientRect();
            this.currentX = rect.left;
            this.currentY = rect.top;
            
            this.startX = touch.clientX - this.currentX;
            this.startY = touch.clientY - this.currentY;
            
            this.floatButton.classList.add('dragging');
        });
        
        // 触摸移动
        this.floatButton.addEventListener('touchmove', (e) => {
            e.preventDefault();
            const touch = e.touches[0];
            
            // 计算移动距离
            const deltaX = Math.abs(touch.clientX - startPos.x);
            const deltaY = Math.abs(touch.clientY - startPos.y);
            
            // 如果移动超过阈值，认为是拖拽
            if (deltaX > moveThreshold || deltaY > moveThreshold) {
                hasMoved = true;
                
                // 计算新位置
                this.currentX = touch.clientX - this.startX;
                this.currentY = touch.clientY - this.startY;
                
                // 限制在屏幕范围内
                const maxX = window.innerWidth - 50;
                const maxY = window.innerHeight - 50;
                
                this.currentX = Math.max(0, Math.min(this.currentX, maxX));
                this.currentY = Math.max(0, Math.min(this.currentY, maxY));
                
                // 更新位置
                this.floatButton.style.left = this.currentX + 'px';
                this.floatButton.style.top = this.currentY + 'px';
                this.floatButton.style.right = 'auto';
                this.floatButton.style.bottom = 'auto';
                this.floatButton.style.transition = 'none';
            }
        });
        
        // 触摸结束
        this.floatButton.addEventListener('touchend', (e) => {
            e.preventDefault();
            this.floatButton.classList.remove('dragging');
            
            const touchDuration = Date.now() - startTime;
            
            // 如果没有移动且触摸时间很短，认为是点击
            if (!hasMoved && touchDuration < 300) {
                this.toggleDebugPanel();
            } else if (hasMoved) {
                // 如果发生了拖拽，吸附到边缘
                this.snapToEdge();
            }
        });
        
        // 鼠标事件（用于桌面测试）
        let mouseStartTime;
        let mouseStartPos = { x: 0, y: 0 };
        let mouseMoved = false;
        
        this.floatButton.addEventListener('mousedown', (e) => {
            e.preventDefault();
            mouseStartTime = Date.now();
            mouseMoved = false;
            
            mouseStartPos.x = e.clientX;
            mouseStartPos.y = e.clientY;
            
            // 记录当前位置
            const rect = this.floatButton.getBoundingClientRect();
            this.currentX = rect.left;
            this.currentY = rect.top;
            
            this.startX = e.clientX - this.currentX;
            this.startY = e.clientY - this.currentY;
            
            this.floatButton.classList.add('dragging');
            
            // 添加document级别的事件监听
            const handleMouseMove = (e) => {
                e.preventDefault();
                
                // 计算移动距离
                const deltaX = Math.abs(e.clientX - mouseStartPos.x);
                const deltaY = Math.abs(e.clientY - mouseStartPos.y);
                
                // 如果移动超过阈值，认为是拖拽
                if (deltaX > moveThreshold || deltaY > moveThreshold) {
                    mouseMoved = true;
                    
                    // 计算新位置
                    this.currentX = e.clientX - this.startX;
                    this.currentY = e.clientY - this.startY;
                    
                    // 限制在屏幕范围内
                    const maxX = window.innerWidth - 50;
                    const maxY = window.innerHeight - 50;
                    
                    this.currentX = Math.max(0, Math.min(this.currentX, maxX));
                    this.currentY = Math.max(0, Math.min(this.currentY, maxY));
                    
                    // 更新位置
                    this.floatButton.style.left = this.currentX + 'px';
                    this.floatButton.style.top = this.currentY + 'px';
                    this.floatButton.style.right = 'auto';
                    this.floatButton.style.bottom = 'auto';
                    this.floatButton.style.transition = 'none';
                }
            };
            
            const handleMouseUp = (e) => {
                e.preventDefault();
                this.floatButton.classList.remove('dragging');
                
                const mouseDuration = Date.now() - mouseStartTime;
                
                // 如果没有移动且点击时间很短，认为是点击
                if (!mouseMoved && mouseDuration < 300) {
                    this.toggleDebugPanel();
                } else if (mouseMoved) {
                    // 如果发生了拖拽，吸附到边缘
                    this.snapToEdge();
                }
                
                // 移除document级别的事件监听
                document.removeEventListener('mousemove', handleMouseMove);
                document.removeEventListener('mouseup', handleMouseUp);
            };
            
            document.addEventListener('mousemove', handleMouseMove);
            document.addEventListener('mouseup', handleMouseUp);
        });
    }
    
    // 吸附到边缘
    snapToEdge() {
        const rect = this.floatButton.getBoundingClientRect();
        const centerX = rect.left + rect.width / 2;
        const isLeftSide = centerX < window.innerWidth / 2;
        
        // 保持当前的垂直位置
        const currentTop = rect.top;
        
        this.floatButton.style.transition = 'all 0.3s ease';
        this.floatButton.style.bottom = 'auto';
        this.floatButton.style.top = currentTop + 'px';
        
        if (isLeftSide) {
            this.floatButton.style.left = '10px';
            this.floatButton.style.right = 'auto';
            this.currentX = 10;
        } else {
            this.floatButton.style.right = '10px';
            this.floatButton.style.left = 'auto';
            this.currentX = window.innerWidth - 60;
        }
        
        this.currentY = currentTop;
        
        // 震动反馈（如果支持）
        if (navigator.vibrate && document.getElementById('enableVibration')?.checked !== false) {
            navigator.vibrate(20);
        }
        
        setTimeout(() => {
            this.floatButton.style.transition = '';
        }, 300);
    }
    
    // 创建调试面板
    createDebugPanel() {
        this.debugPanel = document.createElement('div');
        this.debugPanel.id = 'mobile-debug-panel';
        this.debugPanel.style.cssText = `
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.95);
            z-index: 10000;
            display: none;
            overflow-y: auto;
            padding: 20px;
            box-sizing: border-box;
        `;
        
        this.debugPanel.innerHTML = `
            <div class="mobile-debug-content">
                <div class="debug-header">
                    <h2><i class="fas fa-bug"></i> 移动调试面板</h2>
                    <button class="close-btn" onclick="mobileDebug.hidePanel()">
                        <i class="fas fa-times"></i>
                    </button>
                </div>
                
                <div class="debug-sections">
                    <!-- 存档管理 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-save"></i> 存档管理</h3>
                        <div class="button-grid">
                            <button onclick="mobileDebug.exportSave()" class="debug-btn primary">
                                <i class="fas fa-download"></i> 导出存档
                            </button>
                            <button onclick="mobileDebug.importSave()" class="debug-btn">
                                <i class="fas fa-upload"></i> 导入存档
                            </button>
                            <button onclick="mobileDebug.restoreBackup()" class="debug-btn">
                                <i class="fas fa-history"></i> 恢复备份
                            </button>
                        </div>
                    </div>
                    
                    <!-- 快速操作 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-zap"></i> 快速操作</h3>
                        <div class="button-grid">
                            <button onclick="mobileDebug.exportLogs()" class="debug-btn">
                                <i class="fas fa-bug"></i> 导出日志
                            </button>
                            <button onclick="mobileDebug.showLogSummary()" class="debug-btn">
                                <i class="fas fa-list"></i> 日志摘要
                            </button>
                            <button onclick="mobileDebug.clearLogs()" class="debug-btn">
                                <i class="fas fa-trash"></i> 清空日志
                            </button>
                            <button onclick="mobileDebug.reloadGame()" class="debug-btn warning">
                                <i class="fas fa-redo"></i> 重新加载
                            </button>
                        </div>
                    </div>
                    
                    <!-- 系统信息 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-info-circle"></i> 系统信息</h3>
                        <div class="info-panel" id="mobile-system-info">
                            <p>正在加载系统信息...</p>
                        </div>
                    </div>
                    
                    <!-- 游戏状态 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-gamepad"></i> 游戏状态</h3>
                        <div class="info-panel" id="mobile-game-state">
                            <p>正在加载游戏状态...</p>
                        </div>
                    </div>
                    
                    <!-- 日志摘要 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-clipboard-list"></i> 日志摘要</h3>
                        <div class="info-panel" id="mobile-log-summary">
                            <p>点击"日志摘要"查看详情</p>
                        </div>
                    </div>
                    
                    <!-- 调试选项 -->
                    <div class="debug-section">
                        <h3><i class="fas fa-cog"></i> 调试选项</h3>
                        <div class="option-list">
                            <label class="debug-option">
                                <input type="checkbox" id="enableVibration" checked>
                                <span>启用震动反馈</span>
                            </label>
                            <label class="debug-option">
                                <input type="checkbox" id="autoRefresh">
                                <span>自动刷新信息</span>
                            </label>
                            <label class="debug-option">
                                <input type="checkbox" id="verboseLogging">
                                <span>详细日志模式</span>
                            </label>
                        </div>
                    </div>
                </div>
            </div>
        `;
        
        document.body.appendChild(this.debugPanel);
        this.addPanelStyles();
    }
    
    // 添加面板样式
    addPanelStyles() {
        const style = document.createElement('style');
        style.textContent = `
            .mobile-debug-content {
                max-width: 100%;
                color: #fff;
                font-family: 'Orbitron', monospace;
            }
            
            .debug-header {
                display: flex;
                justify-content: space-between;
                align-items: center;
                padding: 0 0 20px 0;
                border-bottom: 2px solid #00d4ff;
                margin-bottom: 20px;
            }
            
            .debug-header h2 {
                color: #00d4ff;
                font-size: 1.5rem;
                margin: 0;
            }
            
            .close-btn {
                background: #ff6b6b;
                color: white;
                border: none;
                width: 40px;
                height: 40px;
                border-radius: 50%;
                font-size: 18px;
                cursor: pointer;
                display: flex;
                align-items: center;
                justify-content: center;
            }
            
            .debug-section {
                background: rgba(20, 20, 30, 0.8);
                border: 1px solid rgba(0, 212, 255, 0.3);
                border-radius: 10px;
                padding: 15px;
                margin-bottom: 15px;
            }
            
            .debug-section h3 {
                color: #00d4ff;
                font-size: 1.2rem;
                margin: 0 0 15px 0;
                display: flex;
                align-items: center;
                gap: 8px;
            }
            
            .button-grid {
                display: grid;
                grid-template-columns: 1fr 1fr;
                gap: 10px;
            }
            
            .debug-btn {
                background: linear-gradient(145deg, #444, #333);
                color: white;
                border: 1px solid #666;
                padding: 12px 8px;
                border-radius: 8px;
                font-size: 0.9rem;
                cursor: pointer;
                display: flex;
                flex-direction: column;
                align-items: center;
                gap: 5px;
                transition: all 0.3s ease;
            }
            
            .debug-btn.primary {
                background: linear-gradient(145deg, #00d4ff, #0099cc);
                border-color: #00d4ff;
            }
            
            .debug-btn.warning {
                background: linear-gradient(145deg, #ff6b6b, #ee5a52);
                border-color: #ff6b6b;
            }
            
            .debug-btn:active {
                transform: scale(0.95);
            }
            
            .info-panel {
                background: rgba(0, 0, 0, 0.5);
                border: 1px solid rgba(0, 212, 255, 0.2);
                border-radius: 8px;
                padding: 15px;
                font-family: 'Courier New', monospace;
                font-size: 0.85rem;
                line-height: 1.6;
                max-height: 300px;
                overflow-y: auto;
            }
            
            .info-panel p {
                margin: 4px 0;
                display: flex;
                justify-content: space-between;
                align-items: center;
                padding: 2px 0;
                border-bottom: 1px solid rgba(255, 255, 255, 0.05);
            }
            
            .info-panel p:last-child {
                border-bottom: none;
            }
            
            .info-panel strong {
                color: #00d4ff;
                font-weight: normal;
                margin-right: 10px;
                flex-shrink: 0;
            }
            
            .option-list {
                display: flex;
                flex-direction: column;
                gap: 12px;
            }
            
            .debug-option {
                display: flex;
                align-items: center;
                gap: 10px;
                font-size: 0.9rem;
                cursor: pointer;
            }
            
            .debug-option input[type="checkbox"] {
                width: 18px;
                height: 18px;
                accent-color: #00d4ff;
            }
            
            /* 滚动条样式 */
            .info-panel::-webkit-scrollbar {
                width: 6px;
            }
            
            .info-panel::-webkit-scrollbar-track {
                background: rgba(0, 0, 0, 0.2);
                border-radius: 3px;
            }
            
            .info-panel::-webkit-scrollbar-thumb {
                background: #00d4ff;
                border-radius: 3px;
            }
        `;
        document.head.appendChild(style);
    }
    
    // 显示/隐藏调试面板
    toggleDebugPanel() {
        if (this.isVisible) {
            this.hidePanel();
        } else {
            this.showPanel();
        }
    }
    
    // 显示面板
    showPanel() {
        this.isVisible = true;
        this.debugPanel.style.display = 'block';
        this.floatButton.style.display = 'none';
        this.updateSystemInfo();
        this.updateGameState();
        
        // 震动反馈
        if (navigator.vibrate && document.getElementById('enableVibration')?.checked) {
            navigator.vibrate(30);
        }
    }
    
    // 隐藏面板
    hidePanel() {
        this.isVisible = false;
        this.debugPanel.style.display = 'none';
        this.floatButton.style.display = 'flex';
    }
    
    // 更新系统信息
    updateSystemInfo() {
        const info = {
            platform: navigator.platform,
            language: navigator.language,
            languages: navigator.languages ? navigator.languages.join(', ') : navigator.language,
            onLine: navigator.onLine ? '在线' : '离线',
            screenSize: `${screen.width}x${screen.height}`,
            windowSize: `${window.innerWidth}x${window.innerHeight}`,
            availScreenSize: `${screen.availWidth}x${screen.availHeight}`,
            pixelRatio: window.devicePixelRatio,
            colorDepth: screen.colorDepth + ' bit',
            orientation: screen.orientation ? screen.orientation.type : '未知',
            touchSupport: 'ontouchstart' in window ? '支持' : '不支持',
            touchPoints: navigator.maxTouchPoints || 0,
            localStorage: this.checkLocalStorageAvailable(),
            sessionStorage: this.checkSessionStorageAvailable(),
            cookies: navigator.cookieEnabled ? '启用' : '禁用',
            doNotTrack: navigator.doNotTrack || '未设置',
            hardwareConcurrency: navigator.hardwareConcurrency || '未知',
            deviceMemory: navigator.deviceMemory ? navigator.deviceMemory + ' GB' : '未知',
            connection: this.getConnectionInfo(),
            battery: '检测中...',
            webGL: this.checkWebGLSupport(),
            serviceWorker: 'serviceWorker' in navigator ? '支持' : '不支持',
            webRTC: this.checkWebRTCSupport(),
            permissions: '检测中...'
        };
        
        // 增强的浏览器信息
        const ua = navigator.userAgent;
        const browserInfo = this.getBrowserInfo(ua);
        info.browser = browserInfo.name + ' ' + browserInfo.version;
        info.browserEngine = browserInfo.engine;
        info.os = browserInfo.os;
        info.device = browserInfo.device;
        info.userAgent = ua.substring(0, 100) + '...';
        
        // 检查电池状态
        if ('getBattery' in navigator) {
            navigator.getBattery().then(battery => {
                const batteryInfo = `${Math.floor(battery.level * 100)}% ${battery.charging ? '(充电中)' : ''}`;
                const batteryElements = document.querySelectorAll('#mobile-system-info p');
                for (let elem of batteryElements) {
                    if (elem.innerHTML.includes('电池:')) {
                        elem.innerHTML = `<strong>电池:</strong> ${batteryInfo}`;
                        break;
                    }
                }
            }).catch(() => {
                const batteryElements = document.querySelectorAll('#mobile-system-info p');
                for (let elem of batteryElements) {
                    if (elem.innerHTML.includes('电池:')) {
                        elem.innerHTML = `<strong>电池:</strong> 不支持`;
                        break;
                    }
                }
            });
        }
        
        // 检查权限状态
        this.checkPermissions().then(perms => {
            const permElements = document.querySelectorAll('#mobile-system-info p');
            for (let elem of permElements) {
                if (elem.innerHTML.includes('权限:')) {
                    elem.innerHTML = `<strong>权限:</strong> ${perms}`;
                    break;
                }
            }
        });
        
        const infoHtml = Object.entries(info).map(([key, value]) => 
            `<p><strong>${this.translateInfoKey(key)}:</strong> ${value}</p>`
        ).join('');
        
        document.getElementById('mobile-system-info').innerHTML = infoHtml;
    }
    
    // 翻译信息键名
    translateInfoKey(key) {
        const translations = {
            platform: '平台',
            language: '语言',
            languages: '语言列表',
            onLine: '网络状态',
            screenSize: '屏幕尺寸',
            windowSize: '窗口尺寸',
            availScreenSize: '可用屏幕',
            pixelRatio: '像素比',
            colorDepth: '颜色深度',
            orientation: '屏幕方向',
            touchSupport: '触摸支持',
            touchPoints: '触摸点数',
            localStorage: '本地存储',
            sessionStorage: '会话存储',
            cookies: 'Cookie',
            browser: '浏览器',
            browserEngine: '浏览器引擎',
            os: '操作系统',
            device: '设备类型',
            userAgent: 'User Agent',
            doNotTrack: 'DNT设置',
            hardwareConcurrency: 'CPU核心数',
            deviceMemory: '设备内存',
            connection: '网络连接',
            battery: '电池',
            webGL: 'WebGL',
            serviceWorker: 'Service Worker',
            webRTC: 'WebRTC',
            permissions: '权限'
        };
        return translations[key] || key;
    }
    
    // 更新游戏状态
    updateGameState() {
        try {
            const gameInfo = {};
            
            if (typeof player !== 'undefined' && player) {
                gameInfo.playerName = player.name || '未知';
                gameInfo.playerLevel = player.lvl || 1;
                gameInfo.playerGold = player.gold || 0;
                gameInfo.playerHP = `${player.stats?.hp || 0}/${player.stats?.hpMax || 0}`;
                gameInfo.allocated = player.allocated ? '是' : '否';
            }
            
            if (typeof dungeon !== 'undefined' && dungeon) {
                gameInfo.dungeonFloor = dungeon.floor || 1;
                gameInfo.dungeonRoom = dungeon.room || 1;
                gameInfo.exploring = dungeon.status?.exploring ? '是' : '否';
            }
            
            const savedData = localStorage.getItem('playerData');
            gameInfo.savedDataSize = savedData ? `${(savedData.length / 1024).toFixed(1)}KB` : '无';
            
            const gameHtml = Object.entries(gameInfo).map(([key, value]) => 
                `<p><strong>${key}:</strong> ${value}</p>`
            ).join('');
            
            document.getElementById('mobile-game-state').innerHTML = gameHtml || '<p>游戏数据未加载</p>';
            
        } catch (error) {
            document.getElementById('mobile-game-state').innerHTML = `<p>获取游戏状态失败: ${error.message}</p>`;
        }
    }
    
    // 检查localStorage可用性
    checkLocalStorageAvailable() {
        try {
            const test = '__test__';
            localStorage.setItem(test, test);
            localStorage.removeItem(test);
            return '可用';
        } catch (e) {
            return `不可用: ${e.message}`;
        }
    }
    
    // 检查sessionStorage可用性
    checkSessionStorageAvailable() {
        try {
            const test = '__test__';
            sessionStorage.setItem(test, test);
            sessionStorage.removeItem(test);
            return '可用';
        } catch (e) {
            return `不可用`;
        }
    }
    
    // 获取浏览器详细信息
    getBrowserInfo(ua) {
        const info = {
            name: '未知',
            version: '',
            engine: '未知',
            os: '未知',
            device: '未知'
        };
        
        // 检测浏览器
        if (ua.includes('Chrome/') && !ua.includes('Edg/')) {
            info.name = 'Chrome';
            info.version = ua.match(/Chrome\/(\d+\.\d+)/)?.[1] || '';
            info.engine = 'Blink';
        } else if (ua.includes('Safari/') && !ua.includes('Chrome')) {
            info.name = 'Safari';
            info.version = ua.match(/Version\/(\d+\.\d+)/)?.[1] || '';
            info.engine = 'WebKit';
        } else if (ua.includes('Firefox/')) {
            info.name = 'Firefox';
            info.version = ua.match(/Firefox\/(\d+\.\d+)/)?.[1] || '';
            info.engine = 'Gecko';
        } else if (ua.includes('Edg/')) {
            info.name = 'Edge';
            info.version = ua.match(/Edg\/(\d+\.\d+)/)?.[1] || '';
            info.engine = 'Blink';
        } else if (ua.includes('OPR/') || ua.includes('Opera/')) {
            info.name = 'Opera';
            info.version = ua.match(/(?:OPR|Opera)\/(\d+\.\d+)/)?.[1] || '';
            info.engine = 'Blink';
        }
        
        // 检测操作系统
        if (ua.includes('Windows NT')) {
            const version = ua.match(/Windows NT (\d+\.\d+)/)?.[1];
            const winVersions = {
                '10.0': 'Windows 10/11',
                '6.3': 'Windows 8.1',
                '6.2': 'Windows 8',
                '6.1': 'Windows 7'
            };
            info.os = winVersions[version] || 'Windows';
        } else if (ua.includes('Mac OS X')) {
            info.os = 'macOS';
            const version = ua.match(/Mac OS X (\d+[_\.]\d+)/)?.[1]?.replace('_', '.');
            if (version) info.os += ' ' + version;
        } else if (ua.includes('Android')) {
            info.os = 'Android';
            const version = ua.match(/Android (\d+\.\d+)/)?.[1];
            if (version) info.os += ' ' + version;
        } else if (ua.includes('iPhone') || ua.includes('iPad')) {
            info.os = 'iOS';
            const version = ua.match(/OS (\d+_\d+)/)?.[1]?.replace('_', '.');
            if (version) info.os += ' ' + version;
        } else if (ua.includes('Linux')) {
            info.os = 'Linux';
        }
        
        // 检测设备类型
        if (ua.includes('Mobile')) {
            info.device = '移动设备';
        } else if (ua.includes('Tablet') || ua.includes('iPad')) {
            info.device = '平板电脑';
        } else {
            info.device = '桌面设备';
        }
        
        return info;
    }
    
    // 获取网络连接信息
    getConnectionInfo() {
        if ('connection' in navigator || 'mozConnection' in navigator || 'webkitConnection' in navigator) {
            const connection = navigator.connection || navigator.mozConnection || navigator.webkitConnection;
            if (connection) {
                const type = connection.effectiveType || connection.type || '未知';
                const downlink = connection.downlink ? `${connection.downlink}Mbps` : '';
                const rtt = connection.rtt ? `${connection.rtt}ms` : '';
                return `${type} ${downlink} ${rtt}`.trim();
            }
        }
        return '未知';
    }
    
    // 检查WebGL支持
    checkWebGLSupport() {
        try {
            const canvas = document.createElement('canvas');
            const gl = canvas.getContext('webgl') || canvas.getContext('experimental-webgl');
            if (gl) {
                const debugInfo = gl.getExtension('WEBGL_debug_renderer_info');
                if (debugInfo) {
                    const renderer = gl.getParameter(debugInfo.UNMASKED_RENDERER_WEBGL);
                    return `支持 (${renderer})`;
                }
                return '支持';
            }
        } catch (e) {}
        return '不支持';
    }
    
    // 检查WebRTC支持
    checkWebRTCSupport() {
        if ('RTCPeerConnection' in window || 'webkitRTCPeerConnection' in window || 'mozRTCPeerConnection' in window) {
            return '支持';
        }
        return '不支持';
    }
    
    // 检查权限状态
    async checkPermissions() {
        const permissions = [];
        const permissionNames = ['camera', 'microphone', 'geolocation', 'notifications'];
        
        if ('permissions' in navigator) {
            for (const name of permissionNames) {
                try {
                    const result = await navigator.permissions.query({ name });
                    if (result.state === 'granted') {
                        permissions.push(name);
                    }
                } catch (e) {}
            }
        }
        
        return permissions.length > 0 ? permissions.join(', ') : '无';
    }
    
    // 导出日志
    exportLogs() {
        if (typeof exportLogsForMobile === 'function') {
            exportLogsForMobile();
        } else if (window.debugLogger) {
            window.debugLogger.exportLogs();
        } else {
            alert('日志系统未初始化');
        }
    }
    
    // 显示日志摘要
    showLogSummary() {
        try {
            if (window.debugLogger) {
                const summary = window.debugLogger.getSummary();
                const summaryHtml = `
                    <p><strong>总日志数:</strong> ${summary.totalLogs}</p>
                    <p><strong>错误数:</strong> ${summary.errors}</p>
                    <p><strong>警告数:</strong> ${summary.warnings}</p>
                    ${summary.recentErrors.length > 0 ? `
                        <p><strong>最近错误:</strong></p>
                        ${summary.recentErrors.slice(0, 3).map(error => 
                            `<p style="color: #ff6b6b; font-size: 0.8rem;">• ${error.message.substring(0, 80)}...</p>`
                        ).join('')}
                    ` : '<p>暂无错误</p>'}
                `;
                
                document.getElementById('mobile-log-summary').innerHTML = summaryHtml;
            }
        } catch (error) {
            document.getElementById('mobile-log-summary').innerHTML = `<p>获取日志摘要失败: ${error.message}</p>`;
        }
    }
    
    // 清空日志
    clearLogs() {
        if (confirm('确定要清空所有日志吗？')) {
            if (window.debugLogger) {
                window.debugLogger.clearLogs();
                this.showLogSummary();
                alert('日志已清空');
            }
        }
    }
    
    // 重新加载游戏
    reloadGame() {
        if (confirm('确定要重新加载游戏吗？')) {
            window.location.reload();
        }
    }
    
    // 导出存档
    exportSave() {
        try {
            if (window.saveManager) {
                window.saveManager.exportSave();
                this.hidePanel();
            } else {
                alert('存档管理系统未初始化');
            }
        } catch (error) {
            console.error('导出存档失败:', error);
            alert('导出存档失败: ' + error.message);
        }
    }
    
    // 导入存档
    importSave() {
        try {
            if (window.saveManager) {
                this.hidePanel();
                window.saveManager.showImportInterface();
            } else {
                alert('存档管理系统未初始化');
            }
        } catch (error) {
            console.error('导入存档失败:', error);
            alert('导入存档失败: ' + error.message);
        }
    }
    
    // 恢复备份
    restoreBackup() {
        try {
            if (window.saveManager) {
                const result = window.saveManager.restoreBackup();
                if (result) {
                    this.hidePanel();
                }
            } else {
                alert('存档管理系统未初始化');
            }
        } catch (error) {
            console.error('恢复备份失败:', error);
            alert('恢复备份失败: ' + error.message);
        }
    }
}

// 创建全局实例
window.mobileDebug = new MobileDebugFloat();

console.log('[Mobile Debug] Debug float initialized, visible:', window.mobileDebug.isDebugMode);