// ========== 存档管理系统 ==========

class SaveManager {
    constructor() {
        this.version = '1.4.0';
        this.supportedVersions = ['1.4.0', '1.3.0', '1.2.0']; // 支持的存档版本
    }
    
    // 导出完整存档
    exportSave() {
        try {
            const saveData = this.collectAllGameData();
            const exportData = {
                version: this.version,
                exportTime: new Date().toISOString(),
                gameData: saveData,
                checksum: this.generateChecksum(saveData)
            };
            
            const dataStr = JSON.stringify(exportData, null, 2);
            const fileName = `深空探索者-存档-${this.formatDate()}.json`;
            
            if (this.isMobileDevice()) {
                this.exportForMobile(dataStr, fileName, exportData);
            } else {
                this.exportForDesktop(dataStr, fileName);
            }
            
            logGameEvent('Save Export', `Export completed, size: ${dataStr.length} bytes`);
            return exportData;
            
        } catch (error) {
            console.error('导出存档失败:', error);
            alert('导出存档失败: ' + error.message);
            throw error;
        }
    }
    
    // 收集所有游戏数据
    collectAllGameData() {
        const gameData = {};
        
        // 收集所有localStorage中的游戏数据（排除临时和调试数据）
        const gameKeys = [
            'playerData',
            'dungeonData', 
            'shopPurchaseHistory',
            'volume',
            'theme',
            'achievements',
            'statistics'
        ];
        
        // 排除的临时数据和调试数据
        const excludeKeys = [
            'backlog',
            'debugLogs',
            'errorLogs',
            'tempData',
            'sessionData',
            'mobileDebug',
            'saveBackup',  // 备份数据也不包含在导出中
            'privacyConsent', // 隐私同意不需要导出
            'gameSettings', // 游戏设置通常包含在其他数据中
            'tutorials' // 教程进度不需要导出
        ];
        
        gameKeys.forEach(key => {
            const value = localStorage.getItem(key);
            if (value !== null) {
                try {
                    // 尝试解析JSON，如果失败则保存原始字符串
                    gameData[key] = JSON.parse(value);
                } catch (e) {
                    gameData[key] = value;
                }
            }
        });
        
        // 优化玩家数据
        if (gameData.playerData) {
            gameData.playerData = this.optimizePlayerData(gameData.playerData);
        }
        
        // 优化地牢数据
        if (gameData.dungeonData) {
            gameData.dungeonData = this.optimizeDungeonData(gameData.dungeonData);
        }
        
        return gameData;
    }
    
    // 序列化玩家数据
    serializePlayer(playerObj) {
        const playerData = JSON.parse(JSON.stringify(playerObj)); // 深拷贝
        
        // 确保所有重要字段都被包含
        const requiredFields = [
            'name', 'lvl', 'exp', 'gold', 'allocated', 'inCombat',
            'stats', 'baseStats', 'equippedStats', 'bonusStats',
            'inventory', 'equipped', 'skills', 'tempBuffs'
        ];
        
        // 排除临时和调试相关的字段
        const excludeFields = [
            'backlog',
            'debugInfo', 
            'tempLogs',
            'sessionId',
            'lastError',
            'pendingDeathPenalty' // 死亡惩罚应该在存档时就处理完毕
        ];
        
        requiredFields.forEach(field => {
            if (!(field in playerData)) {
                console.warn(`玩家数据缺少字段: ${field}`);
            }
        });
        
        // 移除不需要的字段
        excludeFields.forEach(field => {
            if (field in playerData) {
                delete playerData[field];
                console.log(`已从存档中排除玩家字段: ${field}`);
            }
        });
        
        // 清理临时buff数据中的过期项
        if (playerData.tempBuffs) {
            const now = Date.now();
            Object.keys(playerData.tempBuffs).forEach(buffId => {
                const buff = playerData.tempBuffs[buffId];
                if (buff.endTime && buff.endTime < now) {
                    delete playerData.tempBuffs[buffId];
                }
            });
        }
        
        return playerData;
    }
    
    // 序列化地牢数据
    serializeDungeon(dungeonObj) {
        const dungeonData = JSON.parse(JSON.stringify(dungeonObj)); // 深拷贝
        
        // 确保重要字段都被包含
        const requiredFields = [
            'floor', 'room', 'status', 'progress', 'settings'
        ];
        
        // 排除临时和不必要的字段
        const excludeFields = [
            'tempEvents',
            'lastEventLog',
            'sessionStats',
            'debugInfo',
            'backlog',
            'currentEnemy', // 当前敌人信息不需要保存
            'combatLog'     // 战斗日志不需要保存
        ];
        
        requiredFields.forEach(field => {
            if (!(field in dungeonData)) {
                console.warn(`地牢数据缺少字段: ${field}`);
            }
        });
        
        // 移除不需要的字段
        excludeFields.forEach(field => {
            if (field in dungeonData) {
                delete dungeonData[field];
                console.log(`已从存档中排除地牢字段: ${field}`);
            }
        });
        
        // 清理状态中的临时数据
        if (dungeonData.status) {
            // 重置一些应该重新开始的状态
            delete dungeonData.status.tempMessage;
            delete dungeonData.status.lastAction;
        }
        
        return dungeonData;
    }
    
    // 优化玩家数据（移除冗余字段）
    optimizePlayerData(playerData) {
        if (!playerData) return playerData;
        
        const optimized = { ...playerData };
        
        // 移除计算字段（这些可以从其他数据计算得出）
        const removeFields = [
            'hpPercent', // 可以从hp/hpMax计算
            'expPercent', // 可以从exp计算
            'tempStats', // 临时状态不需要保存
            'backlog', // 战斗日志
            'combatHistory', // 战斗历史
            'sessionStats', // 会话统计
            'lastUpdate', // 最后更新时间
            'debugInfo' // 调试信息
        ];
        
        removeFields.forEach(field => {
            if (optimized.stats && field in optimized.stats) {
                delete optimized.stats[field];
            }
            if (optimized.exp && field in optimized.exp) {
                delete optimized.exp[field];
            }
            if (field in optimized) {
                delete optimized[field];
            }
        });
        
        // 确保装备数据是对象格式而不是字符串
        if (optimized.inventory && optimized.inventory.equipment) {
            optimized.inventory.equipment = optimized.inventory.equipment.map(item => {
                if (typeof item === 'string') {
                    try {
                        return JSON.parse(item);
                    } catch (e) {
                        return item;
                    }
                }
                return item;
            });
        }
        
        return optimized;
    }
    
    // 优化地牢数据（移除冗余字段）
    optimizeDungeonData(dungeonData) {
        if (!dungeonData) return dungeonData;
        
        const optimized = { ...dungeonData };
        
        // 移除不必要的字段
        const removeFields = [
            'backlog', // 战斗日志不需要保存（太大）
            'currentEnemy', // 当前敌人
            'combatLog', // 战斗日志
            'tempEvents', // 临时事件
            'sessionData', // 会话数据
            'lastUpdate' // 最后更新时间
        ];
        
        removeFields.forEach(field => {
            if (field in optimized) {
                delete optimized[field];
            }
        });
        
        // 限制backlog大小（如果必须保留）
        if (optimized.backlog && Array.isArray(optimized.backlog)) {
            optimized.backlog = optimized.backlog.slice(-20); // 只保留最后20条
        }
        
        return optimized;
    }
    
    // 生成存档内容摘要
    generateSaveSummary(gameData) {
        const summary = [];
        
        // 玩家信息
        if (gameData.playerData) {
            try {
                const player = typeof gameData.playerData === 'string' ? 
                    JSON.parse(gameData.playerData) : gameData.playerData;
                summary.push(`• 玩家: ${player.name || '未知'} (Lv.${player.lvl || 1})`);
                summary.push(`• 金币: ${player.gold || 0}`);
            } catch (e) {
                summary.push('• 玩家数据: 已包含');
            }
        }
        
        // 地牢进度
        if (gameData.dungeonData) {
            try {
                const dungeon = typeof gameData.dungeonData === 'string' ? 
                    JSON.parse(gameData.dungeonData) : gameData.dungeonData;
                summary.push(`• 地牢进度: 第${dungeon.floor || 1}层`);
            } catch (e) {
                summary.push('• 地牢数据: 已包含');
            }
        }
        
        // 其他数据
        const dataTypes = {
            'shopPurchaseHistory': '商店购买记录',
            'volume': '音量设置',
            'theme': '主题设置',
            'achievements': '成就数据',
            'statistics': '统计数据'
        };
        
        Object.keys(dataTypes).forEach(key => {
            if (gameData[key]) {
                summary.push(`• ${dataTypes[key]}: 已包含`);
            }
        });
        
        return summary.length > 0 ? summary.join('<br>') : '• 基础游戏数据';
    }
    
    // 生成校验和
    generateChecksum(data) {
        const str = JSON.stringify(data);
        let hash = 0;
        for (let i = 0; i < str.length; i++) {
            const char = str.charCodeAt(i);
            hash = ((hash << 5) - hash) + char;
            hash = hash & hash; // 转换为32位整数
        }
        return hash.toString(16);
    }
    
    // 格式化日期
    formatDate() {
        const now = new Date();
        return now.toISOString().replace(/[:.]/g, '-').split('T')[0] + '_' + 
               now.toTimeString().split(' ')[0].replace(/:/g, '-');
    }
    
    // 检测移动设备
    isMobileDevice() {
        return /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
    }
    
    // 桌面端导出
    exportForDesktop(dataStr, fileName) {
        const dataBlob = new Blob([dataStr], { type: 'application/json' });
        const url = URL.createObjectURL(dataBlob);
        const link = document.createElement('a');
        link.href = url;
        link.download = fileName;
        
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
        
        URL.revokeObjectURL(url);
        
        console.log('存档已导出:', fileName);
        if (typeof addDungeonLog === 'function') {
            addDungeonLog(`<i class="fas fa-download"></i> 存档已导出: ${fileName}`);
        }
    }
    
    // 移动端导出
    exportForMobile(dataStr, fileName, exportData) {
        const modal = document.createElement('div');
        modal.style.cssText = `
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0,0,0,0.9);
            z-index: 10001;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 20px;
            box-sizing: border-box;
        `;
        
        const content = document.createElement('div');
        content.style.cssText = `
            background: #1a1a2e;
            border: 2px solid #00d4ff;
            border-radius: 15px;
            padding: 25px;
            max-width: 90%;
            max-height: 90%;
            overflow-y: auto;
            color: #fff;
            font-family: 'Orbitron', monospace;
        `;
        
        content.innerHTML = `
            <h3 style="color: #00d4ff; margin-bottom: 20px; text-align: center;">
                <i class="fas fa-download"></i> 存档导出
            </h3>
            <div style="margin-bottom: 15px;">
                <p><strong>文件名:</strong> ${fileName}</p>
                <p><strong>数据大小:</strong> ${(dataStr.length / 1024).toFixed(1)} KB</p>
                <p><strong>导出时间:</strong> ${new Date().toLocaleString()}</p>
                <p><strong>校验码:</strong> ${exportData.checksum}</p>
            </div>
            <p style="margin-bottom: 15px; color: #ffa726;">
                请复制下方存档数据并保存到文本文件中：
            </p>
            <textarea id="saveDataArea" style="
                width: 100%;
                height: 200px;
                background: #0f0f23;
                color: #00ff7f;
                border: 1px solid #00d4ff;
                border-radius: 8px;
                padding: 15px;
                font-family: 'Courier New', monospace;
                font-size: 11px;
                margin: 10px 0;
                resize: vertical;
            " readonly>${dataStr}</textarea>
            <div style="text-align: center; margin-top: 20px;">
                <button id="copySaveBtn" style="
                    background: linear-gradient(145deg, #00d4ff, #0099cc);
                    color: white;
                    border: none;
                    padding: 12px 25px;
                    border-radius: 8px;
                    margin-right: 15px;
                    cursor: pointer;
                    font-size: 16px;
                "><i class="fas fa-copy"></i> 复制存档</button>
                <button id="closeSaveModal" style="
                    background: linear-gradient(145deg, #666, #444);
                    color: white;
                    border: none;
                    padding: 12px 25px;
                    border-radius: 8px;
                    cursor: pointer;
                    font-size: 16px;
                "><i class="fas fa-times"></i> 关闭</button>
            </div>
        `;
        
        modal.appendChild(content);
        document.body.appendChild(modal);
        
        // 复制功能
        document.getElementById('copySaveBtn').onclick = () => {
            const textarea = document.getElementById('saveDataArea');
            textarea.select();
            textarea.setSelectionRange(0, 99999);
            
            try {
                document.execCommand('copy');
                alert('存档数据已复制到剪贴板！请粘贴到文本文件中保存。');
                if (typeof addDungeonLog === 'function') {
                    addDungeonLog(`<i class="fas fa-copy"></i> 存档数据已复制到剪贴板`);
                }
            } catch (err) {
                console.error('复制失败:', err);
                alert('复制失败，请手动选择文本复制');
            }
        };
        
        // 关闭功能
        document.getElementById('closeSaveModal').onclick = () => {
            document.body.removeChild(modal);
        };
        
        modal.onclick = (e) => {
            if (e.target === modal) {
                document.body.removeChild(modal);
            }
        };
    }
    
    // 导入存档
    importSave(fileContent) {
        try {
            let importData;
            
            // 尝试解析JSON数据
            try {
                importData = JSON.parse(fileContent);
            } catch (e) {
                throw new Error('存档文件格式无效，请确保是有效的JSON格式');
            }
            
            // 验证存档格式
            if (!this.validateSaveFormat(importData)) {
                throw new Error('存档文件格式不正确或已损坏');
            }
            
            // 版本兼容性检查
            if (!this.isVersionSupported(importData.version)) {
                const proceed = confirm(
                    `存档版本 ${importData.version} 可能不完全兼容当前游戏版本 ${this.version}。\n` +
                    `是否继续导入？可能会丢失部分数据或功能。`
                );
                if (!proceed) {
                    return false;
                }
            }
            
            // 校验和验证
            const calculatedChecksum = this.generateChecksum(importData.gameData);
            if (importData.checksum !== calculatedChecksum) {
                const proceed = confirm(
                    '存档文件校验失败，数据可能已损坏或被修改。\n' +
                    '是否继续导入？这可能导致游戏不稳定。'
                );
                if (!proceed) {
                    return false;
                }
            }
            
            // 备份当前存档
            this.backupCurrentSave();
            
            // 导入数据
            this.restoreGameData(importData.gameData);
            
            logGameEvent('Save Import', `Import completed, version: ${importData.version}`);
            
            // 显示成功信息
            alert(
                '存档导入成功！\n' +
                `导入时间: ${importData.exportTime}\n` +
                `存档版本: ${importData.version}\n` +
                '\n游戏将在3秒后重新加载以应用新存档。'
            );
            
            if (typeof addDungeonLog === 'function') {
                addDungeonLog(`<i class="fas fa-upload"></i> 存档导入成功，游戏即将重新加载`);
            }
            
            // 延迟重新加载
            setTimeout(() => {
                window.location.reload();
            }, 3000);
            
            return true;
            
        } catch (error) {
            console.error('导入存档失败:', error);
            alert('导入存档失败: ' + error.message);
            return false;
        }
    }
    
    // 验证存档格式
    validateSaveFormat(importData) {
        // 检查必需字段
        const requiredFields = ['version', 'exportTime', 'gameData', 'checksum'];
        for (let field of requiredFields) {
            if (!(field in importData)) {
                console.error(`存档缺少必需字段: ${field}`);
                return false;
            }
        }
        
        // 检查gameData是否为对象
        if (typeof importData.gameData !== 'object' || importData.gameData === null) {
            console.error('gameData字段格式无效');
            return false;
        }
        
        return true;
    }
    
    // 检查版本支持
    isVersionSupported(version) {
        return this.supportedVersions.includes(version);
    }
    
    // 备份当前存档
    backupCurrentSave() {
        try {
            const currentSave = this.collectAllGameData();
            const backupData = {
                version: this.version,
                backupTime: new Date().toISOString(),
                gameData: currentSave
            };
            
            localStorage.setItem('saveBackup', JSON.stringify(backupData));
            console.log('当前存档已备份');
            
        } catch (error) {
            console.error('备份当前存档失败:', error);
        }
    }
    
    // 恢复游戏数据
    restoreGameData(gameData) {
        // 清空当前localStorage中的游戏数据
        const gameKeys = [
            'playerData', 'dungeonData', 'shopPurchaseHistory',
            'volume', 'theme', 'privacyConsent', 'gameSettings',
            'achievements', 'statistics', 'tutorials'
        ];
        
        gameKeys.forEach(key => {
            localStorage.removeItem(key);
        });
        
        // 处理数据兼容性
        let processedData = { ...gameData };
        
        // 如果存档中有currentPlayer但没有playerData，进行转换
        if (gameData.currentPlayer && !gameData.playerData) {
            processedData.playerData = gameData.currentPlayer;
            console.log('已将currentPlayer转换为playerData');
        }
        
        // 如果存档中有currentDungeon但没有dungeonData，进行转换
        if (gameData.currentDungeon && !gameData.dungeonData) {
            processedData.dungeonData = gameData.currentDungeon;
            console.log('已将currentDungeon转换为dungeonData');
        }
        
        // 修复装备数据格式问题
        if (processedData.playerData && processedData.playerData.inventory && processedData.playerData.inventory.equipment) {
            processedData.playerData.inventory.equipment = processedData.playerData.inventory.equipment.map(item => {
                // 如果装备是字符串格式的JSON，解析它
                if (typeof item === 'string') {
                    try {
                        return JSON.parse(item);
                    } catch (e) {
                        console.warn('解析装备数据失败:', item);
                        return item;
                    }
                }
                return item;
            });
            console.log('已修复装备数据格式');
        }
        
        // 恢复数据
        Object.keys(processedData).forEach(key => {
            // 跳过临时字段
            if (key === 'currentPlayer' || key === 'currentDungeon') {
                return;
            }
            
            const value = processedData[key];
            if (value !== null && value !== undefined) {
                const dataStr = typeof value === 'string' ? value : JSON.stringify(value);
                localStorage.setItem(key, dataStr);
            }
        });
        
        console.log('游戏数据恢复完成');
    }
    
    // 恢复备份存档
    restoreBackup() {
        try {
            const backupStr = localStorage.getItem('saveBackup');
            if (!backupStr) {
                alert('没有找到备份存档');
                return false;
            }
            
            const backupData = JSON.parse(backupStr);
            
            const proceed = confirm(
                `确定要恢复备份存档吗？\n` +
                `备份时间: ${new Date(backupData.backupTime).toLocaleString()}\n` +
                `当前进度将被覆盖！`
            );
            
            if (proceed) {
                this.restoreGameData(backupData.gameData);
                alert('备份存档已恢复，游戏将重新加载');
                setTimeout(() => {
                    window.location.reload();
                }, 2000);
                return true;
            }
            
        } catch (error) {
            console.error('恢复备份失败:', error);
            alert('恢复备份失败: ' + error.message);
        }
        
        return false;
    }
    
    // 显示导入界面
    showImportInterface() {
        const modal = document.createElement('div');
        modal.style.cssText = `
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0,0,0,0.9);
            z-index: 10001;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 20px;
            box-sizing: border-box;
        `;
        
        const content = document.createElement('div');
        content.style.cssText = `
            background: #1a1a2e;
            border: 2px solid #00d4ff;
            border-radius: 15px;
            padding: 25px;
            max-width: 90%;
            max-height: 90%;
            overflow-y: auto;
            color: #fff;
            font-family: 'Orbitron', monospace;
        `;
        
        content.innerHTML = `
            <h3 style="color: #00d4ff; margin-bottom: 20px; text-align: center;">
                <i class="fas fa-upload"></i> 存档导入
            </h3>
            <div style="margin-bottom: 20px;">
                <p style="color: #ffa726; margin-bottom: 15px;">
                    <i class="fas fa-exclamation-triangle"></i> 
                    <strong>注意：导入存档将覆盖当前游戏进度！</strong>
                </p>
                <p style="margin-bottom: 15px;">
                    请选择存档文件或粘贴存档数据：
                </p>
            </div>
            
            <div style="margin-bottom: 20px;">
                <label style="display: block; margin-bottom: 10px; color: #00d4ff;">
                    <i class="fas fa-file"></i> 选择存档文件：
                </label>
                <input type="file" id="saveFileInput" accept=".json,.txt" style="
                    width: 100%;
                    padding: 10px;
                    background: #0f0f23;
                    color: #fff;
                    border: 1px solid #00d4ff;
                    border-radius: 5px;
                    margin-bottom: 15px;
                ">
            </div>
            
            <div style="margin-bottom: 20px;">
                <label style="display: block; margin-bottom: 10px; color: #00d4ff;">
                    <i class="fas fa-paste"></i> 或粘贴存档数据：
                </label>
                <textarea id="saveDataInput" placeholder="请粘贴存档JSON数据..." style="
                    width: 100%;
                    height: 150px;
                    background: #0f0f23;
                    color: #00ff7f;
                    border: 1px solid #00d4ff;
                    border-radius: 8px;
                    padding: 15px;
                    font-family: 'Courier New', monospace;
                    font-size: 11px;
                    resize: vertical;
                "></textarea>
            </div>
            
            <div style="text-align: center; margin-top: 25px;">
                <button id="importSaveBtn" style="
                    background: linear-gradient(145deg, #4caf50, #45a049);
                    color: white;
                    border: none;
                    padding: 12px 25px;
                    border-radius: 8px;
                    margin-right: 15px;
                    cursor: pointer;
                    font-size: 16px;
                "><i class="fas fa-upload"></i> 导入存档</button>
                <button id="closeImportModal" style="
                    background: linear-gradient(145deg, #666, #444);
                    color: white;
                    border: none;
                    padding: 12px 25px;
                    border-radius: 8px;
                    cursor: pointer;
                    font-size: 16px;
                "><i class="fas fa-times"></i> 取消</button>
            </div>
        `;
        
        modal.appendChild(content);
        document.body.appendChild(modal);
        
        // 文件选择处理
        document.getElementById('saveFileInput').onchange = (event) => {
            const file = event.target.files[0];
            if (file) {
                const reader = new FileReader();
                reader.onload = (e) => {
                    document.getElementById('saveDataInput').value = e.target.result;
                };
                reader.readAsText(file);
            }
        };
        
        // 导入按钮处理
        document.getElementById('importSaveBtn').onclick = () => {
            const saveData = document.getElementById('saveDataInput').value.trim();
            if (!saveData) {
                alert('请先选择文件或粘贴存档数据');
                return;
            }
            
            if (this.importSave(saveData)) {
                document.body.removeChild(modal);
            }
        };
        
        // 关闭按钮处理
        document.getElementById('closeImportModal').onclick = () => {
            document.body.removeChild(modal);
        };
        
        modal.onclick = (e) => {
            if (e.target === modal) {
                document.body.removeChild(modal);
            }
        };
    }
}

// 创建全局实例
window.saveManager = new SaveManager();

// 全局函数
window.exportGameSave = () => window.saveManager.exportSave();
window.importGameSave = () => window.saveManager.showImportInterface();
window.restoreBackupSave = () => window.saveManager.restoreBackup();

console.log('[Save Manager] Save management system initialized');