// ========== 量子商店系统 ==========

// 检查增益是否正在激活
const checkBuffActive = (itemId) => {
    if (!player.timedBuffs) return false;
    
    // 根据商品ID查找对应的buff类型
    const buffTypeMap = {
        "cpu-overclock": "atkSpd",
        "weapon-overload": "atk",
        "shield-boost": "def",
        "crit-module": "critRate",
        "damage-amplifier": "critDmg",
        "life-steal": "vamp",
        "all-stats": ["atk", "def", "atkSpd", "hp"] // 全属性需要特殊处理
    };
    
    const buffType = buffTypeMap[itemId];
    if (!buffType) return false;
    
    // 如果是全属性，检查任一属性是否激活
    if (Array.isArray(buffType)) {
        return buffType.some(type => 
            player.timedBuffs[type] && Date.now() < player.timedBuffs[type].endTime
        );
    }
    
    // 检查单个buff是否激活
    return player.timedBuffs[buffType] && Date.now() < player.timedBuffs[buffType].endTime;
};

// 商店商品数据
const shopItems = {
    // 增强模块（限时增益）
    consumables: [
        {
            id: "cpu-overclock",
            name: "处理器超频芯片",
            icon: "⚡",
            effect: "反应速度+30%（持续10分钟）",
            description: "临时超频中央处理器，提升系统响应速度",
            limitedTime: true,
            duration: 600000, // 10分钟
            action: () => {
                applyTimedBuff("atkSpd", 0.3, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "weapon-overload",
            name: "武器系统过载",
            icon: "🔥",
            effect: "武器输出+25%（持续10分钟）",
            description: "解除武器功率限制，临时提升火力输出",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("atk", 0.25, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "shield-boost",
            name: "护盾矩阵增幅",
            icon: "🛡️",
            effect: "防御力+30%（持续10分钟）",
            description: "强化护盾发生器，提升防御效能",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("def", 0.3, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "crit-module",
            name: "精准瞄准模块",
            icon: "🎯",
            effect: "暴击率+20%（持续10分钟）",
            description: "高精度瞄准辅助系统，提升关键打击概率",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("critRate", 0.2, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "damage-amplifier",
            name: "伤害放大器",
            icon: "💥",
            effect: "暴击伤害+50%（持续10分钟）",
            description: "增强关键部位打击效果，造成更高伤害",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("critDmg", 0.5, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "life-steal",
            name: "纳米修复协议",
            icon: "🩸",
            effect: "吸血+15%（持续10分钟）",
            description: "战斗中自动修复受损部件",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("vamp", 0.15, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        },
        {
            id: "all-stats",
            name: "全系统强化",
            icon: "⭐",
            effect: "全属性+15%（持续10分钟）",
            description: "全面提升机体各项性能参数",
            limitedTime: true,
            duration: 600000,
            action: () => {
                applyTimedBuff("atk", 0.15, 600000);
                applyTimedBuff("def", 0.15, 600000);
                applyTimedBuff("atkSpd", 0.15, 600000);
                applyTimedBuff("hp", 0.15, 600000);
                // 不要添加到地牢日志，避免干扰事件流程
            }
        }
    ]
};

// 商店购买记录（用于限购）
let shopPurchaseHistory = {};

// 当前选中的商品分类
let currentShopCategory = "consumables";

// 打开量子商店
const openQuantumShop = () => {
    safePlaySFX(sfxOpen);
    
    // 显示商店模态窗口
    const shopModal = document.querySelector("#quantumShop");
    shopModal.style.display = "flex";
    
    // 使用层级管理器设置z-index
    if (window.zIndexManager) {
        window.zIndexManager.pushModal(shopModal);
    }
    
    // 直接渲染所有商品
    renderShopItems();
    
    // 更新商品数量显示
    updateShopStats();
};

// 关闭量子商店
const closeQuantumShop = () => {
    safePlaySFX(sfxDecline);
    const shopModal = document.querySelector("#quantumShop");
    shopModal.style.display = "none";
    
    // 从层级管理器移除
    if (window.zIndexManager) {
        window.zIndexManager.popModal(shopModal);
    }
    
    // 关闭商店后，如果之前在探索，继续探索
    if (typeof continueExploring === 'function') {
        continueExploring();
    }
};

// 渲染商品列表
const renderShopItems = () => {
    const container = document.querySelector("#shopItemsContainer");
    container.innerHTML = "";
    
    // 直接显示consumables分类的所有商品
    const items = shopItems.consumables || [];
    
    items.forEach(item => {
        const shopItem = createShopItemElement(item);
        container.appendChild(shopItem);
    });
};

// 更新商店统计信息
const updateShopStats = () => {
    const itemCountElement = document.querySelector("#shop-item-count");
    if (itemCountElement) {
        const totalItems = shopItems.consumables ? shopItems.consumables.length : 0;
        itemCountElement.textContent = totalItems;
    }
};

// 创建单个商品元素
const createShopItemElement = (item) => {
    const itemDiv = document.createElement("div");
    itemDiv.className = "shop-item";
    itemDiv.dataset.itemId = item.id;
    
    // 检查该增益是否正在激活中
    const isBuffActive = checkBuffActive(item.id);
    
    // 使用SVG图标
    const iconHtml = window.createShopIcon ? window.createShopIcon(item.id) : item.icon;
    
    // 持续时间显示
    const durationText = item.duration ? `${Math.floor(item.duration / 60000)}分钟` : '';
    
    itemDiv.innerHTML = `
        <div class="mobile-item-card">
            <div class="mobile-item-top">
                <div class="item-icon">${iconHtml}</div>
                <div class="item-header">
                    <h4 class="item-name">${item.name}</h4>
                </div>
            </div>
            <div class="mobile-item-content" onclick="showShopItemDetail('${item.id}')" style="cursor: pointer;">
                <p class="item-effect">${item.effect}</p>
                <p class="item-description">${item.description}</p>
            </div>
            <div class="mobile-item-bottom">
                <button class="mobile-ad-btn ${isBuffActive ? 'disabled' : ''}" 
                        onclick="confirmGetItem('${item.id}')" 
                        ${isBuffActive ? 'disabled' : ''}>
                    <i class="fas ${isBuffActive ? 'fa-clock' : 'fa-gift'}"></i>
                    <span>${isBuffActive ? '增益生效中' : '获取'}</span>
                </button>
            </div>
        </div>
    `;
    
    return itemDiv;
};

// 确认获取物品
const confirmGetItem = (itemId) => {
    const item = findShopItem(itemId);
    if (!item) return;
    
    // 检查增益是否激活
    if (checkBuffActive(itemId)) {
        showNotification('该增益正在生效中！');
        return;
    }
    
    // 显示确认弹窗
    const modal = document.createElement('div');
    modal.className = 'modal-container';
    modal.style.display = 'flex';
    modal.style.zIndex = '10002';
    
    modal.innerHTML = `
        <div class="content">
            <div class="content-head">
                <h3>获取增强模块</h3>
                <button class="close-btn" onclick="closeShopConfirmModal(this.closest('.modal-container'))">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            <div class="confirm-content">
                <div class="confirm-item-info">
                    <div class="item-icon">${window.createShopIcon ? window.createShopIcon(item.id) : item.icon}</div>
                    <h4 class="${item.rarity || ''}">${item.name}</h4>
                    <p class="item-effect">${item.effect}</p>
                </div>
                <p class="confirm-message">
                    <i class="fas fa-video"></i>
                    观看一段广告即可免费获得此增强模块
                </p>
                <div class="button-container">
                    <button onclick="closeShopConfirmModal(this.closest('.modal-container')); watchAdForItem('${itemId}');" class="confirm-btn">
                        <i class="fas fa-play-circle"></i> 观看广告
                    </button>
                    <button onclick="closeShopConfirmModal(this.closest('.modal-container'));" class="cancel-btn">
                        <i class="fas fa-times"></i> 取消
                    </button>
                </div>
            </div>
        </div>
    `;
    
    document.body.appendChild(modal);
    
    // 点击背景关闭
    modal.addEventListener('click', (e) => {
        if (e.target === modal) {
            closeShopConfirmModal(modal);
        }
    });
};

// 观看广告获取物品
const watchAdForItem = (itemId) => {
    const item = findShopItem(itemId);
    if (!item) return;
    
    // 再次检查增益是否激活
    if (checkBuffActive(itemId)) {
        showNotification('该增益正在生效中！');
        return;
    }
    
    // 显示广告加载提示
    showNotification('正在加载广告...');
    
    // 调用广告系统
    if (typeof showRewardedAd === 'function') {
        showRewardedAd(() => {
            // 广告观看成功回调
            grantShopItem(itemId);
        }, () => {
            // 广告观看失败回调
            showNotification('广告加载失败，请稍后重试');
        });
    } else {
        // 测试环境，直接给予奖励
        console.log('测试环境：直接给予奖励');
        setTimeout(() => {
            grantShopItem(itemId);
        }, 1000);
    }
};

// 关闭商店确认模态窗口（并清理事件状态）
const closeShopConfirmModal = (modal) => {
    if (modal && modal.parentElement) {
        modal.remove();
        
        // 延迟检查并清理事件状态
        setTimeout(() => {
            if (typeof dungeon !== 'undefined' && dungeon.status && dungeon.status.event) {
                // 检查是否还有其他可见的模态窗口
                const activeModals = document.querySelectorAll('.modal-container[style*="flex"], .modal-container[style*="block"]');
                const visibleModals = Array.from(activeModals).filter(modal => 
                    modal.style.display === 'flex' || modal.style.display === 'block'
                );
                
                // 如果没有其他可见模态窗口，检查是否需要清理事件状态
                if (visibleModals.length === 0 && typeof EventStateManager !== 'undefined') {
                    EventStateManager.tryToClearEventState('商店确认模态窗');
                }
            }
        }, 100);
    }
};

// 给予商店物品
const grantShopItem = (itemId) => {
    const item = findShopItem(itemId);
    if (!item) return;
    
    // 记录获取
    shopPurchaseHistory[itemId] = (shopPurchaseHistory[itemId] || 0) + 1;
    
    // 执行物品效果
    if (item.action) {
        item.action();
    }
    
    // 播放获得音效
    safePlaySFX(sfxConfirm);
    
    // 更新显示
    playerLoadStats();
    renderShopItems();
    saveData();
    
    // 注意：事件状态清理将在所有模态窗口关闭后进行
    // 这避免了状态不一致问题
    
    // 延迟清理事件状态，等待所有UI更新完成
    setTimeout(() => {
        if (typeof dungeon !== 'undefined' && dungeon.status && dungeon.status.event) {
            // 检查是否还有其他可见的模态窗口
            const activeModals = document.querySelectorAll('.modal-container[style*="flex"], .modal-container[style*="block"]');
            const visibleModals = Array.from(activeModals).filter(modal => 
                modal.style.display === 'flex' || modal.style.display === 'block'
            );
            
            // 如果没有其他可见模态窗口，才清理事件状态
            if (visibleModals.length === 0 && typeof EventStateManager !== 'undefined') {
                EventStateManager.tryToClearEventState('商店物品获取');
            }
        }
    }, 200);
    
    showNotification(`获得增强：${item.name}！`);
};

// 查找商店物品
const findShopItem = (itemId) => {
    for (const category in shopItems) {
        const item = shopItems[category].find(item => item.id === itemId);
        if (item) return item;
    }
    return null;
};

// 获取购买次数
const getPurchaseCount = (itemId) => {
    return shopPurchaseHistory[itemId] || 0;
};

// 更新商店金币显示（已废弃 - 改为广告获取）
const updateShopGoldDisplay = () => {
    // 不再需要金币显示
};

// 显示商店物品详情
const showShopItemDetail = (itemId) => {
    const item = findShopItem(itemId);
    if (!item) return;
    
    const modal = document.querySelector("#shopItemDetailModal");
    const iconHtml = window.createShopIcon ? window.createShopIcon(item.id) : item.icon;
    
    modal.innerHTML = `
        <div class="content shop-item-detail">
            <div class="shop-detail-header">
                <h3 class="detail-title">${item.name}</h3>
            </div>
            
            <div class="shop-detail-body">
                <div class="detail-icon">${iconHtml}</div>
                
                <div class="detail-info">
                    <div class="detail-section">
                        <h4>效果</h4>
                        <p class="effect-text">${item.effect}</p>
                    </div>
                    
                    <div class="detail-section">
                        <h4>说明</h4>
                        <p class="description-text">${item.description}</p>
                    </div>
                    
                    <div class="detail-section">
                        <h4>获取方式</h4>
                        <p class="ad-text">
                            <i class="fas fa-video"></i>
                            观看广告免费获得
                        </p>
                    </div>
                </div>
            </div>
            
            <div class="shop-detail-footer">
                <button class="watch-ad-detail-btn ${checkBuffActive(item.id) ? 'disabled' : ''}"
                        onclick="confirmGetItem('${item.id}'); closeShopItemDetail();"
                        ${checkBuffActive(item.id) ? 'disabled' : ''}>
                    ${checkBuffActive(item.id) ? '增益生效中' : '立即获取'}
                </button>
                <button class="close-detail-btn" onclick="closeShopItemDetail()">
                    关闭
                </button>
            </div>
        </div>
    `;
    
    modal.style.display = "flex";
    
    // 使用层级管理器设置z-index
    if (window.zIndexManager) {
        window.zIndexManager.pushModal(modal);
    }
};

// 关闭商店物品详情
const closeShopItemDetail = () => {
    const modal = document.querySelector("#shopItemDetailModal");
    modal.style.display = "none";
    
    // 从层级管理器移除
    if (window.zIndexManager) {
        window.zIndexManager.popModal(modal);
    }
    
    // 延迟检查并清理事件状态
    setTimeout(() => {
        if (typeof dungeon !== 'undefined' && dungeon.status && dungeon.status.event) {
            // 检查是否还有其他可见的模态窗口
            const activeModals = document.querySelectorAll('.modal-container[style*="flex"], .modal-container[style*="block"]');
            const visibleModals = Array.from(activeModals).filter(modal => 
                modal.style.display === 'flex' || modal.style.display === 'block'
            );
            
            // 如果没有其他可见模态窗口，才清理事件状态
            if (visibleModals.length === 0 && typeof EventStateManager !== 'undefined') {
                EventStateManager.tryToClearEventState('商店详情模态窗');
            }
        }
        
        // 关闭详情页面后，如果之前在探索，继续探索
        if (typeof continueExploring === 'function') {
            continueExploring();
        }
    }, 100);
};

// 初始化量子商店系统
const initQuantumShop = () => {
    // 加载购买历史
    const savedHistory = localStorage.getItem('shopPurchaseHistory');
    if (savedHistory) {
        shopPurchaseHistory = JSON.parse(savedHistory);
    }
};

// 保存购买历史
const saveShopData = () => {
    localStorage.setItem('shopPurchaseHistory', JSON.stringify(shopPurchaseHistory));
};

// 重置商店购买记录（每次重新开始游戏时调用）
const resetShopPurchases = () => {
    // 只重置limitPerRun的物品
    const newHistory = {};
    for (const itemId in shopPurchaseHistory) {
        const item = findShopItem(itemId);
        if (item && !item.limitPerRun) {
            newHistory[itemId] = shopPurchaseHistory[itemId];
        }
    }
    shopPurchaseHistory = newHistory;
    saveShopData();
};

// 应用限时增益效果
const applyTimedBuff = (statType, value, duration) => {
    // 确保有限时buff系统
    if (!player.timedBuffs) {
        player.timedBuffs = {};
    }
    
    // 设置buff
    player.timedBuffs[statType] = {
        value: value,
        endTime: Date.now() + duration
    };
    
    // 更新玩家属性显示
    if (typeof playerLoadStats === 'function') {
        playerLoadStats();
    }
    
    // 启动定时器来实时更新时间倒计时
    if (typeof startTimedBuffTimer === 'function') {
        startTimedBuffTimer();
    }
    
    // 设置buff到期处理
    setTimeout(() => {
        if (player.timedBuffs[statType] && player.timedBuffs[statType].endTime <= Date.now()) {
            delete player.timedBuffs[statType];
            if (typeof playerLoadStats === 'function') {
                playerLoadStats();
            }
            // 不要添加到地牢日志，避免干扰事件流程
        }
    }, duration);
};

