// ========== Z-Index 层级管理系统 ==========

// 定义层级常量
const Z_INDEX = {
    // 背景装饰层 (-99 到 -1)
    BACKGROUND_DECORATION: -1,
    BACKGROUND_EFFECT: -2,
    
    // 基础内容层 (0 到 99)
    BASE_CONTENT: 0,
    HEADER_DECORATION: 0,
    HEADER_CONTENT: 1,
    
    // 浮动内容层 (100 到 199)
    DAMAGE_NUMBERS: 100,
    FLOATING_TEXT: 110,
    TOOLTIPS: 120,
    
    // 固定UI层 (200 到 299)
    FIXED_HEADER: 200,
    FIXED_SIDEBAR: 210,
    FIXED_FOOTER: 220,
    
    // 游戏面板层 (300 到 399)
    COMBAT_PANEL: 300,
    INVENTORY_PANEL: 310,
    INVENTORY_HEADER: 311,
    STATS_PANEL: 320,
    
    // 弹出面板层 (400 到 499)
    EQUIPMENT_INFO: 400,
    ITEM_DETAIL: 410,
    SKILL_POPUP: 420,
    
    // 模态框层 (500 到 599)
    MODAL_BACKDROP: 500,
    MODAL_CONTAINER: 510,
    MENU_MODAL: 520,
    DEFAULT_MODAL: 530,
    CONFIRMATION_MODAL: 540,
    QUANTUM_SHOP: 550,
    
    // 系统级遮罩层 (600 到 699)
    SYSTEM_OVERLAY: 600,
    PRIVACY_OVERLAY: 610,
    LOADING_SCREEN: 620,
    
    // 紧急/临时层 (700+)
    EMERGENCY_ALERT: 700,
    DEBUG_PANEL: 999
};

// 层级管理器类
class ZIndexManager {
    constructor() {
        this.activeModals = [];
        this.baseModalZIndex = Z_INDEX.MODAL_CONTAINER;
    }
    
    // 应用z-index到元素
    applyZIndex(element, zIndexKey) {
        if (!element) return;
        
        const zIndexValue = Z_INDEX[zIndexKey];
        if (zIndexValue !== undefined) {
            element.style.zIndex = zIndexValue;
        } else {
            console.warn(`Unknown z-index key: ${zIndexKey}`);
        }
    }
    
    // 管理模态框层级（支持多个模态框堆叠）
    pushModal(modalElement) {
        if (!modalElement) return;
        
        this.activeModals.push(modalElement);
        const newZIndex = this.baseModalZIndex + (this.activeModals.length - 1) * 10;
        modalElement.style.zIndex = newZIndex;
    }
    
    // 移除模态框
    popModal(modalElement) {
        const index = this.activeModals.indexOf(modalElement);
        if (index > -1) {
            this.activeModals.splice(index, 1);
            this.refreshModalStack();
        }
    }
    
    // 刷新模态框堆叠顺序
    refreshModalStack() {
        this.activeModals.forEach((modal, index) => {
            const zIndex = this.baseModalZIndex + index * 10;
            modal.style.zIndex = zIndex;
        });
    }
    
    // 获取当前最高层级
    getTopZIndex() {
        if (this.activeModals.length > 0) {
            return this.baseModalZIndex + (this.activeModals.length - 1) * 10;
        }
        return this.baseModalZIndex;
    }
    
    // 初始化所有元素的z-index
    initializeAllElements() {
        // 背景装饰
        const bodyBefore = document.querySelector('body::before');
        if (bodyBefore) this.applyZIndex(bodyBefore, 'BACKGROUND_DECORATION');
        
        // 基础内容
        const headerContent = document.querySelectorAll('header > *');
        headerContent.forEach(el => this.applyZIndex(el, 'HEADER_CONTENT'));
        
        // 伤害数字
        const dmgNumbers = document.querySelectorAll('.dmg-numbers, .player-dmg-numbers');
        dmgNumbers.forEach(el => this.applyZIndex(el, 'DAMAGE_NUMBERS'));
        
        // 游戏面板
        this.applyZIndex(document.getElementById('combatPanel'), 'COMBAT_PANEL');
        this.applyZIndex(document.getElementById('inventory'), 'INVENTORY_PANEL');
        
        const inventoryHead = document.querySelector('#inventory .content-head');
        if (inventoryHead) this.applyZIndex(inventoryHead, 'INVENTORY_HEADER');
        
        // 弹出面板
        this.applyZIndex(document.getElementById('equipmentInfo'), 'EQUIPMENT_INFO');
        
        // 模态框
        this.applyZIndex(document.getElementById('menuModal'), 'MENU_MODAL');
        this.applyZIndex(document.getElementById('defaultModal'), 'DEFAULT_MODAL');
        this.applyZIndex(document.getElementById('confirmationModal'), 'CONFIRMATION_MODAL');
        this.applyZIndex(document.getElementById('quantumShop'), 'QUANTUM_SHOP');
        
        // 系统遮罩
        const privacyOverlay = document.querySelector('.privacy-overlay');
        if (privacyOverlay) this.applyZIndex(privacyOverlay, 'PRIVACY_OVERLAY');
    }
}

// 创建全局实例
const zIndexManager = new ZIndexManager();

// 导出给其他模块使用
window.Z_INDEX = Z_INDEX;
window.zIndexManager = zIndexManager;

// DOM加载完成后初始化
document.addEventListener('DOMContentLoaded', () => {
    zIndexManager.initializeAllElements();
});