// 游戏核心 - 增强版
// 可直接在浏览器中运行，无需构建

// ===== 事件总线系统 =====
class EventBus {
  constructor() {
    this.events = new Map();
    this.onceHandlers = new WeakMap();
  }

  on(event, handler) {
    if (!this.events.has(event)) {
      this.events.set(event, new Set());
    }
    this.events.get(event).add(handler);
    
    // 返回取消订阅函数
    return () => this.off(event, handler);
  }

  once(event, handler) {
    const onceHandler = (data) => {
      handler(data);
      this.off(event, onceHandler);
    };
    this.onceHandlers.set(onceHandler, handler);
    return this.on(event, onceHandler);
  }

  emit(event, data) {
    const handlers = this.events.get(event);
    if (!handlers || handlers.size === 0) return;
    
    const handlersCopy = Array.from(handlers);
    for (const handler of handlersCopy) {
      try {
        handler(data);
      } catch (error) {
        console.error(`Error in event handler for "${event}":`, error);
      }
    }
  }

  off(event, handler) {
    const handlers = this.events.get(event);
    if (!handlers) return;
    
    if (handler) {
      handlers.delete(handler);
      const originalHandler = this.onceHandlers.get(handler);
      if (originalHandler) {
        handlers.delete(originalHandler);
        this.onceHandlers.delete(handler);
      }
    } else {
      handlers.clear();
    }
    
    if (handlers.size === 0) {
      this.events.delete(event);
    }
  }

  clear() {
    this.events.clear();
    this.onceHandlers = new WeakMap();
  }
}

// 全局事件总线
const gameEventBus = new EventBus();

// ===== 性能监控系统 =====
class PerformanceMonitor {
  constructor() {
    this.metrics = {
      fps: 0,
      frameTime: 0,
      memoryUsage: 0,
      drawCalls: 0
    };
    this.lastFrameTime = 0;
    this.frameCount = 0;
    this.fpsUpdateInterval = 1000;
    this.lastFpsUpdate = 0;
    this.rafId = null;
    this.displayElement = null;
    this.isVisible = false;
  }

  init() {
    this.createDisplay();
    this.startMonitoring();
    
    // F3切换显示
    document.addEventListener('keydown', (e) => {
      if (e.key === 'F3') {
        e.preventDefault();
        this.toggleDisplay();
      }
    });
  }

  createDisplay() {
    this.displayElement = document.createElement('div');
    this.displayElement.id = 'performance-monitor';
    this.displayElement.style.cssText = `
      position: fixed;
      top: 10px;
      right: 10px;
      background: rgba(0, 0, 0, 0.8);
      color: #00ff00;
      padding: 10px;
      font-family: monospace;
      font-size: 12px;
      border-radius: 5px;
      z-index: 10000;
      pointer-events: none;
      display: none;
      min-width: 150px;
    `;
    document.body.appendChild(this.displayElement);
  }

  startMonitoring() {
    const monitor = (currentTime) => {
      if (this.lastFrameTime) {
        this.metrics.frameTime = currentTime - this.lastFrameTime;
      }
      this.lastFrameTime = currentTime;
      
      this.frameCount++;
      if (currentTime - this.lastFpsUpdate >= this.fpsUpdateInterval) {
        this.metrics.fps = Math.round((this.frameCount * 1000) / (currentTime - this.lastFpsUpdate));
        this.frameCount = 0;
        this.lastFpsUpdate = currentTime;
        
        this.updateMemoryUsage();
        this.updateDisplay();
      }
      
      this.rafId = requestAnimationFrame(monitor);
    };
    
    this.rafId = requestAnimationFrame(monitor);
  }

  updateMemoryUsage() {
    if (performance.memory) {
      this.metrics.memoryUsage = Math.round(performance.memory.usedJSHeapSize / 1048576);
    }
  }

  updateDisplay() {
    if (!this.displayElement || !this.isVisible) return;
    
    const fpsColor = this.metrics.fps >= 55 ? '#00ff00' : 
                     this.metrics.fps >= 30 ? '#ffff00' : '#ff0000';
    
    this.displayElement.innerHTML = `
      <div style="color: ${fpsColor}">FPS: ${this.metrics.fps}</div>
      <div>帧时间: ${this.metrics.frameTime.toFixed(2)}ms</div>
      <div>内存: ${this.metrics.memoryUsage}MB</div>
    `;
  }

  toggleDisplay() {
    this.isVisible = !this.isVisible;
    this.displayElement.style.display = this.isVisible ? 'block' : 'none';
  }

  destroy() {
    if (this.rafId) {
      cancelAnimationFrame(this.rafId);
    }
    if (this.displayElement) {
      this.displayElement.remove();
    }
  }
}

// ===== 开发者工具 =====
class DevTools {
  constructor() {
    this.enabled = false;
    this.commands = {};
    this.panel = null;
  }

  init() {
    this.setupCommands();
    this.setupHotkeys();
    this.createPanel();
    
    // 开发环境自动启用
    if (window.location.hostname === 'localhost' || window.location.hostname === '127.0.0.1') {
      this.enable();
    }
  }

  enable() {
    this.enabled = true;
    console.log('%c🛠️ 开发者工具已启用', 'color: #00ff00; font-size: 16px;');
    console.log('按 Ctrl+Shift+D 打开面板');
    console.log('按 F12 查看控制台命令');
    
    // 暴露到全局
    window.devTools = this;
    window.game = this.commands;
  }

  setupCommands() {
    this.commands = {
      // 玩家命令
      setLevel: (level) => {
        if (!player) return console.error('玩家未初始化');
        player.lvl = level;
        playerLoadStats();
        console.log(`等级设置为 ${level}`);
      },
      
      addGold: (amount) => {
        if (!player) return console.error('玩家未初始化');
        player.gold = safeNumber(player.gold + amount);
        playerLoadStats();
        console.log(`增加 ${amount} 金币`);
      },
      
      heal: () => {
        if (!player) return console.error('玩家未初始化');
        player.stats.hp = player.stats.hpMax;
        playerLoadStats();
        console.log('已满血');
      },
      
      // 地牢命令
      teleport: (floor, room = 1) => {
        if (!dungeon) return console.error('地牢未初始化');
        dungeon.progress.floor = Math.min(floor, 100);
        dungeon.progress.room = Math.min(room, 5);
        dungeonLoadStats();
        console.log(`传送到 ${floor} 层 ${room} 房间`);
      },
      
      // 战斗命令
      killEnemy: () => {
        if (!enemy || !player.inCombat) return console.error('当前没有战斗');
        enemy.stats.hp = 0;
        console.log('击杀当前敌人');
      },
      
      // 系统命令
      save: () => {
        saveData();
        console.log('游戏已保存');
      },
      
      showStats: () => {
        console.table({
          玩家: {
            等级: player?.lvl,
            生命值: `${player?.stats.hp}/${player?.stats.hpMax}`,
            金币: player?.gold,
            装备数: player?.equipped?.length
          },
          地牢: {
            楼层: dungeon?.progress?.floor,
            房间: dungeon?.progress?.room,
            击杀数: dungeon?.statistics?.kills
          }
        });
      },
      
      help: () => {
        console.log(`
=== 开发者命令 ===
game.setLevel(n)    - 设置等级
game.addGold(n)     - 增加金币
game.heal()         - 满血
game.teleport(f,r)  - 传送
game.killEnemy()    - 击杀敌人
game.save()         - 保存游戏
game.showStats()    - 显示统计
        `);
      }
    };
  }

  setupHotkeys() {
    document.addEventListener('keydown', (e) => {
      if (!this.enabled) return;
      
      // Ctrl+Shift+D 打开面板
      if (e.ctrlKey && e.shiftKey && e.key === 'D') {
        e.preventDefault();
        this.togglePanel();
      }
      
      // 快捷键
      if (e.ctrlKey && e.shiftKey) {
        switch(e.key) {
          case 'H': // 满血
            this.commands.heal();
            break;
          case 'G': // 传送到99层
            this.commands.teleport(99);
            break;
          case 'K': // 击杀敌人
            this.commands.killEnemy();
            break;
        }
      }
    });
  }

  createPanel() {
    this.panel = document.createElement('div');
    this.panel.id = 'dev-panel';
    this.panel.style.cssText = `
      position: fixed;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      background: rgba(0, 0, 0, 0.95);
      color: white;
      padding: 20px;
      border-radius: 10px;
      z-index: 10001;
      min-width: 300px;
      display: none;
      border: 2px solid #00ff00;
    `;
    
    this.panel.innerHTML = `
      <h3 style="margin: 0 0 15px 0; color: #00ff00;">开发者工具</h3>
      <div style="display: grid; gap: 10px;">
        <button onclick="game.setLevel(50)" class="dev-btn">设置等级 50</button>
        <button onclick="game.addGold(10000)" class="dev-btn">增加 10000 金币</button>
        <button onclick="game.heal()" class="dev-btn">满血恢复</button>
        <button onclick="game.teleport(99)" class="dev-btn">传送到 99 层</button>
        <button onclick="game.killEnemy()" class="dev-btn">秒杀敌人</button>
        <button onclick="game.showStats()" class="dev-btn">显示统计</button>
        <button onclick="devTools.togglePanel()" class="dev-btn" style="background: #ff3333;">关闭</button>
      </div>
      <style>
        .dev-btn {
          padding: 8px 15px;
          background: #333;
          color: white;
          border: 1px solid #666;
          border-radius: 5px;
          cursor: pointer;
          transition: all 0.2s;
        }
        .dev-btn:hover {
          background: #555;
          border-color: #00ff00;
        }
      </style>
    `;
    
    document.body.appendChild(this.panel);
  }

  togglePanel() {
    if (!this.panel) return;
    const isVisible = this.panel.style.display !== 'none';
    this.panel.style.display = isVisible ? 'none' : 'block';
  }
}

// ===== 增强的战斗系统 =====
class EnhancedCombatSystem {
  constructor() {
    this.damageNumbers = [];
    this.combatLog = [];
    this.maxLogEntries = 50;
  }

  init() {
    // 监听战斗事件
    gameEventBus.on('combat:damage', (data) => {
      this.addCombatLog(data);
      this.showDamageNumber(data);
    });
    
    // 创建伤害数字容器
    const container = document.createElement('div');
    container.id = 'damage-numbers';
    container.style.cssText = `
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      pointer-events: none;
      z-index: 9999;
    `;
    document.body.appendChild(container);
  }

  showDamageNumber(data) {
    const { damage, x, y, critical, target } = data;
    
    const damageEl = document.createElement('div');
    damageEl.className = 'damage-number';
    damageEl.style.cssText = `
      position: absolute;
      left: ${x || Math.random() * window.innerWidth}px;
      top: ${y || window.innerHeight * 0.3}px;
      color: ${critical ? '#FFD700' : (target === 'player' ? '#FF4444' : '#FFFFFF')};
      font-size: ${critical ? '28px' : '24px'};
      font-weight: bold;
      text-shadow: 2px 2px 4px rgba(0,0,0,0.8);
      animation: float-up 1s ease-out forwards;
      pointer-events: none;
      z-index: 10000;
    `;
    damageEl.textContent = critical ? `${damage}!` : damage;
    
    document.getElementById('damage-numbers').appendChild(damageEl);
    
    // 1秒后移除
    setTimeout(() => damageEl.remove(), 1000);
  }

  addCombatLog(data) {
    const entry = {
      message: data.message,
      type: data.type,
      timestamp: Date.now()
    };
    
    this.combatLog.push(entry);
    if (this.combatLog.length > this.maxLogEntries) {
      this.combatLog.shift();
    }
    
    gameEventBus.emit('combat:log_updated', entry);
  }

  getCombatLog() {
    return this.combatLog;
  }
}

// ===== 数据验证和安全 =====
class DataValidator {
  static validatePlayerData(data) {
    if (!data || typeof data !== 'object') return false;
    
    // 验证必要字段
    const requiredFields = ['name', 'lvl', 'stats', 'exp', 'inventory'];
    for (const field of requiredFields) {
      if (!(field in data)) return false;
    }
    
    // 验证数值范围
    if (data.lvl < 1 || data.lvl > 100) return false;
    if (data.gold < 0) return false;
    
    return true;
  }

  static sanitizeNumber(value, min = 0, max = Number.MAX_SAFE_INTEGER) {
    const num = Number(value);
    if (isNaN(num) || !isFinite(num)) return min;
    return Math.max(min, Math.min(max, Math.floor(num)));
  }

  static preventCheat() {
    // 防止控制台修改关键变量
    let protectedVars = new WeakMap();
    
    return {
      protect: (obj, key, value) => {
        const id = Symbol(key);
        protectedVars.set(obj, { [id]: value });
        
        Object.defineProperty(obj, key, {
          get() {
            return protectedVars.get(this)[id];
          },
          set(newValue) {
            console.warn(`尝试修改受保护的属性 ${key}`);
            // 可以添加验证逻辑
            protectedVars.get(this)[id] = newValue;
          }
        });
      }
    };
  }
}

// ===== 游戏增强管理器 =====
class GameEnhancer {
  constructor() {
    this.systems = {
      performance: new PerformanceMonitor(),
      devTools: new DevTools(),
      combat: new EnhancedCombatSystem(),
      eventBus: gameEventBus
    };
  }

  init() {
    console.log('🚀 初始化游戏增强系统...');
    
    // 初始化各系统
    this.systems.performance.init();
    this.systems.devTools.init();
    this.systems.combat.init();
    
    // 添加CSS动画
    this.injectStyles();
    
    // 增强原有函数
    this.enhanceGameFunctions();
    
    console.log('✅ 游戏增强系统初始化完成');
  }

  injectStyles() {
    const style = document.createElement('style');
    style.textContent = `
      @keyframes float-up {
        0% {
          transform: translateY(0) scale(0.8);
          opacity: 0;
        }
        20% {
          transform: translateY(-20px) scale(1.2);
          opacity: 1;
        }
        100% {
          transform: translateY(-80px) scale(0.9);
          opacity: 0;
        }
      }
      
      .damage-number {
        font-family: 'Orbitron', monospace;
        user-select: none;
      }
      
      #performance-monitor {
        font-family: 'Courier New', monospace;
        line-height: 1.4;
      }
      
      /* 增强游戏界面 */
      .enhanced-glow {
        box-shadow: 0 0 10px rgba(0, 255, 255, 0.5);
        transition: box-shadow 0.3s;
      }
      
      .enhanced-glow:hover {
        box-shadow: 0 0 20px rgba(0, 255, 255, 0.8);
      }
    `;
    document.head.appendChild(style);
  }

  enhanceGameFunctions() {
    // 增强 playerAttack 函数
    if (typeof playerAttack !== 'undefined') {
      const originalPlayerAttack = playerAttack;
      window.playerAttack = function() {
        const result = originalPlayerAttack.apply(this, arguments);
        
        // 触发伤害事件
        if (enemy && enemy.stats) {
          gameEventBus.emit('combat:damage', {
            damage: lastDamageDealt || 0,
            target: 'enemy',
            critical: lastWasCritical || false
          });
        }
        
        return result;
      };
    }

    // 增强 enemyAttack 函数
    if (typeof enemyAttack !== 'undefined') {
      const originalEnemyAttack = enemyAttack;
      window.enemyAttack = function() {
        const result = originalEnemyAttack.apply(this, arguments);
        
        // 触发伤害事件
        if (player && player.stats) {
          gameEventBus.emit('combat:damage', {
            damage: lastDamageTaken || 0,
            target: 'player',
            critical: false
          });
        }
        
        return result;
      };
    }

    // 增强保存函数
    if (typeof saveData !== 'undefined') {
      const originalSaveData = saveData;
      window.saveData = function() {
        console.log('💾 保存游戏数据...');
        const result = originalSaveData.apply(this, arguments);
        console.log('✅ 游戏已保存');
        return result;
      };
    }
  }

  // 获取系统实例
  getSystem(name) {
    return this.systems[name];
  }
}

// ===== 初始化 =====
// 等待页面加载完成
if (document.readyState === 'loading') {
  document.addEventListener('DOMContentLoaded', initGameEnhancer);
} else {
  initGameEnhancer();
}

function initGameEnhancer() {
  // 创建全局实例
  window.gameEnhancer = new GameEnhancer();
  window.gameEnhancer.init();
  
  // 暴露常用工具到全局
  window.gameEventBus = gameEventBus;
  
  console.log('💡 提示: 按 F3 显示性能监控, Ctrl+Shift+D 打开开发面板');
}