// 游戏模块化增强系统
// 为现有游戏添加模块化支持，无需修改原代码

(function() {
  'use strict';

  // ===== 模块管理器 =====
  window.GameModules = {
    modules: {},
    
    // 注册模块
    register(name, module) {
      this.modules[name] = module;
      console.log(`✅ 模块已注册: ${name}`);
    },
    
    // 获取模块
    get(name) {
      return this.modules[name];
    },
    
    // 初始化所有模块
    initAll() {
      console.log('🚀 初始化游戏模块...');
      for (const [name, module] of Object.entries(this.modules)) {
        if (module.init && typeof module.init === 'function') {
          try {
            module.init();
            console.log(`✅ ${name} 模块初始化成功`);
          } catch (error) {
            console.error(`❌ ${name} 模块初始化失败:`, error);
          }
        }
      }
    }
  };

  // ===== 玩家系统模块 =====
  const PlayerModule = {
    init() {
      // 增强玩家数据验证
      this.validatePlayerData();
      this.enhancePlayerFunctions();
    },

    validatePlayerData() {
      if (typeof player !== 'undefined' && player) {
        // 确保所有必要的属性存在
        player.baseStats = player.baseStats || {
          hp: 500, hpMax: 500, atk: 100, def: 50,
          atkSpd: 0.6, vamp: 0, critRate: 0, critDmg: 50
        };
        player.equippedStats = player.equippedStats || {};
        player.bonusStats = player.bonusStats || {};
        player.skills = player.skills || [];
        player.victoryStats = player.victoryStats || {
          completions: 0,
          fastestTime: null,
          totalKills: 0,
          totalPlaytime: 0
        };
      }
    },

    enhancePlayerFunctions() {
      // 增强经验获取函数
      if (typeof playerExpGain !== 'undefined') {
        const originalExpGain = playerExpGain;
        window.playerExpGain = function() {
          console.log(`⚡ 获得经验: ${enemy?.rewards?.exp || 0}`);
          return originalExpGain.apply(this, arguments);
        };
      }

      // 增强升级函数
      if (typeof playerLvlUp !== 'undefined') {
        const originalLvlUp = playerLvlUp;
        window.playerLvlUp = function() {
          const oldLevel = player.lvl;
          const result = originalLvlUp.apply(this, arguments);
          console.log(`🎉 升级! ${oldLevel} → ${player.lvl}`);
          GameModules.get('EventModule')?.emit('player:levelup', { 
            oldLevel, 
            newLevel: player.lvl 
          });
          return result;
        };
      }
    },

    // 工具方法
    getStats() {
      if (!player) return null;
      return {
        level: player.lvl,
        hp: `${player.stats.hp}/${player.stats.hpMax}`,
        attack: player.stats.atk,
        defense: player.stats.def,
        gold: player.gold,
        equipment: player.equipped?.filter(e => e).length || 0
      };
    },

    addExp(amount) {
      if (!player) return;
      player.exp.expCurr += amount;
      player.exp.expCurrLvl += amount;
      while (player.exp.expCurr >= player.exp.expMax) {
        playerLvlUp();
      }
      playerLoadStats();
    },

    heal(amount) {
      if (!player) return;
      player.stats.hp = Math.min(player.stats.hp + amount, player.stats.hpMax);
      playerLoadStats();
    }
  };

  // ===== 战斗系统模块 =====
  const CombatModule = {
    combatLog: [],
    damageHistory: [],
    
    init() {
      this.enhanceCombatFunctions();
      this.setupDamageTracking();
    },

    enhanceCombatFunctions() {
      // 增强玩家攻击
      if (typeof playerAttack !== 'undefined') {
        const original = playerAttack;
        window.playerAttack = function() {
          const enemyHpBefore = enemy?.stats?.hp || 0;
          const result = original.apply(this, arguments);
          const damage = enemyHpBefore - (enemy?.stats?.hp || 0);
          
          if (damage > 0) {
            CombatModule.recordDamage('player', damage);
            GameModules.get('EventModule')?.emit('combat:damage', {
              source: 'player',
              target: 'enemy',
              damage: damage,
              critical: window.lastWasCritical || false
            });
          }
          
          return result;
        };
      }

      // 增强敌人攻击
      if (typeof enemyAttack !== 'undefined') {
        const original = enemyAttack;
        window.enemyAttack = function() {
          const playerHpBefore = player?.stats?.hp || 0;
          const result = original.apply(this, arguments);
          const damage = playerHpBefore - (player?.stats?.hp || 0);
          
          if (damage > 0) {
            CombatModule.recordDamage('enemy', damage);
            GameModules.get('EventModule')?.emit('combat:damage', {
              source: 'enemy',
              target: 'player',
              damage: damage
            });
          }
          
          return result;
        };
      }
    },

    setupDamageTracking() {
      // 跟踪最近的伤害数据
      this.damageHistory = [];
    },

    recordDamage(source, damage) {
      const record = {
        source,
        damage,
        timestamp: Date.now()
      };
      
      this.damageHistory.push(record);
      if (this.damageHistory.length > 100) {
        this.damageHistory.shift();
      }
      
      this.combatLog.push(`${source === 'player' ? '玩家' : '敌人'} 造成 ${damage} 点伤害`);
      if (this.combatLog.length > 50) {
        this.combatLog.shift();
      }
    },

    getStats() {
      const playerDamage = this.damageHistory
        .filter(d => d.source === 'player')
        .reduce((sum, d) => sum + d.damage, 0);
      
      const enemyDamage = this.damageHistory
        .filter(d => d.source === 'enemy')
        .reduce((sum, d) => sum + d.damage, 0);
      
      return {
        totalPlayerDamage: playerDamage,
        totalEnemyDamage: enemyDamage,
        combatRounds: this.damageHistory.length
      };
    }
  };

  // ===== 地牢系统模块 =====
  const DungeonModule = {
    eventHistory: [],
    
    init() {
      this.enhanceDungeonFunctions();
    },

    enhanceDungeonFunctions() {
      // 增强地牢事件
      if (typeof dungeonEvent !== 'undefined') {
        const original = dungeonEvent;
        window.dungeonEvent = function() {
          const result = original.apply(this, arguments);
          
          // 记录事件
          if (dungeon?.backlog?.length > 0) {
            const lastEvent = dungeon.backlog[dungeon.backlog.length - 1];
            DungeonModule.recordEvent(lastEvent);
          }
          
          return result;
        };
      }
    },

    recordEvent(event) {
      this.eventHistory.push({
        ...event,
        timestamp: Date.now()
      });
      
      if (this.eventHistory.length > 100) {
        this.eventHistory.shift();
      }
      
      GameModules.get('EventModule')?.emit('dungeon:event', event);
    },

    getStats() {
      if (!dungeon) return null;
      
      return {
        floor: dungeon.progress.floor,
        room: dungeon.progress.room,
        kills: dungeon.statistics.kills,
        runtime: Math.floor(dungeon.statistics.runtime / 60) + ' 分钟',
        events: this.eventHistory.length
      };
    }
  };

  // ===== 事件系统模块 =====
  const EventModule = {
    listeners: {},
    
    init() {
      // 事件系统已就绪
    },

    on(event, callback) {
      if (!this.listeners[event]) {
        this.listeners[event] = [];
      }
      this.listeners[event].push(callback);
      
      // 返回取消订阅函数
      return () => {
        const index = this.listeners[event].indexOf(callback);
        if (index > -1) {
          this.listeners[event].splice(index, 1);
        }
      };
    },

    emit(event, data) {
      if (!this.listeners[event]) return;
      
      this.listeners[event].forEach(callback => {
        try {
          callback(data);
        } catch (error) {
          console.error(`事件处理器错误 [${event}]:`, error);
        }
      });
    },

    off(event) {
      delete this.listeners[event];
    }
  };

  // ===== 存档系统模块 =====
  const SaveModule = {
    autoSaveInterval: 60000, // 1分钟
    autoSaveTimer: null,
    
    init() {
      this.enhanceSaveFunctions();
      this.setupAutoSave();
    },

    enhanceSaveFunctions() {
      // 增强保存函数
      if (typeof saveData !== 'undefined') {
        const original = saveData;
        window.saveData = function() {
          console.log('💾 保存游戏中...');
          const result = original.apply(this, arguments);
          
          // 添加额外的保存数据
          SaveModule.saveEnhancedData();
          
          console.log('✅ 游戏已保存');
          GameModules.get('EventModule')?.emit('game:saved');
          
          return result;
        };
      }
    },

    setupAutoSave() {
      // 自动保存
      this.autoSaveTimer = setInterval(() => {
        if (typeof saveData !== 'undefined') {
          saveData();
        }
      }, this.autoSaveInterval);
      
      // 页面关闭时保存
      window.addEventListener('beforeunload', () => {
        if (typeof saveData !== 'undefined') {
          saveData();
        }
      });
    },

    saveEnhancedData() {
      // 保存增强数据
      const enhancedData = {
        version: '1.0',
        timestamp: Date.now(),
        modules: {
          combat: CombatModule.getStats(),
          dungeon: DungeonModule.getStats(),
          player: PlayerModule.getStats()
        }
      };
      
      localStorage.setItem('gameEnhancedData', JSON.stringify(enhancedData));
    },

    loadEnhancedData() {
      try {
        const data = localStorage.getItem('gameEnhancedData');
        if (data) {
          return JSON.parse(data);
        }
      } catch (error) {
        console.error('加载增强数据失败:', error);
      }
      return null;
    }
  };

  // ===== 统计系统模块 =====
  const StatsModule = {
    init() {
      this.setupTracking();
    },

    setupTracking() {
      // 跟踪各种统计数据
      EventModule.on('player:levelup', (data) => {
        console.log(`📊 升级统计: ${data.oldLevel} → ${data.newLevel}`);
      });

      EventModule.on('combat:damage', (data) => {
        // 可以在这里添加伤害统计
      });

      EventModule.on('dungeon:event', (event) => {
        // 可以在这里添加事件统计
      });
    },

    getAllStats() {
      return {
        player: PlayerModule.getStats(),
        combat: CombatModule.getStats(),
        dungeon: DungeonModule.getStats(),
        game: {
          playTime: dungeon?.statistics?.runtime || 0,
          saves: parseInt(localStorage.getItem('gameSaveCount') || '0')
        }
      };
    },

    printStats() {
      const stats = this.getAllStats();
      console.group('📊 游戏统计');
      console.table(stats.player);
      console.table(stats.combat);
      console.table(stats.dungeon);
      console.table(stats.game);
      console.groupEnd();
    }
  };

  // ===== 快捷命令模块 =====
  const CommandsModule = {
    init() {
      this.registerCommands();
    },

    registerCommands() {
      window.GM = {
        // 玩家命令
        player: {
          stats: () => PlayerModule.getStats(),
          heal: (amount = 9999) => PlayerModule.heal(amount),
          addExp: (amount) => PlayerModule.addExp(amount),
          setLevel: (level) => {
            if (player) {
              player.lvl = level;
              playerLoadStats();
            }
          }
        },
        
        // 战斗命令
        combat: {
          log: () => CombatModule.combatLog,
          stats: () => CombatModule.getStats(),
          win: () => {
            if (enemy && player.inCombat) {
              enemy.stats.hp = 0;
            }
          }
        },
        
        // 地牢命令
        dungeon: {
          stats: () => DungeonModule.getStats(),
          events: () => DungeonModule.eventHistory,
          teleport: (floor, room = 1) => {
            if (dungeon) {
              dungeon.progress.floor = floor;
              dungeon.progress.room = room;
              dungeonLoadStats();
            }
          }
        },
        
        // 系统命令
        stats: () => StatsModule.printStats(),
        save: () => saveData(),
        help: () => {
          console.log(`
=== 游戏模块命令 ===
GM.player.stats()      - 查看玩家状态
GM.player.heal()       - 满血治疗
GM.player.addExp(n)    - 添加经验
GM.player.setLevel(n)  - 设置等级

GM.combat.log          - 查看战斗日志
GM.combat.stats()      - 战斗统计
GM.combat.win()        - 立即胜利

GM.dungeon.stats()     - 地牢统计
GM.dungeon.events      - 事件历史
GM.dungeon.teleport(f) - 传送

GM.stats()             - 显示所有统计
GM.save()              - 保存游戏
          `);
        }
      };
      
      console.log('💡 游戏命令已加载，输入 GM.help() 查看帮助');
    }
  };

  // ===== 注册所有模块 =====
  GameModules.register('EventModule', EventModule);
  GameModules.register('PlayerModule', PlayerModule);
  GameModules.register('CombatModule', CombatModule);
  GameModules.register('DungeonModule', DungeonModule);
  GameModules.register('SaveModule', SaveModule);
  GameModules.register('StatsModule', StatsModule);
  GameModules.register('CommandsModule', CommandsModule);

  // ===== 初始化 =====
  if (document.readyState === 'loading') {
    document.addEventListener('DOMContentLoaded', () => {
      setTimeout(() => GameModules.initAll(), 100); // 延迟初始化，确保游戏加载完成
    });
  } else {
    setTimeout(() => GameModules.initAll(), 100);
  }
})();