// ========== 调试工具和状态管理 ==========

// 全局调试函数
window.checkDungeonState = () => {
    console.log('=== 地牢状态检查 ===');
    console.log('dungeon.status:', dungeon?.status);
    console.log('player.inCombat:', player?.inCombat);
    
    const activeModals = document.querySelectorAll('.modal-container[style*="flex"], .modal-container[style*="block"]');
    const visibleModals = Array.from(activeModals).filter(modal => 
        modal.style.display === 'flex' || modal.style.display === 'block'
    );
    console.log('可见模态窗口数量:', visibleModals.length);
    visibleModals.forEach(modal => console.log('- 模态窗口:', modal.id || modal.className));
    
    const button = document.querySelector("#dungeonActivity");
    console.log('按钮状态:', {
        text: button?.innerHTML,
        disabled: button?.disabled,
        opacity: button?.style.opacity
    });
    
    if (typeof validateDungeonState === 'function') {
        const wasFixed = validateDungeonState();
        if (wasFixed) {
            console.log('✅ 检测到并修复了状态问题');
            if (typeof updateDungeonActivityButton === 'function') {
                updateDungeonActivityButton();
            }
        } else {
            console.log('✅ 状态正常');
        }
    }
};

// 强制修复状态
window.fixDungeonState = () => {
    console.log('🔧 执行强制状态修复...');
    
    if (typeof forceResetDungeonState === 'function') {
        forceResetDungeonState();
        console.log('✅ 强制重置完成');
    } else {
        // 备用修复方案
        console.log('使用备用修复方案...');
        
        // 关闭所有模态窗口
        const modals = document.querySelectorAll('.modal-container');
        modals.forEach(modal => {
            if (modal.style.display === 'flex' || modal.style.display === 'block') {
                modal.style.display = 'none';
                console.log('关闭模态窗口:', modal.id || modal.className);
            }
        });
        
        // 重置状态
        if (typeof dungeon !== 'undefined') {
            dungeon.status.event = false;
        }
        if (typeof player !== 'undefined') {
            player.inCombat = false;
        }
        
        // 更新UI
        if (typeof updateDungeonActivityButton === 'function') {
            updateDungeonActivityButton();
        }
        
        console.log('✅ 备用修复完成');
    }
};

// 紧急清理事件状态（用户快捷键）
window.emergencyEventCleanup = () => {
    console.log('🆘 紧急清理事件状态...');
    
    // 关闭所有可能卡住的模态窗口
    const problematicModals = [
        '.modal-container',
        '#quantumShop',
        '#shopItemDetailModal', 
        '#defaultModal',
        '#confirmationModal',
        '#combatPanel'
    ];
    
    problematicModals.forEach(selector => {
        const modals = document.querySelectorAll(selector);
        modals.forEach(modal => {
            if (modal && (modal.style.display === 'flex' || modal.style.display === 'block')) {
                modal.style.display = 'none';
                console.log('紧急关闭:', selector);
            }
        });
    });
    
    // 立即清理事件状态
    if (typeof dungeon !== 'undefined') {
        dungeon.status.event = false;
        console.log('✅ 事件状态已清理');
    }
    
    // 强制更新按钮
    if (typeof updateDungeonActivityButton === 'function') {
        updateDungeonActivityButton();
        console.log('✅ 按钮状态已更新');
    }
    
    console.log('💫 紧急清理完成！可以继续游戏了');
};

// 启用调试模式
window.enableDebugMode = () => {
    window.dungeonDebugMode = true;
    console.log('🐛 调试模式已启用');
    console.log('可用命令:');
    console.log('- checkDungeonState(): 检查当前状态');
    console.log('- fixDungeonState(): 强制修复状态');
    console.log('- emergencyEventCleanup(): 紧急清理事件状态');
    console.log('- validateDungeonState(): 验证并自动修复状态');
    console.log('- 按键 Ctrl+F: 快速状态检查');
    console.log('- 按键 Ctrl+Shift+R: 强制重置状态');
    console.log('- 按键 Ctrl+E: 紧急清理事件状态');
};

// 调试快捷键
document.addEventListener('keydown', function(event) {
    // 只在非输入框时响应
    if (event.target.tagName === 'INPUT' || event.target.tagName === 'TEXTAREA') return;
    
    if (event.key.toLowerCase() === 'f' && event.ctrlKey) {
        event.preventDefault();
        checkDungeonState();
    } else if (event.key.toLowerCase() === 'r' && event.ctrlKey && event.shiftKey) {
        event.preventDefault();
        if (confirm('确定要强制重置游戏状态吗？这将关闭所有窗口并清除事件状态。')) {
            fixDungeonState();
        }
    } else if (event.key.toLowerCase() === 'e' && event.ctrlKey) {
        event.preventDefault();
        emergencyEventCleanup();
    }
});

window.addEventListener("load", function () {
    // 记录游戏启动事件
    if (typeof logGameEvent === 'function') {
        logGameEvent('Game Load', 'Game started loading');
    }
    
    // 初始化音频系统
    setVolume();
    
    // 检查隐私政策同意状态
    checkPrivacyConsent();
    
    if (player === null) {
        logGameEvent('New Player', 'Creating new character');
        runLoad("character-creation", "flex");
    } else {
        // 检查是否有未处理的死亡惩罚
        if (player.pendingDeathPenalty) {
            console.log("检测到未处理的死亡惩罚，执行重置");
            logGameEvent('Death Penalty', 'Processing pending death penalty');
            progressReset();
            delete player.pendingDeathPenalty;
            saveData();
        }
        logGameEvent('Returning Player', `Player ${player.name || 'Unknown'} loaded, Level ${player.lvl || 1}`);
        let target = document.querySelector("#title-screen");
        target.style.display = "flex";
    }

    // Title Screen Validation
    document.querySelector("#title-screen").addEventListener("click", function () {
        // 确保 Howler 音频上下文被激活
        if (Howler && Howler.ctx && Howler.ctx.state === 'suspended') {
            Howler.ctx.resume().then(() => {
                console.log("音频上下文已激活");
                // 播放一个测试音效来确认音频工作
                safePlaySFX(sfxOpen);
            }).catch(err => {
                console.log("音频上下文激活失败:", err);
            });
        }
        
        const player = JSON.parse(localStorage.getItem("playerData"));
        if (player && player.allocated) {
            enterDungeon();
        } else if (player) {
            allocationPopup();
        }
    });


    // Prevent double-click zooming on mobile devices
    document.ondblclick = function (e) {
        e.preventDefault();
    }

    // Submit Name
    document.querySelector("#name-submit").addEventListener("submit", function (e) {
        e.preventDefault();
        let playerName = document.querySelector("#name-input").value;

        var format = /[!@#$%^&*()_+\-=\[\]{};':"\\|,.<>\/?]+/;
        if (format.test(playerName)) {
            document.querySelector("#alert").innerHTML = "名字不能包含特殊字符！";
        } else {
            if (playerName.length < 1 || playerName.length > 8) {
                document.querySelector("#alert").innerHTML = "名字应该在1-8个字符之间！";
            } else {
                player = {
                    name: playerName,
                    lvl: 1,
                    stats: {
                        hp: null,
                        hpMax: null,
                        atk: null,
                        def: null,
                        pen: null,
                        atkSpd: null,
                        vamp: null,
                        critRate: null,
                        critDmg: null
                    },
                    baseStats: {
                        hp: 500,
                        atk: 100,
                        def: 50,
                        pen: 0,
                        atkSpd: 0.6,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 50
                    },
                    equippedStats: {
                        hp: 0,
                        atk: 0,
                        def: 0,
                        pen: 0,
                        atkSpd: 0,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 0,
                        hpPct: 0,
                        atkPct: 0,
                        defPct: 0,
                        penPct: 0,
                    },
                    bonusStats: {
                        hp: 0,
                        atk: 0,
                        def: 0,
                        atkSpd: 0,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 0
                    },
                    exp: {
                        expCurr: 0,
                        expMax: 100,
                        expCurrLvl: 0,
                        expMaxLvl: 100,
                        lvlGained: 0
                    },
                    inventory: {
                        consumables: [],
                        equipment: []
                    },
                    equipped: [],
                    gold: 0,
                    playtime: 0,
                    kills: 0,
                    deaths: 0,
                    inCombat: false
                };
                calculateStats();
                player.stats.hp = player.stats.hpMax;
                saveData();
                document.querySelector("#character-creation").style.display = "none";
                runLoad("title-screen", "flex");
            }
        }
    });

    // Unequip all items
    document.querySelector("#unequip-all").addEventListener("click", function () {
        safePlaySFX(sfxOpen);

        dungeon.status.exploring = false;
        let dimTarget = document.querySelector('#inventory');
        dimTarget.style.filter = "brightness(50%)";
        defaultModalElement.style.display = "flex";
        defaultModalElement.innerHTML = `
        <div class="content">
            <p>卸下所有物品？</p>
            <div class="button-container">
                <button id="unequip-confirm">卸下</button>
                <button id="unequip-cancel">取消</button>
            </div>
        </div>`;
        let confirm = document.querySelector('#unequip-confirm');
        let cancel = document.querySelector('#unequip-cancel');
        confirm.onclick = function () {
            safePlaySFX(sfxUnequip);
            unequipAll();
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
        };
        cancel.onclick = function () {
            safePlaySFX(sfxDecline);
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
        };
    });

    // Batch sell items
    document.querySelector("#sell-all").addEventListener("click", function () {
        const selectedRarity = document.querySelector('#sell-rarity').value;
        
        // 检查是否有相应的装备
        let hasItems = false;
        if (selectedRarity === "全部") {
            hasItems = player.inventory.equipment.length > 0;
        } else {
            hasItems = player.inventory.equipment.some(item => {
                try {
                    let equipment;
                    if (typeof item === 'object') {
                        equipment = item;
                    } else {
                        equipment = JSON.parse(item);
                    }
                    return equipment.rarity === selectedRarity;
                } catch (error) {
                    return false;
                }
            });
        }
        
        if (!hasItems) {
            safePlaySFX(sfxDeny);
            showNotification(selectedRarity === "全部" ? "背包中没有装备！" : `背包中没有${selectedRarity}装备！`);
            return;
        }
        
        safePlaySFX(sfxOpen);
        
        dungeon.status.exploring = false;
        let dimTarget = document.querySelector('#inventory');
        dimTarget.style.filter = "brightness(50%)";
        defaultModalElement.style.display = "flex";
        defaultModalElement.innerHTML = `
        <div class="content">
            <p>确认回收${selectedRarity === "全部" ? "所有装备" : "所有" + selectedRarity + "装备"}？</p>
            <p class="warning-text">此操作不可撤销！</p>
            <div class="button-container">
                <button id="sell-confirm">回收</button>
                <button id="sell-cancel">取消</button>
            </div>
        </div>`;
        
        let confirm = document.querySelector('#sell-confirm');
        let cancel = document.querySelector('#sell-cancel');
        
        confirm.onclick = function () {
            safePlaySFX(sfxConfirm);
            sellAll(selectedRarity);
            showInventory();
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
            showNotification(`${selectedRarity === "全部" ? "所有装备" : "所有" + selectedRarity + "装备"}已回收！`);
        };
        
        cancel.onclick = function () {
            safePlaySFX(sfxDecline);
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
        };
    });

    // 使用事件委托处理系统菜单
    document.addEventListener("click", function (e) {
        if (e.target && e.target.id === "menu-btn") {
            showSystemMenu();
        }
    });
    
    // 系统菜单显示函数
    function showSystemMenu() {
        // 不关闭库存面板，只是调暗背景
        dungeon.status.exploring = false;
        let dimDungeon = document.querySelector('#dungeon-main');
        dimDungeon.style.filter = "brightness(50%)";
        menuModalElement.style.display = "flex";

        // Menu tab
        menuModalElement.innerHTML = `
        <div class="content">
            <div class="content-head">
                <h3>菜单</h3>
                <p id="close-menu"><i class="fa fa-xmark"></i></p>
            </div>
            <button id="player-menu"><i class="fas fa-user"></i>${player.name}</button>
            <button id="stats">当前闯关</button>
            <button id="volume-btn">音量设置</button>
            <button id="theme-menu-btn"><i class="fas fa-palette"></i>主题切换</button>
            <button id="clear-save">清除存档</button>
            <button id="quit-run">放弃</button>
        </div>`;

        let close = document.querySelector('#close-menu');
        let playerMenu = document.querySelector('#player-menu');
        let runMenu = document.querySelector('#stats');
        let quitRun = document.querySelector('#quit-run');
        let volumeSettings = document.querySelector('#volume-btn');
        let themeToggleBtn = document.querySelector('#theme-menu-btn');
        let clearSave = document.querySelector('#clear-save');

        // Player profile click function
        playerMenu.onclick = function () {
            safePlaySFX(sfxOpen);
            let playTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="profile-tab">
                <div class="content-head">
                    <h3>统计信息</h3>
                    <p id="profile-close"><i class="fa fa-xmark"></i></p>
                </div>
                <p>${player.name} Lv.${player.lvl}</p>
                <p>击杀: ${nFormatter(player.kills)}</p>
                <p>死亡: ${nFormatter(player.deaths)}</p>
                <p>游戏时间: ${playTime}</p>
            </div>`;
            let profileTab = document.querySelector('#profile-tab');
            profileTab.style.width = "15rem";
            let profileClose = document.querySelector('#profile-close');
            profileClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Dungeon run click function
        runMenu.onclick = function () {
            safePlaySFX(sfxOpen);
            let runTime = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
            let currentFloor = dungeon.progress.floor;
            let currentRoom = dungeon.progress.room;
            let totalRooms = dungeon.progress.roomLimit;
            let maxFloor = dungeon.progress.floorLimit;
            let killsThisRun = dungeon.statistics.kills;
            let playerDeaths = player.deaths;
            let avgTimePerFloor = dungeon.statistics.runtime > 0 ? (dungeon.statistics.runtime / currentFloor).toFixed(1) : 0;
            
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="run-tab">
                <div class="content-head">
                    <h3><i class="fas fa-chart-line"></i> 当前闯关统计</h3>
                </div>
                
                <div class="stats-container">
                    <div class="stats-section">
                        <h4><i class="fas fa-user"></i> 操作员状态</h4>
                        <p><i class="fas fa-id-badge"></i> ${player.name} Lv.${player.lvl}</p>
                        <p><i class="fas fa-coins"></i> 信用点: ${nFormatter(player.gold)}</p>
                        <p><i class="fas fa-heart"></i> 装甲完整度: ${player.stats.hp}/${player.stats.hpMax}</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-map"></i> 探索进度</h4>
                        <p><i class="fas fa-layer-group"></i> 当前星区: ${currentFloor}/${maxFloor}</p>
                        <p><i class="fas fa-door-open"></i> 区域进度: ${currentRoom}/${totalRooms}</p>
                        <p><i class="fas fa-percentage"></i> 完成度: ${(currentFloor / maxFloor * 100).toFixed(1)}%</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-crosshairs"></i> 战斗数据</h4>
                        <p><i class="fas fa-skull"></i> 本次击杀: ${nFormatter(killsThisRun)}</p>
                        <p><i class="fas fa-heartbeat"></i> 系统崩溃: ${playerDeaths}次</p>
                        <p><i class="fas fa-tachometer-alt"></i> 平均每星区用时: ${avgTimePerFloor}秒</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-cogs"></i> 系统参数</h4>
                        <p><i class="fas fa-arrow-up"></i> 系统强化: Lv.${player.blessing}</p>
                        <p><i class="fas fa-radiation"></i> 干扰核心: Lv.${Math.round((dungeon.settings.enemyScaling - 1) * 10)}</p>
                        <p><i class="fas fa-clock"></i> 运行时间: ${runTime}</p>
                    </div>
                </div>
                
                <button id="run-close" class="bottom-close-btn">退出</button>
            </div>`;
            let runTab = document.querySelector('#run-tab');
            runTab.style.width = "25rem";
            runTab.style.maxWidth = "90vw";
            let runClose = document.querySelector('#run-close');
            runClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Quit the current run
        quitRun.onclick = function () {
            safePlaySFX(sfxOpen);
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content">
                <p>你要放弃这次闯关吗？</p>
                <div class="button-container">
                    <button id="quit-run">放弃</button>
                    <button id="cancel-quit">取消</button>
                </div>
            </div>`;
            let quit = document.querySelector('#quit-run');
            let cancel = document.querySelector('#cancel-quit');
            quit.onclick = function () {
                safePlaySFX(sfxConfirm);
                // Clear out everything, send the player back to meny and clear progress.
                MusicManager.stopBGM();
                let dimDungeon = document.querySelector('#dungeon-main');
                dimDungeon.style.filter = "brightness(100%)";
                dimDungeon.style.display = "none";
                menuModalElement.style.display = "none";
                menuModalElement.innerHTML = "";
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                runLoad("title-screen", "flex");
                clearInterval(dungeonTimer);
                clearInterval(playTimer);
                stopResting(); // 清理休息计时器
                progressReset();
            };
            cancel.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Opens the volume settings
        volumeSettings.onclick = function () {
            safePlaySFX(sfxOpen);

            let master = volume.master * 100;
            let bgm = volume.bgm * 100;
            let sfx = volume.sfx * 100;
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="volume-tab">
                <div class="content-head">
                    <h3>音量</h3>
                    <p id="volume-close"><i class="fa fa-xmark"></i></p>
                </div>
                <label id="master-label" for="master-volume">主音量 (${master}%)</label>
                <input type="range" id="master-volume" min="0" max="100" value="${master}">
                <label id="bgm-label" for="bgm-volume">背景音乐 (${bgm}%)</label>
                <input type="range" id="bgm-volume" min="0" max="100" value="${bgm}">
                <label id="sfx-label" for="sfx-volume">音效 (${sfx}%)</label>
                <input type="range" id="sfx-volume" min="0" max="100" value="${sfx}">
                <button id="apply-volume">应用</button>
            </div>`;
            let masterVol = document.querySelector('#master-volume');
            let bgmVol = document.querySelector('#bgm-volume');
            let sfxVol = document.querySelector('#sfx-volume');
            let applyVol = document.querySelector('#apply-volume');
            let volumeTab = document.querySelector('#volume-tab');
            volumeTab.style.width = "15rem";
            let volumeClose = document.querySelector('#volume-close');
            volumeClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };

            // Volume Control
            masterVol.oninput = function () {
                master = this.value;
                document.querySelector('#master-label').innerHTML = `主音量 (${master}%)`;
            };

            bgmVol.oninput = function () {
                bgm = this.value;
                document.querySelector('#bgm-label').innerHTML = `背景音乐 (${bgm}%)`;
            };

            sfxVol.oninput = function () {
                sfx = this.value;
                document.querySelector('#sfx-label').innerHTML = `音效 (${sfx}%)`;
            };

            applyVol.onclick = function () {
                volume.master = master / 100;
                volume.bgm = bgm / 100;
                volume.sfx = sfx / 100;
                // 重新设置音量并恢复当前音乐
                let wasPlaying = MusicManager.currentBGM && MusicManager.currentBGM.playing();
                let currentType = null;
                if (wasPlaying) {
                    // 确定当前播放的音乐类型
                    for (let type in MusicManager.bgmMap) {
                        if (MusicManager.currentBGM === MusicManager.bgmMap[type]()) {
                            currentType = type;
                            break;
                        }
                    }
                }
                MusicManager.stopBGM();
                setVolume();
                if (currentType && !MusicManager.isPaused) {
                    MusicManager.playBGM(currentType);
                }
                saveData();
            };
        };

        // Theme toggle
        themeToggleBtn.onclick = function () {
            safePlaySFX(sfxConfirm);
            // 调用主题切换函数
            if (typeof toggleTheme === 'function') {
                toggleTheme();
            }
            // 关闭菜单
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "none";
            dimDungeon.style.filter = "brightness(100%)";
        };

        // Clear save data
        clearSave.onclick = function () {
            safePlaySFX(sfxOpen);
            menuModalElement.style.display = "none";
            confirmationModalElement.style.display = "flex";
            confirmationModalElement.innerHTML = `
            <div class="content">
                <h3><i class="fas fa-exclamation-triangle"></i> 清除存档警告</h3>
                <p style="color: #ff6b6b; font-weight: bold; margin: 1rem 0;">
                    此操作将永久删除所有游戏数据！
                </p>
                <div style="text-align: left; margin: 1rem 0; padding: 1rem; background: rgba(255,255,255,0.05); border-radius: 8px;">
                    <p style="margin: 0.5rem 0;">将会删除的内容：</p>
                    <ul style="margin: 0.5rem 0 0.5rem 1.5rem;">
                        <li>角色数据（等级、经验、金币）</li>
                        <li>所有装备和背包物品</li>
                        <li>地牢进度和统计信息</li>
                        <li>设置和偏好选项</li>
                    </ul>
                </div>
                <p style="color: #ffa726; font-size: 0.9rem;">
                    确定要继续吗？此操作无法撤销！
                </p>
                <div class="button-container">
                    <button id="confirm-clear-save" style="background: #ff4444; border-color: #cc0000;">
                        <i class="fas fa-trash"></i> 确认清除
                    </button>
                    <button id="cancel-clear-save">
                        <i class="fas fa-times"></i> 取消
                    </button>
                </div>
            </div>`;
            
            let confirmClear = document.querySelector('#confirm-clear-save');
            let cancelClear = document.querySelector('#cancel-clear-save');
            
            confirmClear.onclick = function () {
                safePlaySFX(sfxConfirm);
                
                // 停止所有音乐
                if (window.MusicManager) {
                    MusicManager.stopBGM();
                }
                
                // 清除所有存储
                try {
                    // 停止所有定时器
                    if (typeof dungeonTimer !== 'undefined') clearInterval(dungeonTimer);
                    if (typeof playTimer !== 'undefined') clearInterval(playTimer);
                    if (typeof combatTimer !== 'undefined') clearInterval(combatTimer);
                    
                    // 清除所有已知的localStorage键
                    const keysToRemove = [
                        'playerData',
                        'dungeonData',
                        'enemyData',
                        'volumeData',
                        'dungeonTheme',
                        'shopPurchaseHistory',
                        'privacy_consent',
                        'saveBackup',
                        'chestData',
                        'independentChestSystem',
                        'mobileDebug',
                        'debugLogs',
                        'backlog',
                        'achievements',
                        'statistics',
                        'gameSettings',
                        'tutorials'
                    ];
                    
                    // 逐个删除
                    keysToRemove.forEach(key => {
                        localStorage.removeItem(key);
                    });
                    
                    // 获取并删除任何剩余的键
                    const remainingKeys = Object.keys(localStorage);
                    remainingKeys.forEach(key => {
                        localStorage.removeItem(key);
                    });
                    
                    // 最终清除
                    localStorage.clear();
                    sessionStorage.clear();
                    
                    // 清除IndexedDB
                    if ('indexedDB' in window) {
                        indexedDB.databases().then(databases => {
                            databases.forEach(db => {
                                indexedDB.deleteDatabase(db.name);
                            });
                        }).catch(() => {});
                    }
                    
                    // 清除所有cookies
                    document.cookie.split(";").forEach(function(c) { 
                        document.cookie = c.replace(/^ +/, "").replace(/=.*/, "=;expires=" + new Date().toUTCString() + ";path=/"); 
                    });
                    
                } catch (e) {
                    console.error('清除存储时出错:', e);
                }
                
                // 显示成功消息
                confirmationModalElement.innerHTML = `
                <div class="content">
                    <h3><i class="fas fa-check-circle" style="color: #4caf50;"></i> 存档已清除</h3>
                    <p style="margin: 1.5rem 0;">
                        所有游戏数据已被完全删除。
                    </p>
                    <p style="font-size: 0.9rem; opacity: 0.7;">
                        正在重新加载...
                    </p>
                </div>`;
                
                // 设置一个标志，表示正在清除数据
                sessionStorage.setItem('clearingGameData', 'true');
                
                // 立即强制重新加载页面
                setTimeout(() => {
                    // 使用replace来避免缓存
                    window.location.replace(window.location.pathname + '?reset=' + Date.now());
                }, 500);
            };
            
            cancelClear.onclick = function () {
                safePlaySFX(sfxDecline);
                confirmationModalElement.style.display = "none";
                confirmationModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Close menu
        close.onclick = function () {
            safePlaySFX(sfxDecline);
            continueExploring();
            menuModalElement.style.display = "none";
            menuModalElement.innerHTML = "";
            dimDungeon.style.filter = "brightness(100%)";
        };
    }
});

// Loading Screen
const runLoad = (id, display) => {
    let loader = document.querySelector("#loading");
    loader.style.display = "flex";
    setTimeout(async () => {
        loader.style.display = "none";
        document.querySelector(`#${id}`).style.display = `${display}`;
    }, 1000);
}

// Start the game
const enterDungeon = () => {
    safePlaySFX(sfxConfirm);
    
    // 立即播放音乐（在用户交互的直接上下文中）
    if (!player.inCombat) {
        MusicManager.playBGM('dungeon');
    }
    
    document.querySelector("#title-screen").style.display = "none";
    runLoad("dungeon-main", "flex");
    
    // 延迟执行其他初始化
    setTimeout(() => {
        if (player.inCombat) {
            enemy = JSON.parse(localStorage.getItem("enemyData"));
            showCombatInfo();
            startCombat('battleMain');
        }
        if (player.stats.hp == 0) {
            progressReset();
        }
        initialDungeonLoad();
        calculateStats();  // 确保基础属性被正确计算
        playerLoadStats();
        
        // Initialize quantum shop system
        if (typeof initQuantumShop === 'function') {
            initQuantumShop();
        }
    }, 1000);
}

// Save all the data into local storage
const saveData = () => {
    // 创建深拷贝避免修改原始数据
    const playerCopy = JSON.parse(JSON.stringify(player));
    const dungeonCopy = JSON.parse(JSON.stringify(dungeon));
    
    // 清理临时状态
    playerCopy.inCombat = false;
    dungeonCopy.status = {
        exploring: false,
        paused: true,
        event: false
    };
    
    // 清理包含交互元素的日志
    if (dungeonCopy.backlog) {
        dungeonCopy.backlog = dungeonCopy.backlog.filter(log => 
            !log.includes('decision-panel') && 
            !log.includes('<button id="choice') &&
            !log.includes('primary-panel') &&
            !log.includes('<ul>') &&
            !log.includes('<li>') &&
            !log.includes('onclick=')
        );
    }
    
    // 如果不在战斗中，清空敌人数据
    const enemyData = JSON.stringify(playerCopy.inCombat ? enemy : {});
    
    const playerData = JSON.stringify(playerCopy);
    const dungeonData = JSON.stringify(dungeonCopy);
    const volumeData = JSON.stringify(volume);
    localStorage.setItem("playerData", playerData);
    localStorage.setItem("dungeonData", dungeonData);
    localStorage.setItem("enemyData", enemyData);
    localStorage.setItem("volumeData", volumeData);
    
    // 保存商店数据（如果存在）
    if (typeof shopPurchaseHistory !== 'undefined') {
        localStorage.setItem("shopPurchaseHistory", JSON.stringify(shopPurchaseHistory));
    }
}

// Calculate every player stat
const calculateStats = () => {
    let equipmentAtkSpd = player.baseStats.atkSpd * (player.equippedStats.atkSpd / 100);
    let playerHpBase = player.baseStats.hp;
    let playerAtkBase = player.baseStats.atk;
    let playerDefBase = player.baseStats.def;
    let playerAtkSpdBase = player.baseStats.atkSpd;
    let playerVampBase = player.baseStats.vamp;
    let playerCRateBase = player.baseStats.critRate;
    let playerCDmgBase = player.baseStats.critDmg;

    player.stats.hpMax = Math.round((playerHpBase + playerHpBase * (player.bonusStats.hp / 100)) + player.equippedStats.hp);
    player.stats.atk = Math.round((playerAtkBase + playerAtkBase * (player.bonusStats.atk / 100)) + player.equippedStats.atk);
    player.stats.def = Math.round((playerDefBase + playerDefBase * (player.bonusStats.def / 100)) + player.equippedStats.def);
    player.stats.atkSpd = (playerAtkSpdBase + playerAtkSpdBase * (player.bonusStats.atkSpd / 100)) + equipmentAtkSpd + (equipmentAtkSpd * (player.equippedStats.atkSpd / 100));
    player.stats.vamp = playerVampBase + player.bonusStats.vamp + player.equippedStats.vamp;
    player.stats.critRate = playerCRateBase + player.bonusStats.critRate + player.equippedStats.critRate;
    player.stats.critDmg = playerCDmgBase + player.bonusStats.critDmg + player.equippedStats.critDmg;

    // Caps attack speed to 2.5
    if (player.stats.atkSpd > 2.5) {
        player.stats.atkSpd = 2.5;
    }
    
    // Caps crit rate to 100%
    if (player.stats.critRate > 100) {
        player.stats.critRate = 100;
    }
}

// Resets the progress back to start
const progressReset = () => {
    player.stats.hp = player.stats.hpMax;
    player.lvl = 1;
    player.blessing = 1;
    reviveCount = 0; // 重置复活次数
    player.exp = {
        expCurr: 0,
        expMax: 100,
        expCurrLvl: 0,
        expMaxLvl: 100,
        lvlGained: 0
    };
    player.bonusStats = {
        hp: 0,
        atk: 0,
        def: 0,
        atkSpd: 0,
        vamp: 0,
        critRate: 0,
        critDmg: 0
    };
    player.skills = [];
    player.inCombat = false;
    
    // 死亡惩罚：金币减半，装备保留
    player.gold = Math.floor(player.gold / 2);
    
    dungeon.progress.floor = 1;
    dungeon.progress.room = 1;
    dungeon.statistics.kills = 0;
    dungeon.status = {
        exploring: false,
        paused: true,
        event: false,
    };
    dungeon.settings = {
        enemyBaseLvl: 1,
        enemyLvlGap: 5,
        enemyBaseStats: 1,
        enemyScaling: 1.1,
    };
    delete dungeon.enemyMultipliers;
    delete player.allocated;
    dungeon.backlog.length = 0;
    dungeon.action = 0;
    dungeon.statistics.runtime = 0;
    combatBacklog.length = 0;
    
    // Reset shop per-run purchases
    if (typeof resetRunPurchases === 'function') {
        resetRunPurchases();
    }
    
    saveData();
}


// Player Stat Allocation
const allocationPopup = () => {
    let allocation = {
        hp: 5,
        atk: 5,
        def: 5,
        atkSpd: 5
    }
    const updateStats = () => {
        stats = {
            hp: 50 * allocation.hp,
            atk: 10 * allocation.atk,
            def: 10 * allocation.def,
            atkSpd: 0.4 + (0.02 * allocation.atkSpd)
        }
    }
    updateStats();
    let points = 20;
    const loadContent = function () {
        defaultModalElement.innerHTML = `
        <div class="content" id="allocate-stats">
            <div class="content-head">
                <h3>系统初始化</h3>
                <p id="allocate-close"><i class="fa fa-xmark"></i></p>
            </div>
            <div class="row">
                <p><i class="fas fa-heart-pulse"></i><span id="hpDisplay">装甲完整度: ${stats.hp}</span></p>
                <div class="row">
                    <button id="hpMin">-</button>
                    <span id="hpAllo">${allocation.hp}</span>
                    <button id="hpAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-bolt"></i><span id="atkDisplay">武器输出: ${stats.atk}W</span></p>
                <div class="row">
                    <button id="atkMin">-</button>
                    <span id="atkAllo">${allocation.atk}</span>
                    <button id="atkAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-shield"></i><span id="defDisplay">护盾强度: ${stats.def}MJ</span></p>
                <div class="row">
                    <button id="defMin">-</button>
                    <span id="defAllo">${allocation.def}</span>
                    <button id="defAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-gauge-high"></i><span id="atkSpdDisplay">反应速度: ${stats.atkSpd}/s</span></p>
                <div class="row">
                    <button id="atkSpdMin">-</button>
                    <span id="atkSpdAllo">${allocation.atkSpd}</span>
                    <button id="atkSpdAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p id="alloPts">可用模块: ${points}</p>
                <button id="allocate-reset">重置</button>
            </div>
            <div class="row skill-select-row">
                <p>增强程序</p>
                <div class="custom-select" id="custom-select">
                    <div class="select-display" id="select-display">
                        <span>等离子刃</span>
                        <i class="fas fa-chevron-down"></i>
                    </div>
                    <div class="select-options" id="select-options">
                        <div class="select-option" data-skill="Remnant Razor">等离子刃</div>
                        <div class="select-option" data-skill="Titan's Will">钛合金装甲</div>
                        <div class="select-option" data-skill="Devastator">毁灭者协议</div>
                        <div class="select-option" data-skill="Blade Dance">高频振动</div>
                        <div class="select-option" data-skill="Paladin's Heart">纳米护盾</div>
                        <div class="select-option" data-skill="Aegis Thorns">反应装甲</div>
                    </div>
                </div>
            </div>
            <div class="row primary-panel pad">
                <p id="skill-desc">攻击造成额外的敌人当前生命值8%的伤害。</p>
            </div>
            <button id="allocate-confirm">确认</button>
        </div>`;
    }
    defaultModalElement.style.display = "flex";
    document.querySelector("#title-screen").style.filter = "brightness(50%)";
    loadContent();

    // Stat Allocation
    const handleStatButtons = (e) => {
        let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
        if (e.includes("Add")) {
            let stat = e.split("Add")[0];
            if (points > 0) {
                safePlaySFX(sfxConfirm);
                allocation[stat]++;
                points--;
                updateStats();
                const statDisplayNames = {
                    "hp": "装甲完整度",
                    "atk": "武器输出",
                    "def": "护盾强度",
                    "atkSpd": "反应速度"
                };
                const statUnits = {
                    "hp": "",
                    "atk": "W",
                    "def": "MJ",
                    "atkSpd": "/s"
                };
                document.querySelector(`#${stat}Display`).innerHTML = `${statDisplayNames[stat]}: ${stats[stat].toFixed(2).replace(rx, "$1")}${statUnits[stat]}`;
                document.querySelector(`#${stat}Allo`).innerHTML = allocation[stat];
                document.querySelector(`#alloPts`).innerHTML = `可用模块: ${points}`;
            } else {
                safePlaySFX(sfxDeny);
            }
        } else if (e.includes("Min")) {
            let stat = e.split("Min")[0];
            if (allocation[stat] > 5) {
                safePlaySFX(sfxConfirm);
                allocation[stat]--;
                points++;
                updateStats();
                const statDisplayNames = {
                    "hp": "装甲完整度",
                    "atk": "武器输出",
                    "def": "护盾强度",
                    "atkSpd": "反应速度"
                };
                const statUnits = {
                    "hp": "",
                    "atk": "W",
                    "def": "MJ",
                    "atkSpd": "/s"
                };
                document.querySelector(`#${stat}Display`).innerHTML = `${statDisplayNames[stat]}: ${stats[stat].toFixed(2).replace(rx, "$1")}${statUnits[stat]}`;
                document.querySelector(`#${stat}Allo`).innerHTML = allocation[stat];
                document.querySelector(`#alloPts`).innerHTML = `可用模块: ${points}`;
            } else {
                safePlaySFX(sfxDeny);
            }
        }
    }
    document.querySelector("#hpAdd").onclick = function () {
        handleStatButtons("hpAdd")
    };
    document.querySelector("#hpMin").onclick = function () {
        handleStatButtons("hpMin")
    };
    document.querySelector("#atkAdd").onclick = function () {
        handleStatButtons("atkAdd")
    };
    document.querySelector("#atkMin").onclick = function () {
        handleStatButtons("atkMin")
    };
    document.querySelector("#defAdd").onclick = function () {
        handleStatButtons("defAdd")
    };
    document.querySelector("#defMin").onclick = function () {
        handleStatButtons("defMin")
    };
    document.querySelector("#atkSpdAdd").onclick = function () {
        handleStatButtons("atkSpdAdd")
    };
    document.querySelector("#atkSpdMin").onclick = function () {
        handleStatButtons("atkSpdMin")
    };

    // Custom dropdown system
    let selectedSkill = "Remnant Razor"; // Default selection
    const customSelect = document.querySelector("#custom-select");
    const selectDisplay = document.querySelector("#select-display");
    const selectOptions = document.querySelector("#select-options");
    const skillDesc = document.querySelector("#skill-desc");
    let isDropdownOpen = false;
    
    // Check if elements exist before binding events
    if (!customSelect || !selectDisplay || !selectOptions || !skillDesc) {
        console.error("Custom select elements not found!");
        return;
    }
    
    // Toggle dropdown
    selectDisplay.addEventListener('click', function() {
        safePlaySFX(sfxOpen);
        isDropdownOpen = !isDropdownOpen;
        
        if (isDropdownOpen) {
            selectOptions.style.display = 'block';
            customSelect.classList.add('open');
            selectDisplay.querySelector('i').style.transform = 'rotate(180deg)';
        } else {
            selectOptions.style.display = 'none';
            customSelect.classList.remove('open');
            selectDisplay.querySelector('i').style.transform = 'rotate(0deg)';
        }
    });
    
    // Handle option selection
    const options = document.querySelectorAll('.select-option');
    options.forEach(option => {
        option.addEventListener('click', function() {
            safePlaySFX(sfxConfirm);
            
            // Remove previous selection
            options.forEach(opt => opt.classList.remove('selected'));
            
            // Add selection to clicked option
            this.classList.add('selected');
            
            // Update selected skill
            selectedSkill = this.dataset.skill;
            
            // Update display
            selectDisplay.querySelector('span').textContent = this.textContent;
            
            // Update skill description
            updateSkillDescription(selectedSkill);
            
            // Close dropdown
            selectOptions.style.display = 'none';
            customSelect.classList.remove('open');
            selectDisplay.querySelector('i').style.transform = 'rotate(0deg)';
            isDropdownOpen = false;
        });
        
        option.addEventListener('mouseenter', function() {
            safePlaySFX(sfxOpen);
        });
    });
    
    // Close dropdown when clicking outside
    document.addEventListener('click', function(event) {
        if (!customSelect.contains(event.target) && isDropdownOpen) {
            selectOptions.style.display = 'none';
            customSelect.classList.remove('open');
            selectDisplay.querySelector('i').style.transform = 'rotate(0deg)';
            isDropdownOpen = false;
        }
    });
    
    // Update skill description function
    const updateSkillDescription = (skill) => {
        if (skill == "Remnant Razor") {
            skillDesc.innerHTML = "攻击造成额外的敌人当前生命值8%的伤害。";
        }
        if (skill == "Titan's Will") {
            skillDesc.innerHTML = "攻击造成额外的你的最大生命值5%的伤害。";
        }
        if (skill == "Devastator") {
            skillDesc.innerHTML = "造成额外的30%的伤害，但你失去30%的基础攻击速度。";
        }
        if (skill == "Rampager") {
            skillDesc.innerHTML = "每次攻击后攻击力增加5。叠加在战斗后重置。";
        }
        if (skill == "Blade Dance") {
            skillDesc.innerHTML = "每次攻击后获得额外的攻击速度。叠加在战斗后重置。";
        }
        if (skill == "Paladin's Heart") {
            skillDesc.innerHTML = "你永久性地受到少的25%的伤害。";
        }
        if (skill == "Aegis Thorns") {
            skillDesc.innerHTML = "敌人受到他们造成伤害的15%的反弹伤害。";
        }
    };
    
    // Set default selection
    document.querySelector('[data-skill="Remnant Razor"]').classList.add('selected');
    updateSkillDescription(selectedSkill);

    // Operation Buttons
    let confirm = document.querySelector("#allocate-confirm");
    let reset = document.querySelector("#allocate-reset");
    let close = document.querySelector("#allocate-close");
    confirm.onclick = function () {
        safePlaySFX(sfxConfirm);
        // Set allocated stats to player base stats
        player.baseStats = {
            hp: stats.hp,
            atk: stats.atk,
            def: stats.def,
            pen: 0,
            atkSpd: stats.atkSpd,
            vamp: 0,
            critRate: 0,
            critDmg: 50
        }

        // Set player skill
        objectValidation();
        if (selectedSkill == "Remnant Razor") {
            player.skills.push("Remnant Razor");
        }
        if (selectedSkill == "Titan's Will") {
            player.skills.push("Titan's Will");
        }
        if (selectedSkill == "Devastator") {
            player.skills.push("Devastator");
            player.baseStats.atkSpd = player.baseStats.atkSpd - ((30 * player.baseStats.atkSpd) / 100);
        }
        if (selectedSkill == "Rampager") {
            player.skills.push("Rampager");
        }
        if (selectedSkill == "Blade Dance") {
            player.skills.push("Blade Dance");
        }
        if (selectedSkill == "Paladin's Heart") {
            player.skills.push("Paladin's Heart");
        }
        if (selectedSkill == "Aegis Thorns") {
            player.skills.push("Aegis Thorns");
        }

        // Proceed to dungeon
        player.allocated = true;
        enterDungeon();
        player.stats.hp = player.stats.hpMax;
        playerLoadStats();
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        document.querySelector("#title-screen").style.filter = "brightness(100%)";
    }
    reset.onclick = function () {
        safePlaySFX(sfxDecline);
        allocation = {
            hp: 5,
            atk: 5,
            def: 5,
            atkSpd: 5
        };
        points = 20;
        updateStats();

        // Display Reset
        document.querySelector(`#hpDisplay`).innerHTML = `装甲完整度: ${stats.hp}`;
        document.querySelector(`#atkDisplay`).innerHTML = `武器输出: ${stats.atk}W`;
        document.querySelector(`#defDisplay`).innerHTML = `护盾强度: ${stats.def}MJ`;
        document.querySelector(`#atkSpdDisplay`).innerHTML = `反应速度: ${stats.atkSpd}/s`;
        document.querySelector(`#hpAllo`).innerHTML = allocation.hp;
        document.querySelector(`#atkAllo`).innerHTML = allocation.atk;
        document.querySelector(`#defAllo`).innerHTML = allocation.def;
        document.querySelector(`#atkSpdAllo`).innerHTML = allocation.atkSpd;
        document.querySelector(`#alloPts`).innerHTML = `Stat Points: ${points}`;
    }
    close.onclick = function () {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        document.querySelector("#title-screen").style.filter = "brightness(100%)";
    }
}

const objectValidation = () => {
    if (player.skills == undefined) {
        player.skills = [];
    }
    if (player.tempStats == undefined) {
        player.tempStats = {};
        player.tempStats.atk = 0;
        player.tempStats.atkSpd = 0;
    }
    saveData();
}

// 测试模式按键监听 (T, G, V)
document.addEventListener('keydown', function(e) {
    // 只在游戏主界面时生效，且没有输入框聚焦
    const dungeonMain = document.querySelector('#dungeon-main');
    const activeElement = document.activeElement;
    const isInputFocused = activeElement && (activeElement.tagName === 'INPUT' || activeElement.tagName === 'TEXTAREA');
    
    if (dungeonMain && dungeonMain.style.display !== 'none' && !isInputFocused) {
        
        // T 触发测试模式
        if (e.key.toLowerCase() === 't') {
            e.preventDefault();
            showTestModeModal();
        }
        
        // V 直接触发胜利
        if (e.key.toLowerCase() === 'v') {
            e.preventDefault();
            triggerTestVictory();
        }
        
        // G 传送到99层
        if (e.key.toLowerCase() === 'g') {
            e.preventDefault();
            teleportTo99();
        }
        
        // D 调试金币显示
        if (e.key.toLowerCase() === 'd') {
            e.preventDefault();
            debugGoldDisplay();
        }
        
        // E 调试事件状态
        if (e.key.toLowerCase() === 'e') {
            e.preventDefault();
            console.log('=== 事件状态调试信息 ===');
            console.log('dungeon.status.event:', dungeon.status.event);
            console.log('dungeon.status.exploring:', dungeon.status.exploring);
            console.log('dungeon.status.paused:', dungeon.status.paused);
            console.log('player.inCombat:', player.inCombat);
            console.log('========================');
        }
    }
});

// 显示测试模式弹窗
const showTestModeModal = () => {
    if (typeof sfxOpen !== 'undefined' && sfxOpen.play) {
        safePlaySFX(sfxOpen);
    }
    dungeon.status.exploring = false;
    let dimDungeon = document.querySelector('#dungeon-main');
    dimDungeon.style.filter = "brightness(50%)";
    
    document.querySelector("#defaultModal").style.display = "flex";
    document.querySelector("#defaultModal").innerHTML = `
    <div class="content">
        <div class="content-head">
            <h3><i class="fas fa-rocket"></i> 测试模式</h3>
            <p id="test-close"><i class="fa fa-xmark"></i></p>
        </div>
        <div style="text-align: center; margin-bottom: 1.5rem;">
            <p>使用快捷键快速测试游戏功能：</p>
            <div style="background: rgba(0, 212, 255, 0.1); padding: 1rem; border-radius: 8px; margin: 1rem 0;">
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">G</kbd> 传送到第99层</p>
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">V</kbd> 直接触发胜利</p>
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">T</kbd> 显示此面板</p>
            </div>
            <p style="color: #ff6b6b; font-size: 0.9rem;">警告：这些操作会影响当前进度！</p>
        </div>
        <div class="button-container">
            <button id="test-to-99">传送到第99层</button>
            <button id="test-victory">直接触发胜利</button>
            <button id="test-cancel">关闭</button>
        </div>
    </div>`;
    
    let testClose = document.querySelector('#test-close');
    let testTo99 = document.querySelector('#test-to-99');
    let testVictory = document.querySelector('#test-victory');
    let testCancel = document.querySelector('#test-cancel');
    
    testClose.onclick = testCancel.onclick = function () {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector("#defaultModal").innerHTML = "";
        dimDungeon.style.filter = "brightness(100%)";
        continueExploring();
    };
    
    testTo99.onclick = function () {
        teleportTo99();
        testCancel.onclick();
    };
    
    testVictory.onclick = function () {
        triggerTestVictory();
        testCancel.onclick();
    };
};

// 传送到99层
const teleportTo99 = () => {
    if (typeof sfxConfirm !== 'undefined' && sfxConfirm.play) {
        safePlaySFX(sfxConfirm);
    }
    
    // 快速设置到99层用于测试
    dungeon.progress.floor = 99;
    dungeon.progress.room = 5;
    player.lvl = 50;
    player.blessing = 10;
    player.gold = 1000000;
    player.kills += 500;
    dungeon.statistics.kills += 100;
    
    // 给予强力装备和属性
    player.bonusStats.hp += 200;
    player.bonusStats.atk += 200;
    player.bonusStats.def += 200;
    player.bonusStats.atkSpd += 50;
    player.bonusStats.critRate += 50;
    player.bonusStats.critDmg += 200;
    
    calculateStats();
    player.stats.hp = player.stats.hpMax;
    playerLoadStats();
    loadDungeonProgress();
    saveData();
    
    addDungeonLog("<span class='Heirloom'>测试模式激活：已传送到第99层！</span>");
};

// 直接触发胜利
const triggerTestVictory = () => {
    if (typeof sfxConfirm !== 'undefined' && sfxConfirm.play) {
        safePlaySFX(sfxConfirm);
    }
    
    // 直接触发胜利界面用于测试
    dungeon.progress.floor = 100;
    dungeon.statistics.runtime = 1800; // 30分钟测试时间
    player.lvl = 75;
    player.blessing = 15;
    dungeon.statistics.kills = 200;
    
    saveData();
    triggerVictory();
};

// ========== 隐私政策相关函数 ==========

// 检查隐私政策同意状态
function checkPrivacyConsent() {
    const consent = localStorage.getItem('privacy_consent');
    if (consent !== 'accepted') {
        showPrivacyModal();
    } else {
        // 用户已同意，初始化SDK
        if (typeof AndroidBridge !== 'undefined' && AndroidBridge.initializeAdSDK) {
            console.log('用户已同意隐私政策，初始化广告SDK...');
            AndroidBridge.initializeAdSDK();
        }
    }
}

// 显示隐私政策弹窗
function showPrivacyModal() {
    const privacyModal = document.getElementById('privacy-modal');
    if (privacyModal) {
        privacyModal.style.display = 'flex';
        
        // 绑定事件监听器
        const acceptBtn = document.getElementById('privacy-accept');
        const declineBtn = document.getElementById('privacy-decline');
        const privacyLink = document.getElementById('privacy-link');
        
        if (acceptBtn) {
            acceptBtn.addEventListener('click', handlePrivacyAccept);
        }
        
        if (declineBtn) {
            declineBtn.addEventListener('click', handlePrivacyDecline);
        }
        
        if (privacyLink) {
            privacyLink.addEventListener('click', function(e) {
                e.preventDefault();
                const url = this.href;
                
                // 在Android环境中使用原生方法打开外部浏览器
                if (typeof AndroidBridge !== 'undefined' && AndroidBridge.openExternalBrowser) {
                    AndroidBridge.openExternalBrowser(url);
                } else {
                    // 在Web环境中正常打开
                    window.open(url, '_blank');
                }
            });
        }
    }
}

// 处理同意隐私政策
function handlePrivacyAccept() {
    // 保存同意状态
    localStorage.setItem('privacy_consent', 'accepted');
    
    // 隐藏弹窗
    const privacyModal = document.getElementById('privacy-modal');
    if (privacyModal) {
        privacyModal.style.display = 'none';
    }
    
    // 播放确认音效
    if (typeof sfxConfirm !== 'undefined') {
        safePlaySFX(sfxConfirm);
    }
    
    console.log('用户已同意隐私政策');
    
    // 初始化广告SDK（仅在Android环境中）
    if (typeof AndroidBridge !== 'undefined' && AndroidBridge.initializeAdSDK) {
        console.log('初始化广告SDK...');
        AndroidBridge.initializeAdSDK();
    }
}

// 处理拒绝隐私政策
function handlePrivacyDecline() {
    // 播放音效
    if (typeof sfxCancel !== 'undefined') {
        safePlaySFX(sfxCancel);
    }
    
    // 退出游戏
    // 在移动端App中，尝试调用原生关闭方法
    if (typeof AndroidBridge !== 'undefined' && AndroidBridge.closeApp) {
        AndroidBridge.closeApp();
    } else if (typeof webkit !== 'undefined' && webkit.messageHandlers && webkit.messageHandlers.closeApp) {
        webkit.messageHandlers.closeApp.postMessage('');
    } else {
        // Web环境下关闭窗口或页面
        try {
            window.close();
        } catch (e) {
            // 如果无法关闭窗口，显示消息并跳转到空白页
            alert('感谢您的使用，再见！');
            window.location.href = 'about:blank';
        }
    }
}

// ========== Inventory 相关函数 ==========

// 打开库存界面
const openInventory = () => {
    safePlaySFX(sfxOpen);
    document.querySelector("#inventory").style.display = "flex";
    showInventory();
    showEquipment();
}

// 关闭库存界面
const closeInventory = () => {
    safePlaySFX(sfxDecline);
    document.querySelector("#inventory").style.display = "none";
    
    // 关闭库存后，如果之前在探索，继续探索
    continueExploring();
}

// 继续探索（在关闭窗口后恢复探索状态）
const continueExploring = () => {
    // 如果之前正在探索且没有事件和战斗，继续探索
    if (dungeon && dungeon.status && dungeon.status.exploring && !dungeon.status.event && !player.inCombat) {
        // 触发下一个事件
        if (typeof EventStateManager !== 'undefined' && EventStateManager.triggerNextEvent) {
            setTimeout(() => {
                EventStateManager.triggerNextEvent();
            }, 500);
        }
    }
}
